/*
 * Copyright 2012  Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *	  http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __DEF_cam_app_H_
#define __DEF_cam_app_H_



#include <Elementary.h>
#include <Ecore_X.h>
#include <Edje.h>
#include <utilX.h>
#include <glib.h>
#include <glib-object.h>

#include <libintl.h>
#include <aul.h>
#include <aul_service.h>
#include <app.h>

#include "cam_property.h"
#include "cam_debug.h"

#include <media_content.h>

#define USE_FIFO_THREAD
#define EFL_TEMP_CODE
#define REG_THREAD_EXIT "REG_THREAD_EXIT"
#define RUN_IMAGE_HANDLE "RUN_IMAGE_HANDLE"
#define UPDATE_THUMBNAIL "UPDATE_THUMBNAIL"
#define UPDATE_THUMBNAIL_NO_ANI "UPDATE_THUMBNAIL_NO_ANI"
#define REC_FILE_SAVE_REG "REC_FILE_SAVE_REG"


#define USE_VCONF_CAMERA_KEY

/* next define statement will be deleted */
#define TODO_SURRPORT
#include <camera.h>
#define BEAT_UI


/*
  * example
GValue value = {0, };
CAM_GVALUE_SET_INT(value, 10);
*/

#define CAM_GVALUE_SET_INT(g_value/*GValue */, n_value) \
{ \
	g_value_init(&g_value, G_TYPE_INT); \
	g_value_set_int(&g_value, n_value); \
}

#define CAM_GVALUE_SET_UINT(g_value/*GValue */, n_value) \
{ \
	g_value_init(&g_value, G_TYPE_UINT); \
	g_value_set_uint(&g_value, n_value); \
}

#define CAM_GVALUE_SET_BOOLEAN(g_value/*GValue */, n_value) \
{ \
	g_value_init(&g_value, G_TYPE_BOOLEAN); \
	g_value_set_boolean(&g_value, n_value); \
}

#define CAM_GVALUE_SET_STRING(g_value/*GValue */, n_value) \
{ \
	g_value_init(&g_value, G_TYPE_STRING); \
	g_value_set_string(&g_value, n_value); \
}

#define _EDJ(x)  (Evas_Object *)elm_layout_edje_get(x)
/* guide rect color of panorama shot & smile shot */
#define UYVY_GUIDE_RECT_GREEN	(unsigned long)0xC262C212;
#define UYVY_GUIDE_RECT_ORANGE 	(unsigned long)0xA6BAA621;
#define UYVY_GUIDE_RECT_RED 	(unsigned long)0x52FA5270;
#define UYVY_GUIDE_RECT_WHITE 	(unsigned long)0xFE7FFE80;
#define YUYV_GUIDE_RECT_GREEN	(unsigned long)0x62C212C2;
#define YUYV_GUIDE_RECT_ORANGE 	(unsigned long)0xBAA621A6;
#define YUYV_GUIDE_RECT_RED		(unsigned long)0xFA527052;
#define YUYV_GUIDE_RECT_WHITE 	(unsigned long)0x7FFE80FE;

enum {
	NORMAL_BATTERY_STATUS = 0,
	LOW_BATTERY_WARNING_STATUS,
	LOW_BATTERY_CRITICAL_STATUS,
};

enum {
	DISPLAY_NONE_POPUP = 0,
	DISPLAY_EDIT_SHOTCUTS_POPUP,
	DISPLAY_BURST_SHOT_MODE_POPUP,
	DISPLAY_VOLUME_KEY_POPUP,
	DISPLAY_SELF_PORTRAIT_POPUP,
	DISPLAY_FLASH_POPUP,
	DISPLAY_SHOOTING_MODE_POPUP,
	DISPLAY_RECORDING_MODE_POPUP,
	DISPLAY_SCENE_MODE_POPUP,
	DISPLAY_FOCUS_MODE_POPUP,
	DISPLAY_TIMER_POPUP,
	DISPLAY_EFFECTS_POPUP,
	DISPLAY_PHOTO_RESOLUTION_POPUP,
	DISPLAY_VIDEO_RESOLUTION_POPUP,
	DISPLAY_WHITE_BALANCE_POPUP,
	DISPLAY_ISO_POPUP,
	DISPLAY_METERING_POPUP,
	DISPLAY_ANTI_SHAKE_POPUP,
	DISPLAY_OUTDOOR_VISIBILITY_POPUP,
	DISPLAY_AUTO_CONTRAST_POPUP,
	DISPLAY_GUIDELINES_POPUP,
	DISPLAY_CAPTURE_VOICE_POPUP,
	DISPLAY_GPS_TAG_POPUP,
	DISPLAY_SAVE_AS_FLIP,
	DISPLAY_STORAGE_POPUP,
	DISPLAY_RESET_POPUP,
};

enum {
	CAM_POPUP_RESPONSE_NONE = 0,
	CAM_POPUP_RESPONSE_TIMEOUT,
	CAM_POPUP_RESPONSE_OK,
	CAM_POPUP_RESPONSE_CANCEL,
	CAM_POPUP_RESPONSE_CLOSE,
  } ;

typedef enum _CamCaptureMode{
	CAM_CAPTURE_DEFAULT = 0,
	CAM_CAPTURE_SINGLE = CAM_CAPTURE_DEFAULT,
	CAM_CAPTURE_BURST,
	CAM_CAPTURE_MAX,
}CamCaptureMode;

typedef enum _CamFileExtention{
	CAM_FILE_EXTENTION_IMAGE =0,
	CAM_FILE_EXTENTION_VIDEO,
}CamFileExtention;

typedef void (*cam_update_view_cb)(void *data);


typedef struct _CamApp CamAppData;

struct _CamApp {
	gint camera_mode;
	gint shooting_mode;
	gint recording_mode;
	gint scene_mode;
	gint focus_mode;
	gint photo_resolution;
	gint video_resolution;
	gint fps;
	gint brightness;
	gint brightness_min;
	gint brightness_max;
	gint white_balance;
	gint iso;
	gint auto_exposure;
	gint effect;
	gint af_mode;
	gint wdr;
	gint flash;
	gint timer;
	gint image_quality;
	gint video_quality;
	gint audio_quality;
	gint default_preview_width;
	gint default_preview_height;
	gint battery_level;
	gint battery_charging;

	gint gps_level;
	gint zoom_min;
	gint zoom_max;
	gint zoom_mode;
	gint storage;
	gint volume_key;

	gint device_type;

	gboolean self_portrait;
	gboolean outdoor_visibility;
	gboolean burst_shot;
	gboolean audio_recording;
	gboolean anti_shake;
	gboolean capture_by_voice;
	gboolean auto_contrast;
	gboolean guideline;
	gboolean gps;
	gboolean review;
	gboolean save_as_flip;
	gboolean enable_touch_af;
	CamTouchAFState touch_af_state;

	int need_gps_popup;
	int need_gps_on;

	gint image_count;
	gint shutter_sound;
	gint size_limit;
	gint size_limit_type;
	guint rec_elapsed;
	guint rec_filesize;
	guint rec_stop_type;

	guint focus_state;

	/* timeout check */
	gdouble last_time;
	gdouble start_time;	/* setting toolbar */

	/* continuous */
	Evas_Object *conti_image;
	int conti_capture_cnt;

	/* guide rect for px & smile shot */
	gulong guide_rect_color;

	/*  continuous shot */
	CamContinuousShotData *continuous_shot_data;

	/* post processing */
	gboolean post_processing;

	/* file */
	gchar *filename;
	char *thumbnail_name;

	gboolean zoom_lock;

	int key_lock;
	int mouse_lock;

	/*set guide rect color */
	gulong guide_rect_green;
	gulong guide_rect_orange;
	gulong guide_rect_red;
	gulong guide_rect_white; /*store white color of yuyv or uvuv*/

	/*camera callback*/
	camera_state_changed_cb state_cb;
	camera_focus_changed_cb focus_cb;
	camera_error_cb error_cb;
	camera_capturing_cb capture_cb;
	camera_capture_completed_cb capture_completed_cb;
	camera_preview_cb preview_cb;
	camera_interrupted_cb cam_interrupted_cb;
	cam_update_view_cb update_view_cb;

	/*recorder callbak*/
	recorder_recording_status_cb recording_status_cb;
	recorder_state_changed_cb recording_state_changed_cb;
	recorder_recording_limit_reached_cb recording_limit_reached_cb;
	recorder_interrupted_cb rec_interrupted_cb;

	/*face detect callback*/
	camera_face_detected_cb face_detect_cb;

	CamCaptureMode default_capture_mode;

	/* reserved setting data*/
	cam_reserved_setting_data reserved_setting_data;
};

typedef struct _CamVideoRectangle CamVideoRectangle;
struct _CamVideoRectangle {
	gint x;
	gint y;
	gint w;
	gint h;
};


/**
 * Structure of Idler item
 */
typedef struct {
	Ecore_Idler *idler;
	void *data;
} CamIdlerItem;

gboolean __cam_single_shot_reg_file(char *file_path);

/* Idler of capture callback management. wh01.cho@samsung.com. 2010-12-15. */
Eina_Bool cam_image_capture_handle_idler(void *item);
Eina_Bool cam_image_capture_handle(void *data);
Eina_Bool cam_capture_on_recording_handle(void *data);

 /* gboolean cam_xwin_create(void *data); */
void *cam_appdata_get(void);
int cam_appdata_init(void *data);
int cam_appdata_fini(void *data);
CamAppData *cam_handle_get(void);

gboolean cam_app_start(void *data);
gboolean cam_app_stop(void *data);
gboolean cam_app_resume(void *data);
gboolean cam_app_pause(void *data);

gboolean cam_app_init(void *data);

gboolean cam_handle_create(void *data);
gboolean cam_handle_free(void *data);
gboolean cam_handle_init(void *data, int mode);
/* auto shot for smile , panorama, action shot and etc. */
Eina_Bool _auto_shot_idle_cb(void *data);

gboolean cam_app_preview_start(void *data);
gboolean cam_app_preview_stop(void);

gboolean cam_camera_touch_af_press(void *data);
gboolean cam_camera_key_press(void *data);
gboolean cam_camera_key_half_press(void *data);
gboolean cam_camera_key_release(void *data);
gboolean cam_camera_key_half_release(void *data);
Eina_Bool cam_volume_key_press(void *data);

Eina_Bool cam_hard_key_up(void *data, int type, void *event_info);
Eina_Bool cam_hard_key_down(void *data, int type, void *event_info);

Eina_Bool cam_mouse_button_down(void *data, void *event_info);
Eina_Bool cam_mouse_button_up(void *data, void *event_info);

gboolean cam_handle_value_set(void *data, int type, const GValue *value);

int cam_app_get_latest_mode(void);
void cam_app_set_config_group(gint mode);

const gchar *cam_app_get_target_path(void);
gchar *cam_app_get_next_filename(CamFileExtention extention);
gchar *cam_app_get_last_filename(void);

gboolean cam_callback_init(void *data);

gboolean cam_app_run_media_browser(void *data, gchar *filename);
/* int cam_quick_waiter(void * data); */

gboolean cam_app_clear_engine_data(void *data, gboolean release);

gboolean cam_app_check_wide_resolution(int id);

gboolean cam_app_is_skip_video_stream();	/* if true , must finish function in stream callback function */

void cam_app_stop_video_stream();	/* This function set skip flag to true, so cam_app_skip_video_stream will be returned true, */

void cam_app_run_video_stream();	/* This function set skip flag to false, for frame process in px or smile shot */

Eina_Bool cam_app_capture_idle_cb(void *yuvdata);

/* progress */
gboolean cam_app_create_progressbar(void *data);
gboolean cam_app_set_progressbar_value(void *data, double value);
gboolean cam_app_set_progressbar_text(void *data, const char *text);
gboolean cam_app_destroy_progressbar(void *data);

/* timeout */
gboolean cam_app_timeout_checker_init(void *data);
gboolean cam_app_timeout_checker_remove(void);

#ifdef USE_FIFO_THREAD
void *cam_app_FIFO_thread_run(void *data);
void cam_app_FIFO_thread_exit();
#endif

gboolean cam_app_create_file_register_thread(void *data);
void *cam_app_file_register_thread_run(void *data);
void cam_app_file_register_thread_exit(void *data);
gboolean cam_app_set_args(void *data, char *args[]);
gboolean cam_app_init_with_args(void *data);

/* gboolean cam_app_wait_target_state(int target, int wait_time); */

gboolean cam_app_exit(void *data);

gboolean cam_key_grab_init(void *data);
gboolean cam_key_grab_deinit(void *data);

gboolean cam_app_key_event_init(void *data);
gboolean cam_app_key_event_deinit(void *data);

gboolean cam_layout_init(void *data);
gboolean cam_mode_change(void *data, int to_mode);
gboolean cam_shooting_mode_change(void *data);
gboolean cam_recording_mode_change(void *data, int rec_mode);

void cam_app_set_progress_value(Evas_Object *pb, double value,
				const char *message);
gboolean cam_app_set_vconf_state(int vconf_state);
gboolean cam_app_get_vconf_state(int *vconf_state);

void cam_app_reset_settings(void *data);
gboolean cam_toolbar_menu_config_update(void *data);

gboolean cam_app_set_resolution(void *data, int width, int height);
gboolean cam_app_get_photo_resolution(int *width, int *height);
gboolean cam_app_reset_resolution(void *data, int width, int height,  gboolean force_set);
int cam_app_get_aenc_bitrate(void *data);
int cam_app_get_venc_bitrate(void *data, int quality);
gboolean cam_app_set_video_quality(void *data, int quality);
gboolean cam_app_set_recording_mode(void *data, int mode);
gboolean cam_app_set_size_limit(int max_val, int size_limit_type);
gboolean cam_app_init_attribute(void *data, CamMode mode);



void cam_app_toggle_indicator(void *data, gboolean hide);
void cam_app_toggle_toolbar(void *data, gboolean hide);
void cam_app_get_preview_offset_coordinate(void *data);
void cam_app_draw_af_box(void *data);

void cam_app_set_blocking_popup();
void cam_app_free_blocking_popup();
void cam_app_popup_response_cb(void *data, Evas_Object *obj, void *event_info);
void cam_app_gps_popup_response_cb(void *data, Evas_Object *obj, void *event_info);

Evas_Object *cam_app_create_win(Evas_Object *parent, const char *name);

Evas_Object *cam_app_load_edj(Evas_Object *parent, const char *file, const char *group);

void cam_app_update_thumbnail();

void cam_set_orient_value(void *data);


gboolean cam_app_parse_args(CamExeArgs *args, service_h service);

#ifdef EFL_TEMP_CODE
void cam_win_transparent_set(void *data);
#endif

void cam_app_gps_enable_popup(void *data, const char *msg,
			      Eina_Bool (*func) (void *data));
void cam_app_notice_popup(void *data, const char *msg,
			   void (*func) (void *data,
			   Evas_Object *obj,
			   void *event_info)
			   );
void cam_app_timeout_notice_response_cb(void *data,
					Evas_Object *obj,
					void *event_info);
void cam_app_lowbattery_close_flash_cb(void *data, Evas_Object *obj,
					void *event_info);
gboolean cam_app_run_image_viewer_ug(void *data, char *file_path, gboolean launch_special_view);
gboolean cam_app_run_location_ug(void *data);
gboolean cam_image_capture_start(void *data);
/* update thumbnail to quickview after first launching or return from image viewer */
void cam_app_update_quickview_icon(void *data);
/* Idler of capture callback management. wh01.cho@samsung.com. 2010-12-15. */
void cam_utils_remove_idler_all(void *data);
gdouble _get_current_time(void);
void cam_remove_tmp_file();
Eina_Bool cam_continuous_af_start(void *data);

Eina_Bool cam_elm_cache_flush();
void cam_app_mdm_syspopup(void *data);
gboolean cam_app_lbs_start(void *data);
gboolean cam_app_lbs_stop(void *data);

Eina_Bool cam_app_focus_guide_create(void *data);
Eina_Bool cam_app_focus_guide_update(void *data);

Eina_Bool cam_screen_rotate(void *data);
void cam_app_screen_rotate(void *data);

void cam_app_cancel_timer(void *data);

gboolean cam_condition_check_to_start_camera(void *data);

void cam_app_get_win_size(void* data);

gboolean cam_do_record(void* data);
gboolean cam_do_capture(void* data);

void cam_reset_focus_mode(void *data);

gboolean cam_set_default_capture_mode(void *data, CamCaptureMode type);
/* timeout */
gboolean cam_app_timeout_checker_update();
gboolean cam_app_hide_progressbar(void *data);
gint cam_app_get_max_image_size_by_ratio(void *data, int resolution);
void cam_app_stop_capture(void* data);
void cam_create_error_popup(void* data);

#endif
