/*
 * Copyright 2012  Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *	  http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef CAM_POPUP_H_
#define CAM_POPUP_H_

#include <Elementary.h>
#include <glib.h>

/* define USE_ELM_POPUP */
void cam_popup_remove(Evas_Object *popup);
void cam_popup_remove_all(void);

#ifdef USE_ELM_POPUP
typedef void (*cam_popup_respons_cb) (void *user_data, Evas_Object *obj,
				      void *event_info);

/* popup with one button,  ELM_POPUP_RESPONSE_OK is sent along with response signal. */
void cam_popup_confirm_add(Evas_Object *window, const char *message,
			   const char *btn_name, cam_popup_respons_cb callback,
			   void *user_data);

/* popup with two button, ELM_POPUP_RESPONSE_OK/ELM_POPUP_RESPONSE_CANCEL is sent along with response signal. */
void cam_popup_question_add(Evas_Object *window, const char *message,
			    const char *btn_n_1, const char *btn_n_2,
			    cam_popup_respons_cb callback, void *user_data);

#else

/* popup with one button */
void
cam_popup_confirm_add(Evas_Object *window, const char *message,
		      const char *btn_name,
		      void (*btn_cb) (void *data, Evas_Object *obj,
				      void *event_info));

/* popup with two button */
void
cam_popup_question_add(Evas_Object *window, const char *message,
		       const char *lbtn_name,
		       void (*left_btn_cb) (void *data, Evas_Object *obj,
					    void *event_info),
		       const char *rbtn_name, void (*right_btn_cb) (void *data,
								    Evas_Object
								    *obj,
								    void
								    *event_info));

Evas_Object *cam_popup_guide_screen_add(Evas_Object *window,
					const char *message);

#endif

gboolean cam_popup_create(void *data);
gboolean cam_popup_add_progress_bar(void *data);
gboolean cam_popup_set_text(void *data, char *text);
gboolean cam_popup_set_bar_value(void *data, double value);
gboolean cam_popup_delete(void *data);
void cam_popup_rotate(void *data);
gboolean cam_popup_for_burst_create(void *data);

#endif
