/*
 * Copyright 2012  Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *	  http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef _CAM_TA_H_
#define _CAM_TA_H_

#define ENABLE_TA
#ifdef ENABLE_TA
#define CAM_TA_MAX_CHECKPOINT	500
#define CAM_TA_MAX_ACCUM		500

typedef struct _cam_ta_checkpoint {
	unsigned long timestamp;
	char *name;
} cam_ta_checkpoint;

typedef struct _cam_ta_accum_item {
	unsigned long elapsed_accum;
	unsigned long num_calls;
	unsigned long elapsed_min;
	unsigned long elapsed_max;
	unsigned long first_start;
	unsigned long last_end;

	char *name;

	unsigned long timestamp;
	int on_estimate;
	int num_unpair;
} cam_ta_accum_item;

#define CAM_TA_SHOW_STDOUT	0
#define CAM_TA_SHOW_STDERR	1
#define CAM_TA_SHOW_FILE	2
#define CAM_TA_RESULT_FILE "/tmp/cam-ta.log"

int cam_ta_init(void);
int cam_ta_release(void);
void cam_ta_set_enable(int enable);
char *cam_ta_fmt(const char *fmt, ...);

int cam_ta_add_checkpoint(char *name, int show, char *filename, int line);
void cam_ta_show_checkpoints(void);
void cam_ta_show_diff(char *name1, char *name2);

int cam_ta_get_numof_checkpoints();
unsigned long cam_ta_get_diff(char *name1, char *name2);
char *cam_ta_get_name(int idx);

int cam_ta_accum_item_begin(char *name, int show, char *filename, int line);
int cam_ta_accum_item_end(char *name, int show, char *filename, int line);
void cam_ta_accum_show_result(int direction);

#define CAM_TA_INIT()								(cam_ta_init())
#define CAM_TA_RELEASE()							(cam_ta_release())
#define CAM_TA_SET_ENABLE(enable)					(cam_ta_set_enable(enable))

#define CAM_TA_ADD_CHECKPOINT(name, show)		(cam_ta_add_checkpoint(name, show, __FILE__, __LINE__))
#define CAM_TA_SHOW_CHECKPOINTS()				(cam_ta_show_checkpoints())
#define CAM_TA_SHOW_DIFF(name1, name2)			(cam_ta_show_diff(name1, name2))
#define CAM_TA_GET_NUMOF_CHECKPOINTS()			(cam_ta_get_numof_checkpoints())
#define CAM_TA_GET_DIFF(name1, name2)				(cam_ta_get_diff(name1, name2))
#define CAM_TA_GET_NAME(idx)						(cam_ta_get_name(idx))

#define CAM_TA_ACUM_ITEM_BEGIN(name, show)		(cam_ta_accum_item_begin(name, show, __FILE__, __LINE__))
#define CAM_TA_ACUM_ITEM_END(name, show)			(cam_ta_accum_item_end(name, show, __FILE__, __LINE__))
#define CAM_TA_ACUM_ITEM_SHOW_RESULT()			(cam_ta_accum_show_result(CAM_TA_SHOW_STDOUT))
#define CAM_TA_ACUM_ITEM_SHOW_RESULT_TO(x)		(cam_ta_accum_show_result(x))

#define __cam_ta__(name, x) \
CAM_TA_ACUM_ITEM_BEGIN(name, 0); \
x \
CAM_TA_ACUM_ITEM_END(name, 0);

#define __cam_tafmt__(fmt, args...) 			(cam_ta_fmt(fmt, ##args))

#else

#define CAM_TA_INIT()
#define CAM_TA_RELEASE()
#define CAM_TA_SET_ENABLE(enable)

#define CAM_TA_ADD_CHECKPOINT(name, show)
#define CAM_TA_SHOW_CHECKPOINTS()
#define CAM_TA_SHOW_DIFF(name1, name2)
#define CAM_TA_GET_NUMOF_CHECKPOINTS()
#define CAM_TA_GET_DIFF(name1, name2)
#define CAM_TA_GET_NAME(idx)

#define CAM_TA_ACUM_ITEM_BEGIN(name, show)
#define CAM_TA_ACUM_ITEM_END(name, show)
#define CAM_TA_ACUM_ITEM_SHOW_RESULT()
#define CAM_TA_ACUM_ITEM_SHOW_RESULT_TO(x)
#define __cam_ta__(name, x) x
#define __cam_tafmt__(fmt, args...)

#endif
#endif
