/*
 * Copyright 2012  Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *	  http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __H_CAM_UI_ROTATE_UTILS_H__
#define __H_CAM_UI_ROTATE_UTILS_H__

#include "cam.h"

struct cam_ui_rotate_obj_params
{
	Evas_Coord x, y;/*start_x, start_y*/
	double degree;

	Evas_Object *obj;
};

/**
 * @brief		set @obj rotate @degree, the @obj left_top coordinate (start_x, start_y)
 * @param[in]	obj	The object to be set
 * @param[in]	start_x 	left_top coordinate x,
 * @param[in]	start_y 	left_top coordinate y,
 * @param[in]	degree 	the rotate angle
 * @return			Operation result
 * @return			void
 */
void cam_ui_rotate_utils_map_rotate(Evas_Object *obj,
						Evas_Coord start_x,
						Evas_Coord start_y,
						double degree);
/**
 * @brief		set @obj rotate from@from_degree to @to_degree, the time is @duration
 * @param[in]	obj	The object to be set
 * @param[in]	from_degree 	start angle
 * @param[in]	to_degree 	end angle
 * @param[in]	duration 	effect duration time
 * @param[in]	cb 		callback function, it will be called in the rotation end
 * @param[in]	data 		@cb user data.
 * @return			Operation result
 * @return			void
 */
void cam_ui_rotate_utils_rotation_effect(Evas_Object *obj,
							float from_degree,
							float to_degree,
							double duration,
							void (*cb) (void *data, Elm_Transit *transit),
							void *data);
/**
 * @brief		set @setting popup rotate,  @degree, the @obj left_top coordinate (start_x, start_y)
 * @param[in]	obj	The object to be set
 * @param[in]	start_x 	left_top coordinate x,
 * @param[in]	start_y 	left_top coordinate y,
 * @param[in]	degree 	the rotate angle
 * @return			Operation result
 * @return			void
 */
void cam_ui_rotate_utils_map_setting_popup_rotate(Evas_Object *obj,
									Evas_Coord start_x,
									Evas_Coord start_y,
									double degree);
/**
 * @brief		@data appdata, rotate the camera ui icons
 * @param[in]	data	appdata
 * @param[in]	duration 	effect duration time
 * @return			Operation result
 * @return			void
 */
gboolean cam_ui_rotate_utils_rotate_start(void *data, double duration);
/**
 * @brief		set @obj,  self rotate @degree, using evas_map.
 * @param[in]	obj	The object to be set
 * @param[in]	degree 	the rotate angle
 * @return			Operation result
 * @return			void
 */
void cam_ui_rotate_utils_map_self_rotate(Evas_Object *obj,
							double degree);
/**
 * @brief		@data appdata, rotate the camera ui:toolbar shortcust icons
 * @param[in]	data	appdata
 * @param[in]	duration 	effect duration time
 * @return			Operation result
 * @return			void
 */
gboolean cam_ui_rotate_utils_rotate_toolbar_shortcuts(void *data, double duration);

#endif	/* __H_CAM_UI_ROTATE_UTILS_H__ */
//end file
