/*
 * Copyright 2012  Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *	  http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __DEF_CAM_TOOLBAR_EDC_H_
#define __DEF_CAM_TOOLBAR_EDC_H_

#include "cam_property.h"
#include "cam.h"

typedef enum {
	BUTTON_STATE_NORMAL,
	BUTTON_STATE_PRESS,
	BUTTON_STATE_DIM,
} ButtonState;

typedef enum {
	TOOLBAR_ITEM_STATE_NORMAL,
	TOOLBAR_ITEM_STATE_PRESS,
	TOOLBAR_ITEM_STATE_EDIT,
	TOOLBAR_ITEM_STATE_DIM,
	TOOLBAR_ITEM_STATE_INVISIBLE,
} ToolbarItemState;

typedef struct __Shortcuts_List_Prop {
	CAM_EDIT_SHORTCUTS_INDEX index;
	char prop_name[16];
} Shortcuts_List_Prop;

int cam_toolbar_create(struct appdata *ad);
void cam_toolbar_destroy(struct appdata *ad);
void cam_toolbar_update(struct appdata *ad);
int cam_toolbar_rotate(struct appdata *ad);
int show_toolbar_edje(struct appdata *ad);
int hide_toolbar_edje(struct appdata *ad);

gboolean toolbar_update_quickview_thumbnail(struct appdata *ad);
/**
 * @brief		update thumbnail
 * @param[in]	data	appdata
 * @return			Operation result
 * @return			gboolean
 */
gboolean toolbar_update_quickview_thumbnail_no_animation(struct appdata *ad);

#ifdef ENABLE_CAPTURE_ANIMATION
int toolbar_update_quickview_thumbnail_by_screennail(struct appdata *ad);
#endif

int cam_toolbar_setting_popup_create(struct appdata *ad);
void cam_toolbar_setting_popup_update(struct appdata *ad);
void cam_toolbar_setting_popup_destroy(struct appdata *ad);

Eina_Bool cam_animation_effect(void *data, char *type, Evas_Object *obj);
Eina_Bool cam_icon_animation_effect(void *data);
int toolbar_shot_guide_popup_create(struct appdata *ad, int shot_mode);
int toolbar_shot_guide_popup_destory(struct appdata *ad);
int toolbar_shot_guide_popup_move();

Eina_Bool cam_show_setting_menu(void *data);
Eina_Bool cam_show_setting_menu_option_popup(void *data);
gboolean cam_check_timer_is_running(void *data);
int cam_guideline_create(struct appdata *ad);
void settings_guideline_refresh(struct appdata *ad);
void toolbar_destroy_shortcuts_popup(struct appdata *ad);
void cam_toolbar_shutter_button_cb(void *data, Evas_Object *o, const char *emission, const char *source);
void cam_toolbar_recording_button_cb(void *data, Evas_Object *o, const char *emission, const char *source);
void cam_toolbar_recording_stop_button_cb(void *data, Evas_Object *o, const char *emission, const char *source);


/**
 * @brief			create tip popup
 * @param[in]	ad	cam appdata handle
 * @param[in]	ad	tip popup type
 * @return		Operation result
 * @return		void
 */
void cam_tip_popup_create(struct appdata *ad, const CamTipPopupType type);

/**
 * @brief			destroy tip popup
 * @param[in]	ad	cam appdata handle
 * @return		Operation result
 * @return		void
 */
void cam_tip_popup_destroy(struct appdata *ad);

/**
 * @brief			rotate tip popup
 * @param[in]	ad	cam appdata handle
 * @return		Operation result
 * @return		void
 */
void cam_tip_popup_rotate(struct appdata *ad);

/**
 * @brief				set show state of caf button
 * @param[in]	ad		cam appdata handle
 * @param[in]	show	caf button show state
 * @return			Operation result
 * @return			void
 */
void cam_toolbar_show_cafbutton(struct appdata *ad, gboolean show);
void cam_toolbar_update_shutter_button(struct appdata *ad, ToolbarItemState state);

#endif	/* __DEF_CAM_TOOLBAR_EDC_H_ */

