/*
 * Copyright 2012  Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *	  http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include <X11/Xlib.h>
#include <X11/keysymdef.h>
#include <sys/wait.h>
#include <pthread.h>
#include <unistd.h>
#include <aul.h>
#include <power.h>
#include <syspopup_caller.h>
#include <ui-gadget.h>
#include <ui-gadget-module.h>

#include "cam.h"
#include "cam_app.h"
#include "edc_string.h"
#include "cam_sound.h"
#include "cam_continuous_shot.h"
#include "cam_file.h"
#include "cam_ta.h"
#include "cam_error.h"
#include "cam_config.h"
#include "cam_mm.h"
#include "cam_rec.h"
#include "cam_lbs.h"
#include "cam_popup.h"

#include "cam_common_edc_callback.h"
#include "cam_indicator_edc_callback.h"
#include "cam_recording_edc_callback.h"
#include "cam_toolbar_edc_callback.h"
#include "cam_zoom_edc_callback.h"
#include "cam_ev_edc_callback.h"
#include "camera_utils.h"

#include "cam_face_detection_focus.h"
#include "cam_ui_effect_utils.h"
#include "cam_ui_rotate_utils.h"

#include "cam_menu_composer.h"
#include "cam_device_capacity.h"

#ifdef ENABLE_CAPTURE_ANIMATION
#include "cam_animation.h"
#endif
#define GPS_TIME_OUT 220
#define ZSL_MAX_REL (1280*720)	/* 1m wide */
#define FOCUS_FOCUSED_TIME_OUT 2
#define THUMBNAIL_UPDATE_WAIT_TIME (100*1000)


/* 5m ZSL TEST*/
/* #define ZSL_5M_TEST (2560*1920) */

#define NEW_NOTI_API


static CamAppData *cam_handle = NULL;
static struct appdata *app_handle = NULL;

/* static Ecore_Idler *spy_rotation_idler=NULL; */

#define TEMP_SAVE_PATH "/tmp/temp_image.jpg"	/* not used maybe... */
#define SELF_SHOT_TEMP_SAVE_PATH "/tmp/self_temp_shot.jpg"

#define ZOOM_LONG_PRESS_INTERVAL 0.05	/* sec */

#define INAGE_FILE_NAME			"IMAGE"
#define VIDEO_FILE_NAME			"VIDEO"
#define TEMP_FILE_NAME				".camera_result"
#define IMAGE_FILE_EXTENSION		".jpg"
#define VIDEO_FILE_EXTENSION_3GP	".3gp"
#define VIDEO_FILE_EXTENSION_MP4	".mp4"

#define SHUTTER_W_RATIO	0.1
#define SHUTTER_H_RATIO	0.34
#define SCREEN_RATIO 1.0
/* #define CAMAPP_SIG_HANDLING */

/* #define ENABLE_CHECK_CAM_STATUS       //provent camera hang,  */

#ifdef ENABLE_CHECK_CAM_STATUS
#define CAM_CHECK_STATUS_INTERVAL_TIME 10
#ifndef CAMAPP_SIG_HANDLING
#define CAMAPP_SIG_HANDLING
#endif
#endif


static int cam_app_start_rotate(struct appdata *ad, bool bInitial);

#ifdef ENABLE_CHECK_CAM_STATUS
static void cam_app_check_status();
#endif

static gboolean cam_power_key_press(void *data);
static void cam_app_update_gps_level(void *data, int gps_level);
static gboolean cam_app_return_ext_app(void *data, const char *r_file_path);

/* vconf changed cb */
static void cam_app_battery_update_cb(keynode_t *key, void *data);
static void cam_app_battery_status_cb(keynode_t *key, void *data);
static void cam_mmc_state_change_cb(keynode_t *key, void *data);
static void cam_torchlight_update_cb(keynode_t *key, void *data);

void cam_app_preview_start_coordinate(CamVideoRectangle src,
				      CamVideoRectangle dst,
				      CamVideoRectangle *result);
void cam_app_timeout_notice_response_cb(void *data, Evas_Object *obj, void *event_info);
static void cam_app_capture_error_popup_response_cb(void *data, Evas_Object *obj, void *event_info);
Eina_Bool cam_app_launch_after_preview_began(void *data);

static Eina_Bool cam_app_gps_timer_cb(void *data);
static void cam_app_timer_update_count(void *data);
static Eina_Bool __focus_guide_destroy(void *data);
static void __cam_capture_cb(camera_image_data_s* image,
							camera_image_data_s* postview, camera_image_data_s* thumbnail,void *user_data);
static Eina_Bool __cam_ug_destroy(void *data);
static Eina_Bool __cam_app_display_error_popup_idler(void *data);
static Eina_Bool __cam_continuous_af_timer_cb(void *data);


/* video streamming */
static gboolean video_stream_skip_flag = false;

/* thumbnail image check count */
static int g_thumbnail_image_check_count = 0;

/*popup */
gboolean g_blocking_popup = false;

void cam_app_set_blocking_popup()
{
	g_blocking_popup = true;
}

void cam_app_free_blocking_popup()
{
	g_blocking_popup = false;
}

gboolean cam_app_check_blocking_popup()
{
	return !g_blocking_popup;
}

struct noti_callback {
	char *setting_key;
	void (*noti_func) (keynode_t *, void *);
};

#define CAMERA_NOTI_MAX		5
struct noti_callback notis[CAMERA_NOTI_MAX] = {
	{VCONFKEY_SYSMAN_BATTERY_CAPACITY, *cam_app_battery_update_cb},
	{VCONFKEY_SYSMAN_BATTERY_CHARGE_NOW, *cam_app_battery_update_cb},
	{VCONFKEY_SYSMAN_BATTERY_STATUS_LOW, *cam_app_battery_status_cb},
	{VCONFKEY_SYSMAN_MMC_STATUS, *cam_mmc_state_change_cb},
	{VCONFKEY_SETAPPL_ACCESSIBILITY_TORCH_LIGHT, *cam_torchlight_update_cb}
};

#ifdef CAMAPP_SIG_HANDLING
#include <signal.h>
static struct sigaction cam_app_act;
static struct sigaction cam_app_act_old;

static void cam_app_register_sigsegv(void);
static void cam_app_sigsegv_handler(int signal_no, siginfo_t *info,
				    void *context);
#endif

static void cam_app_pipe_handler(void *data, void *buffer, unsigned int nbyte);
static int cam_app_camera_state_manager(int previous, int current, gboolean by_asm);
static int cam_app_recorder_state_manager(int previous, int current, gboolean by_asm);

static void cam_app_close_ug(void *data);
Eina_Bool __ug_destory_postprocessing(void *data);

static Eina_Bool cam_app_timeout_checker_cb(void *data);

gdouble _get_current_time(void)
{
	struct timeval tv;
	gettimeofday(&tv, NULL);
	return (gdouble) tv.tv_sec + (gdouble) tv.tv_usec / 1E6;
}

void cam_app_popup_response_cb(void *data, Evas_Object *obj, void *event_info)
{
	if (obj) {
		evas_object_del(obj);
		obj = NULL;
	}
}

void cam_app_gps_popup_response_ok_cb(void *data, Evas_Object *obj, void *event_info)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	cam_ret_if(obj == NULL);

	DEBUG_TRACE("show location ug");

	if (ad->confirm_popup) {
		evas_object_del(ad->confirm_popup);
		ad->confirm_popup = NULL;
	}

	if (!cam_app_run_location_ug(data)) {
		DEBUG_TRACE("cam_app_run_location_ug() fail");
		GValue b_value = { 0, };
		g_value_init(&b_value, G_TYPE_BOOLEAN);
		g_value_set_boolean(&b_value, FALSE);
		cam_handle_value_set(ad, PROP_GPS, &b_value);

		cam_app_notice_popup(data, ("Location Setting launch fail"),
						     cam_app_popup_response_cb);
	}

}

void cam_app_gps_popup_response_cancel_cb(void *data, Evas_Object *obj, void *event_info)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	cam_ret_if(obj == NULL);
	if (!cam_app_lbs_stop(ad))
			DEBUG_TRACE("cam_app_lbs_stop failed");
	if (ad->confirm_popup) {
		evas_object_del(ad->confirm_popup);
		ad->confirm_popup = NULL;
	}
}

static Eina_Bool cam_delay_popup(void *data)
{

	cam_app_notice_popup(data, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA_DURING_CALL"),
			     cam_app_timeout_notice_response_cb);
	return ECORE_CALLBACK_CANCEL;

}
static void cam_add_longpress_key_timer(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	if (!ad->longpress_timer) {
		ad->longpress_timer = ecore_timer_add(0.5, cam_volume_key_press, ad);
	}
}

static void cam_del_longpress_key_timer(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	if (ad->longpress_timer) {
		ecore_timer_del(ad->longpress_timer);
		ad->longpress_timer = 0;
	}
}

#ifdef EFL_TEMP_CODE
void cam_win_transparent_set(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_ret_if(ad == NULL);

	Evas *evas;
	Evas_Object *rect;
	evas = evas_object_evas_get(ad->win_main);
	rect = evas_object_rectangle_add(evas);
	evas_object_color_set(rect, 0, 0, 0, 0);
	evas_object_render_op_set(rect, EVAS_RENDER_COPY);
	evas_object_size_hint_weight_set(rect, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
 	evas_object_show(rect);
	elm_object_part_content_set(ad->ug_base, "transparent_layout", rect);
}
#endif

void cam_set_orient_value(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp_handle is NULL");

	int orient_value = 0;
	gboolean save_as_flip = FALSE;

	if (cam_is_enabled_menu(ad, CAM_MENU_SAVE_AS_FLIP) && camapp->save_as_flip == TRUE)
		save_as_flip = TRUE;

	switch (ad->rot_current) {
	case APP_DEVICE_ORIENTATION_0:
		if (save_as_flip) {
			if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
				orient_value = 7;
			} else {
				if (camapp->self_portrait == TRUE)
					orient_value = 6;
				else
					orient_value = 8;
			}
		} else {
			if (camapp->self_portrait == TRUE)
				orient_value = 8;
			else
				orient_value = 6;
		}
		break;
	case APP_DEVICE_ORIENTATION_180:
		if (save_as_flip) {
			if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
				orient_value = 5;
			} else {
				if (camapp->self_portrait == TRUE)
					orient_value = 8;
				else
					orient_value = 6;
			}
		} else {
			if (camapp->self_portrait == TRUE)
				orient_value = 6;
			else
				orient_value = 8;
		}
		break;
	case APP_DEVICE_ORIENTATION_90:
		if (save_as_flip && camapp->camera_mode == CAM_CAMCORDER_MODE)
			orient_value = 4;
		else
			orient_value = 3;
		break;
	case APP_DEVICE_ORIENTATION_270:
		if (save_as_flip && camapp->camera_mode == CAM_CAMCORDER_MODE)
			orient_value = 2;
		else
			orient_value = 1;
		break;
	default:
		break;
	}

	DEBUG_TRACE("rot_cuttent=%d orient_value=%d\n", ad->rot_current, orient_value);

	if (cam_mm_set_tag_img_orient(orient_value))
		DEBUG_TRACE("set image orient succeed %d", orient_value);
	else
		DEBUG_TRACE("set image orient failed %d", orient_value);
}

int cam_noti_init(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	int i = 0;

	debug_fenter(LOG_UI);

	cam_retvm_if(ad == NULL, EXIT_FAILURE, "appdata is NULL");

	/* setting noti */
	for (i = 0; i < CAMERA_NOTI_MAX; i++) {
		if (0 != vconf_notify_key_changed(notis[i].setting_key, notis[i].noti_func, ad)) {
			cam_critical(LOG_SYS, "vconf_notify_key_changed() failed. count=%d ", i);
		}
	}

	return EXIT_SUCCESS;
}

int cam_noti_deinit(void *data)
{
	int i;
	struct appdata *ad = (struct appdata *)data;

	debug_fenter(LOG_SYS);

	cam_retvm_if(ad == NULL, EXIT_FAILURE, "appdata is NULL");

	for (i = 0; i < CAMERA_NOTI_MAX; i++) {
		vconf_ignore_key_changed(notis[i].setting_key, notis[i].noti_func);
	}

	return EXIT_SUCCESS;
}

void *cam_appdata_get(void)
{
	if (app_handle) {
		return app_handle;
	}
	return NULL;
}

void cam_app_get_win_size(void* data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	ecore_x_window_size_get(ad->main_xid, &(ad->win_height), &(ad->win_width));

	cam_debug(LOG_UI, "main window ----- win_width, win_height: [%d, %d]", ad->win_width, ad->win_height);
}

int cam_appdata_init(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, 0, "appdata is NULL");

	app_handle = ad;

	ad->main_pipe = ecore_pipe_add(cam_app_pipe_handler, ad);
	ad->rot_current = app_get_device_orientation();
	ad->rot_previous = ad->rot_current;

	cam_app_get_win_size(ad);

	CAM_TA_ACUM_ITEM_BEGIN("      cam_handle_create", 0);
	if (!cam_handle_create(data)) {
		cam_critical(LOG_CAM, "cam_handle_create failed");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("      cam_handle_create", 0);

	ad->last_camera_zoom_mode = 1;

	return 1;
}

int cam_appdata_fini(void *data)
{
	struct appdata *ad = (struct appdata *)data;

	cam_retvm_if(ad == NULL, 0, "appdata is NULL");

	cam_layout_del_all(ad);

	if (ad->service_handle) {
		service_destroy(ad->service_handle);
		ad->service_handle = NULL;
	}
	if (ad->imageviewer_service) {
		service_destroy(ad->imageviewer_service);
		ad->imageviewer_service = NULL;
	}
	if (ad->key_down) {
		ecore_event_handler_del(ad->key_down);
		ad->key_down = NULL;
	}
	if (ad->key_up) {
		ecore_event_handler_del(ad->key_up);
		ad->key_up = NULL;
	}
	if (ad->mouse_up) {
		ecore_event_handler_del(ad->mouse_up);
		ad->mouse_up = NULL;
	}
	if (ad->mouse_down) {
		ecore_event_handler_del(ad->mouse_down);
		ad->mouse_down = NULL;
	}
	/* Remove Idle handler of capture callback. wh01.cho@samsung.com. 2010-12-15. */
	if (ad->capture_cb_list) {
		cam_utils_remove_idler_all(ad);
	}

	REMOVE_IDLER(ad->recording_commit);
	REMOVE_IDLER(ad->still_captured_idle);
	REMOVE_IDLER(ad->capture_idle);
	REMOVE_IDLER(ad->auto_shot_idle);
	REMOVE_IDLER(ad->update_thumbnail_idler);

	REMOVE_TIMER(ad->rec_icon_updater);
	REMOVE_TIMER(ad->rec_time_updater);
	REMOVE_TIMER(ad->rec_pause_timer);
	REMOVE_TIMER(ad->check_af_timer);
	REMOVE_TIMER(ad->continuous_shot_timer);
	REMOVE_TIMER(ad->shutter_long_tap_timer);
	REMOVE_TIMER(ad->timeout_checker);
	REMOVE_TIMER(ad->setting_toolbar_hide_timer);
	REMOVE_TIMER(ad->gps_animation_timer);
	REMOVE_TIMER(ad->battery_animation_timer);
	REMOVE_TIMER(ad->continuous_af_timer);
	REMOVE_TIMER(ad->timer_timer);
	REMOVE_TIMER(ad->longpress_timer);
	REMOVE_TIMER(ad->focus_guide_hide_timer);

	if( ad->setting_menu_composer != NULL){
		cam_compose_free(ad->setting_menu_composer);
		ad->setting_menu_composer = NULL;
	}
	if( ad->sub_menu_composer != NULL){
		cam_compose_free(ad->sub_menu_composer);
		ad->sub_menu_composer = NULL;
	}
	if (ad->camapp_handle) {
		cam_handle_free(ad);
	}
	if (ad->exe_args) {
		if (ad->exe_args->caller) {
			free(ad->exe_args->caller);
			ad->exe_args->caller = NULL;
		}
		free(ad->exe_args);
		ad->exe_args = NULL;
	}

	if (ad->file_reg_thread) {
		pthread_join(ad->file_reg_thread, NULL);
	}

	if (ad->file_reg_queue) {
		while (!g_queue_is_empty(ad->file_reg_queue)) {
			char *filename = NULL;
			filename = g_queue_pop_head(ad->file_reg_queue);

			cam_critical(LOG_FILE, "[%s] didn't processed",
				     filename);

			if (!strcmp(REG_THREAD_EXIT, filename)) {
				free(filename);
			} else {
				__cam_single_shot_reg_file(filename);
				free(filename);
				filename = NULL;
				cam_debug(LOG_FILE, " register done.");
			}
		}
		g_queue_free(ad->file_reg_queue);
		ad->file_reg_queue = NULL;
	}

	/*  disconnect media content */
	CAM_TA_ACUM_ITEM_BEGIN("    media_content_disconnect", 0);

	if(media_content_disconnect() == MEDIA_CONTENT_ERROR_NONE) {
		DEBUG_TRACE("dis connection is success");
	} else {
		cam_critical(LOG_SYS, " media_content_disconnect failed");
	}

	CAM_TA_ACUM_ITEM_END("	  media_content_disconnect", 0);

	cam_popup_delete(ad);

	if (ad->main_pipe) {
		ecore_pipe_del(ad->main_pipe);
		ad->main_pipe = NULL;
	}
	/* init global handle */
	app_handle = NULL;

	return 1;
}

CamAppData *cam_handle_get(void)
{
	if (cam_handle) {
		return cam_handle;
	}
	return NULL;
}

gboolean cam_app_init(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	GError *error = NULL;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	cam_face_detection_focus_init();

	CAM_TA_ACUM_ITEM_BEGIN("    cam_appdata_init", 0);
	if (!cam_appdata_init(ad)) {
		cam_critical(LOG_CAM, "cam_appdata_init failed");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("    cam_appdata_init", 0);

	cam_retvm_if(ad->camapp_handle == NULL, FALSE, "camapp_handle is NULL");

	CAM_TA_ACUM_ITEM_BEGIN("    cam_config_init", 0);
	if (!cam_config_init(&error)) {
		cam_critical(LOG_SYS, "cam_config_init failed");
		if (error != NULL) {
			cam_critical(LOG_SYS, "cam_config_init error [%s]",
				     error->message);
			g_error_free(error);
			error = NULL;
		}
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("    cam_config_init", 0);

	CAM_TA_ACUM_ITEM_BEGIN("    cam_noti_init", 0);
	if (EXIT_FAILURE == cam_noti_init(ad)) {
		cam_critical(LOG_CAM, "cam_noti_init failed");
	}
	CAM_TA_ACUM_ITEM_END("    cam_noti_init", 0);

	CAM_TA_ACUM_ITEM_BEGIN("    cam_file_init", 0);
	if (!cam_file_init(&error)) {
		cam_critical(LOG_FILE, "cam_file_init failed");
		if (error != NULL) {
			cam_critical(LOG_FILE, "cam_file_init error [%s]",
				     error->message);
			g_error_free(error);
			error = NULL;
		}
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("    cam_file_init", 0);
	CAM_TA_ACUM_ITEM_BEGIN("    cam_sound_init", 0);
	if (!cam_sound_init(&error)) {
		cam_critical(LOG_SND, "cam_sound_init failed");
		if (error != NULL) {
			cam_critical(LOG_SND, "cam_sound_init error [%s]",
				     error->message);
			g_error_free(error);
			error = NULL;
		}
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("    cam_sound_init", 0);
	CAM_TA_ACUM_ITEM_BEGIN("    cam_lbs_init", 0);
	if (!cam_lbs_init()) {
		cam_critical(LOG_FWK, "cam_lbs_init is failed");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("    cam_lbs_init", 0);

	CAM_TA_ACUM_ITEM_BEGIN("    cam_app_create_file_register_thread", 0);
	if (!cam_app_create_file_register_thread(ad)) {
		cam_critical(LOG_SYS,
			     " cam_app_create_file_register_thread failed");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("    cam_app_create_file_register_thread", 0);

	CAM_TA_ACUM_ITEM_BEGIN("    cam_continuous_shot_create_file_save_thread", 0);
	if (!cam_continuous_shot_create_file_save_thread(ad)) {
		cam_critical(LOG_SYS,
			     " cam_continuous_shot_create_file_save_thread failed");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("    cam_continuous_shot_create_file_save_thread", 0);

#ifdef CAMAPP_SIG_HANDLING
	/* register singal handler */
	CAM_TA_ACUM_ITEM_BEGIN("    cam_app_create_file_register_thread", 0);
	cam_app_register_sigsegv();
	CAM_TA_ACUM_ITEM_BEGIN("    cam_app_create_file_register_thread", 0);
#endif

	if(media_content_connect() == MEDIA_CONTENT_ERROR_NONE) {
		DEBUG_TRACE("connection is success");
	} else {
		cam_critical(LOG_SYS, " media_content_connect failed");
		return FALSE;
	}
	if (error != NULL) {
		g_error_free(error);
		error = NULL;
	}
	return TRUE;
}

gboolean cam_app_start(void *data)
{
	CAM_TA_ACUM_ITEM_BEGIN("#########cam_app_start", 0);

	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	debug_fenter(LOG_CAM);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	/* init gps value */
	camapp->gps_level = CAM_LBS_STATE_DISABLE;
	camapp->gps = FALSE;
	camapp->need_gps_on = FALSE;

	/*init guideline value*/
	camapp->guideline = FALSE;

	CAM_TA_ACUM_ITEM_BEGIN("    cam_callback_init", 0);
	if (!cam_callback_init(ad)) {
		cam_critical(LOG_CAM, "cam_init_mm_callback failed");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("    cam_callback_init", 0);

	CAM_TA_ACUM_ITEM_BEGIN("      cam_app_init_attribute", 0);
	if (!cam_app_init_attribute(ad, camapp->camera_mode)) {
		cam_critical(LOG_MM, "cam_app_init_attribute failed");
	}
	CAM_TA_ACUM_ITEM_END("      cam_app_init_attribute", 0);

	CAM_TA_ACUM_ITEM_BEGIN("    cam_app_preview_start", 0);

	cam_continuous_af_start(ad);
	if (!cam_app_preview_start(ad)) {
		cam_critical(LOG_MM, "cam_app_preview_start failed");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("    cam_app_preview_start", 0);
	cam_mm_set_mdnie_mode(TRUE);


	if(!cam_key_grab_init(ad))
		DEBUG_TRACE("cam_key_grab_init fail");
	cam_app_key_event_init(ad);
	cam_app_timeout_checker_init(ad);

#ifdef ENABLE_CHECK_CAM_STATUS
	alarm(CAM_CHECK_STATUS_INTERVAL_TIME);	/* start alarm */
#endif
	CAM_TA_ACUM_ITEM_END("#########cam_app_start", 0);

	ad->displayed_setting_popup = FALSE;

	return TRUE;
}

gboolean cam_app_pause(void *data)
{
	DEBUG_TRACE("#############cam_app_pause - START #############\n");
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	int mm_state = 0;
	mm_state = cam_mm_get_state();

	cam_mm_set_display_visible(FALSE);

	if (ad->launching_mode == CAM_LAUNCHING_MODE_EXTERNAL) {
		if ((ad->exe_args->caller) && (strcmp(ad->exe_args->caller, "contacts") == 0)) {
			DEBUG_TRACE(" contact is paused ");
			service_h reply;
			service_create(&reply);
			service_add_extra_data(reply, "camera_end", "1");
			service_reply_to_launch_request(reply, ad->service_handle, SERVICE_RESULT_CANCELED);
			service_destroy(reply);
		}
	}

	if ((mm_state == RECORDER_STATE_RECORDING
	    || mm_state == RECORDER_STATE_PAUSED)
	    &&(camapp->camera_mode == CAM_CAMCORDER_MODE)) {
		int shutter_sound_state = 0;
		/* get current sound */
		cam_mm_get_shutter_sound(&shutter_sound_state);
		/* disable shutter sound */
		cam_mm_set_shutter_sound(FALSE);
		/*stop recording */
		cam_video_record_stop(ad);
		/*restore shutter sound */
		cam_mm_set_shutter_sound(shutter_sound_state);
	}

	cam_app_stop_capture(ad);

	if(camapp->af_mode == CAM_FOCUS_FACE){
		cam_face_detection_reset();
	}

	if (ad->timer_activated)
		cam_app_cancel_timer(ad);

	CAM_TA_ACUM_ITEM_BEGIN("    cam_app_preview_stop", 0);

	if (camapp->camera_mode == CAM_CAMERA_MODE) {
		while (cam_mm_get_cam_state() == CAMERA_STATE_CAPTURING) {
			cam_critical(LOG_CAM, "state is capturing");
		}
		cam_app_preview_start(ad);
	}

	cam_mm_set_mdnie_mode(FALSE);

	if (camapp->outdoor_visibility)
		cam_mm_set_outdoor_visibility(FALSE);

	if (!cam_app_preview_stop()) {
		cam_critical(LOG_MM, "cam_app_preview_stop fail");
	}
	CAM_TA_ACUM_ITEM_END("    cam_app_preview_stop", 0);

	if (EXIT_FAILURE == cam_noti_deinit(ad))
		cam_critical(LOG_UI, "cam_noti_deinit failed");

	if(!cam_app_key_event_deinit(ad))
		cam_critical(LOG_UI, "cam_app_key_event_deinit failed");

	if(!cam_key_grab_deinit(ad))
		cam_critical(LOG_UI, "cam_key_grab_deinit failed");

	if (camapp->gps == TRUE) {
		int gps_level =CAM_LBS_STATE_DISABLE;
		gps_level = cam_lbs_get_state();
		if (gps_level >=CAM_LBS_STATE_SERVICE_ENABLE)
			camapp->need_gps_on= TRUE;
		if (ad->gps_animation_timer)
			REMOVE_TIMER(ad->gps_animation_timer);
		if (cam_app_lbs_stop(ad))
		 	DEBUG_TRACE("The LBS failed to stop");
	}

	cam_app_timeout_checker_remove();
	DEBUG_TRACE("#############cam_app_pause - END #############\n");
	return TRUE;
}

gboolean cam_app_resume(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	int cam_state = -1;
	debug_fenter(LOG_CAM);

	if (!cam_condition_check_to_start_camera(ad)) {
		cam_critical(LOG_CAM, "cannot start camera");
		return ECORE_CALLBACK_CANCEL;
	}

	if(ad->launching_mode == CAM_LAUNCHING_MODE_NORMAL) {
		if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
			GValue value = {0, };
			CAM_GVALUE_SET_INT(value, CAM_CAMERA_MODE);
			if (!cam_handle_value_set(ad, PROP_MODE, &value)) {
				return ECORE_CALLBACK_CANCEL;
			}
		}
	}

	indicator_update_storage(ad);
	cam_app_timeout_checker_init(ad);

	if (ad->imageviewer_ug == NULL) { /* home key destory imageviewer_ug */
		cam_state = cam_mm_get_state();
		cam_app_get_preview_offset_coordinate(ad);

		cam_continuous_af_start((void*)ad);
		CAM_TA_ACUM_ITEM_BEGIN("    cam_app_preview_start", 0);

		if (ad->torchlight_on && camapp->flash != CAM_FLASH_OFF)
			cam_mm_set_flash(CAM_FLASH_OFF);

		/* reset zoom */
		cam_mm_set_zoom(camapp->zoom_min);
		camapp->zoom_mode  = camapp->zoom_min;

		if (!cam_app_preview_start(ad)) {
			if (ad->fw_error_type == CAMERA_ERROR_SOUND_POLICY || ad->fw_error_type == RECORDER_ERROR_SOUND_POLICY) {
				DEBUG_TRACE(" MM CAMCARORDER ERROR\n");
				ecore_timer_add(0.01, cam_delay_popup, (void *)ad);
				return TRUE;
			}

			cam_critical(LOG_MM, "cam_app_preview_start failed");
			cam_app_notice_popup(ad,
			 "PREVIEW START FAILED !!",
			 cam_app_timeout_notice_response_cb);
			return FALSE;
		}
		CAM_TA_ACUM_ITEM_END("    cam_app_preview_start", 0);
		cam_mm_set_mdnie_mode(TRUE);

		if (camapp->outdoor_visibility)
			cam_mm_set_outdoor_visibility(TRUE);

		if (camapp->camera_mode == CAM_CAMERA_MODE) {
			if(camapp->af_mode == CAM_FOCUS_FACE){
				/*start face detection*/
				if (cam_mm_is_supported_face_detection()) {
					cam_mm_start_camera_face_detection(camapp->face_detect_cb, (void *)ad);
					if (!cam_mm_set_preview_cb(cam_face_detection_focus_start_stream, (void*)ad)) {
						DEBUG_TRACE("preview callback set error");
					}
					cam_app_run_video_stream();
				} else {
					DEBUG_TRACE("not support face detect mode");
				}
			}

		}
		CAM_TA_ACUM_ITEM_BEGIN("    cam_noti_init", 0);
		if (EXIT_FAILURE == cam_noti_init(ad))
			cam_critical(LOG_CAM, "cam_noti_init failed");
		CAM_TA_ACUM_ITEM_END("    cam_noti_init", 0);

		CAM_TA_ACUM_ITEM_BEGIN("    cam_key_grab_init", 0);
		if (!cam_key_grab_init(ad))
			DEBUG_TRACE("cam_key_grab_init fail");
		CAM_TA_ACUM_ITEM_END("    cam_key_grab_init", 0);

		cam_app_key_event_init(ad);
		cam_app_update_quickview_icon(ad);
		cam_toolbar_update(ad);
	}

	if (camapp->need_gps_on== TRUE) {
		camapp->need_gps_popup = FALSE;
		if (!cam_app_lbs_start(ad)) {
			if (!cam_app_lbs_stop(ad))
				DEBUG_TRACE("The LBS failed to stop");
		}
	}

#ifdef ENABLE_CHECK_CAM_STATUS
	alarm(CAM_CHECK_STATUS_INTERVAL_TIME);	/* start alarm */
#endif

	return TRUE;
}

gboolean cam_app_stop(void *data)
{
	debug_fenter(LOG_CAM);
	char *filename = NULL;

	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	CAM_TA_ACUM_ITEM_BEGIN("  cam_app_stop", 0);

	/* return aul result path */
	if (ad->launching_mode == CAM_LAUNCHING_MODE_EXTERNAL) {
		if (ad->exe_args == NULL) {
			DEBUG_TRACE("ad->exe_args is NULL");
			return FALSE;
		}
		if (ad->path_in_return) {
			if (((ad->exe_args->caller) && (strcmp(ad->exe_args->caller, "contacts") == 0))
					|| ((ad->exe_args->caller) && (strcmp(ad->exe_args->caller, "ug-setting-call-efl") == 0))) {
				DEBUG_TRACE("contacts -not need sending result");
			} else {
				if (ad->ug_state != CAM_UG_PAUSE_STATE) {
					if (camapp->filename != NULL) {
						filename = strdup(camapp->filename);
						cam_app_return_ext_app(ad, filename);
					}
				}
			}
		} else {
			cam_app_return_ext_app(ad, filename);
		}
	}

	if (cam_mm_is_created()) {
		/*TODO: new logic will be add for save file while camera process is killed*/
		/*stop*/
		int state = 0;
		state = cam_mm_get_state();
		if (ad->camapp_handle) {
			if (ad->camapp_handle->camera_mode == CAM_CAMCORDER_MODE) {
				switch (state) {
				case RECORDER_STATE_NONE:
				case RECORDER_STATE_CREATED:
					break;
				case RECORDER_STATE_READY:
					break;
				case RECORDER_STATE_RECORDING:
				case RECORDER_STATE_PAUSED:
					cam_video_record_stop(ad);
					break;
				default:
					/*g_assert_not_reached();*/
					break;
				}
			}
		}

		cam_mm_set_mdnie_mode(FALSE);

		if (camapp->outdoor_visibility)
			cam_mm_set_outdoor_visibility(FALSE);

		CAM_TA_ACUM_ITEM_BEGIN("    cam_app_preview_stop", 0);
		if (!cam_app_preview_stop()) {
			cam_critical(LOG_MM, "cam_app_preview_stop failed");
		}
		CAM_TA_ACUM_ITEM_END("    cam_app_preview_stop", 0);

		CAM_TA_ACUM_ITEM_BEGIN("    cam_mm_destory", 0);
		if (!cam_mm_destory()) {
			cam_critical(LOG_MM, "cam_mm_destory failed");
		}
		CAM_TA_ACUM_ITEM_END("    cam_mm_destory", 0);
	}

	if (ad->imageviewer_ug || ad->location_ug) {
		cam_app_close_ug(ad);
	}

	cam_popup_remove_all();

	/* Idler of capture callback management. wh01.cho@samsung.com. 2010-12-15. */
	cam_utils_remove_idler_all(ad);

	if (EXIT_FAILURE == cam_noti_deinit(ad))
		cam_critical(LOG_UI, "cam_noti_deinit failed");

	if(!cam_app_key_event_deinit(ad))
		cam_critical(LOG_UI, "cam_app_key_event_deinit failed");

	if(!cam_key_grab_deinit(ad))
		cam_critical(LOG_UI, "cam_key_grab_deinit failed");

	/* crear data & engine */
	CAM_TA_ACUM_ITEM_BEGIN("    cam_app_clear_engine_data", 0);
	cam_app_clear_engine_data(data, true);
	CAM_TA_ACUM_ITEM_END("    cam_app_clear_engine_data", 0);

	CAM_TA_ACUM_ITEM_BEGIN("    cam_file_finalize", 0);
	cam_file_finalize();
	CAM_TA_ACUM_ITEM_END("    cam_file_finalize", 0);

	CAM_TA_ACUM_ITEM_BEGIN("    cam_sound_finalize", 0);
	cam_sound_finalize();
	CAM_TA_ACUM_ITEM_END("    cam_sound_finalize", 0);

	/*  clean config */
	CAM_TA_ACUM_ITEM_BEGIN("    cam_config_finalize", 0);
	cam_config_finalize();
	CAM_TA_ACUM_ITEM_END("    cam_config_finalize", 0);

	/*  finialize gps */
	CAM_TA_ACUM_ITEM_BEGIN("    cam_gps_finialize", 0);
	cam_lbs_finialize();
	CAM_TA_ACUM_ITEM_END("    cam_gps_finialize", 0);

	/*  cam_handle_free(ad); */
	cam_face_detection_focus_finish();
	cam_appdata_fini(ad);

	if (filename != NULL) {
		free(filename);
		filename = NULL;
	}

	CAM_TA_ACUM_ITEM_END("  cam_app_stop", 0);

	return TRUE;
}

gboolean cam_app_preview_start(void *data)
{
	CAM_TA_ACUM_ITEM_BEGIN("----cam_app_preview_start", 0);
	DEBUG_TRACE
	    ("------------------------------START---------------------------------");

	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp is NULL");

	int state = cam_mm_get_state();
	DEBUG_TRACE("state: %d ", state);

	if (((camapp->camera_mode == CAM_CAMERA_MODE) && (state < CAMERA_STATE_NONE))
			|| ((camapp->camera_mode == CAM_CAMCORDER_MODE) && (state < RECORDER_STATE_NONE)))
		return FALSE;

	if (camapp->camera_mode == CAM_CAMERA_MODE) {
		switch(state) {
		case CAMERA_STATE_CREATED:
		case CAMERA_STATE_CAPTURED:
			{
				CAM_TA_ACUM_ITEM_BEGIN("	  cam_mm_preview_start", 0);
				if (!cam_mm_preview_start(camapp->camera_mode)) {
					cam_critical(LOG_MM, "cam_mm_preview_start failed");
					return FALSE;
				}
				CAM_TA_ACUM_ITEM_END("		cam_mm_preview_start", 0);
			}
			break;
		case CAMERA_STATE_CAPTURING:
			{
				if (cam_mm_capture_stop(FALSE, camapp->camera_mode) == FALSE) {
					cam_critical(LOG_MM, "cam_mm_capture_stop failed");
					return FALSE;
				}
			}
			break;
		default:
			break;
		}
	}else if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		switch(state) {
		case RECORDER_STATE_CREATED:
		case RECORDER_STATE_PAUSED:
			{
				if (!cam_mm_preview_start(camapp->camera_mode)) {
					cam_critical(LOG_MM, "cam_mm_preview_start failed");
					return FALSE;
				}
			}
			break;
		default:
			break;

		}
	}

	CAM_TA_ACUM_ITEM_END("----cam_app_preview_start", 0);
	return TRUE;
}

gboolean cam_app_preview_stop(void)
{
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	cam_retvm_if(ad == NULL, FALSE, "ad is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp is NULL");

	if (camapp->touch_af_state == CAM_TOUCH_AF_STATE_DOING
		|| camapp->touch_af_state == CAM_TOUCH_AF_STATE_READY)
		camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;

	if (!cam_mm_preview_stop(camapp->camera_mode)) {
		cam_critical(LOG_MM, "cam_mm_preview_stop failed");
		return FALSE;
	}
	return TRUE;
}

static void cam_app_timer_icon_rotate(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	DEL_EVAS_OBJECT(ad->timer_icon_edje);
	cam_app_timer_update_count(ad);
}

static int cam_app_start_rotate(struct appdata *ad, bool bInitial)
{
	cam_retvm_if(ad == NULL, -1, "appdata is NULL");

	cam_debug(LOG_UI, "rotated : %d, window rotation angle=%d", ad->rot_current);	/*, elm_win_rotation_get(ad->win_main)); */


	int angle = 0;

	switch (ad->rot_current) {
	case APP_DEVICE_ORIENTATION_0:
		ad->camcorder_rotate = CAMERA_ROTATION_90;
		ad->target_direction = CAM_TARGET_DIRECTION_PORTRAIT;
		angle = 0;
		break;

	case APP_DEVICE_ORIENTATION_180:
		ad->camcorder_rotate = CAMERA_ROTATION_270;
		ad->target_direction = CAM_TARGET_DIRECTION_PORTRAIT_INVERSE;
		angle = 180;
		break;

	case APP_DEVICE_ORIENTATION_270:
		ad->camcorder_rotate = CAMERA_ROTATION_NONE;
		ad->target_direction = CAM_TARGET_DIRECTION_LANDSCAPE;
		angle = 270;
		break;

	case APP_DEVICE_ORIENTATION_90:
		ad->camcorder_rotate = CAMERA_ROTATION_180;
		ad->target_direction = CAM_TARGET_DIRECTION_LANDSCAPE_INVERSE;
		angle = 90;
		break;

	default:
		break;
	}
	ad->angle = angle;
	ad->angle_pre = ad->angle;

////////////////////////////////////////////////////////////////////////////
	if (ad->toolbar_edj_file) {
		free(ad->toolbar_edj_file);
		ad->toolbar_edj_file = NULL;
	}

	switch (ad->angle) {
	case 270:
		ad->toolbar_edj_file = strdup(CAM_TOOLBAR_LAYOUT_EDJ_NAME);
		break;
	case 0:
		ad->toolbar_edj_file = strdup(CAM_TOOLBAR_LAYOUT_VERTICAL_EDJ_NAME);
		break;
	case 90:
		ad->toolbar_edj_file = strdup(CAM_TOOLBAR_LAYOUT_INVERSE_EDJ_NAME);
		break;
	case 180:
		ad->toolbar_edj_file = strdup(CAM_TOOLBAR_LAYOUT_VERTICAL_INVERSE_EDJ_NAME);
		break;
	default:
		ad->toolbar_edj_file = strdup(CAM_TOOLBAR_LAYOUT_EDJ_NAME);
		break;

	}

	if(elm_win_rotation_get(ad->win_main) != ad->angle)
		elm_win_rotation_with_resize_set(ad->win_main, ad->angle);

	cam_app_get_preview_offset_coordinate(ad);

	if (!bInitial) {
		if (ad->toolbar_edje)
			cam_toolbar_rotate(ad);

		if (ad->indicator_edje)
			cam_indicator_rotate(ad);

		if (ad->recording_edje)
			cam_recording_rotate(ad);

		if (ad->timer_icon_edje)
			cam_app_timer_icon_rotate(ad);

		if (ad->ev_edje) {
			unload_ev_edje(ad);
			load_ev_edje(ad);
		}

		if (ad->zoom_edje) {
			unload_zoom_edje(ad);
			load_zoom_edje(ad);
		}
		/* guideline */
		if (ad->guideline_edje)
			settings_guideline_refresh(ad);

	}
	return 0;
}

gboolean cam_layout_init(void *data)
{
	DEBUG_TRACE("START");

	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	if (ad->win_main == NULL) {
		cam_critical(LOG_UI, "win_main is NULL");
		return FALSE;
	}
	ad->pinch_edje = NULL;

	cam_app_start_rotate(ad, TRUE);
	DEBUG_TRACE("ad->angle = %d", ad->angle);

	elm_theme_extension_add(NULL, CAM_SETTING_POPUP_STYLE_EDJ_NAME);
	elm_theme_extension_add(NULL, CAM_SETTING_POPUP_STYLE_WITH_RADIO_EDJ_NAME);
	elm_theme_extension_add(NULL, CAM_SLIDER_STYLE_EDJ_NAME);
	elm_theme_extension_add(NULL, CAM_LABEL_STYLE_EDJ_NAME);
	elm_theme_extension_add(NULL, CAM_BUTTON_STYLE_EDJ_NAME);

#ifndef	CAMERA_MACHINE_I686
	define_mouse_callback(ad);
#endif

	CAM_TA_ACUM_ITEM_BEGIN("      load_toolbar_edje", 0);
	if (cam_toolbar_create(ad)) {
		CAM_TA_ACUM_ITEM_END("      load_toolbar_edje", 0);
		cam_critical(LOG_UI, " load_toolbar_edje failed ");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("      load_toolbar_edje", 0);

	CAM_TA_ACUM_ITEM_BEGIN("      cam_indicator_create", 0);
	if (cam_indicator_create(ad)) {
		CAM_TA_ACUM_ITEM_END("      cam_indicator_create", 0);
		cam_critical(LOG_UI, "cam_indicator_create failed ");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("      cam_indicator_create", 0);

	cam_app_focus_guide_create(ad);
	cam_app_update_quickview_icon(ad);
	settings_guideline_refresh(ad);

	/*note: */
	/*reading from ini: whether need show popup tip*/
	gboolean show_popup_tip = FALSE;
	show_popup_tip = cam_config_get_boolean_by_type(CAM_CONFIG_TYPE_SHORTCUTS, PROP_SHOW_POP_TIP, POP_TIP_DEFAULT);
	if (show_popup_tip) {
		cam_tip_popup_create(ad, CAM_TIP_POPUP_BURSTSHOT_HELP);
	}

	if (ad->battery_status == LOW_BATTERY_CRITICAL_STATUS
		|| ad->battery_status == LOW_BATTERY_WARNING_STATUS
		|| ad->is_calling == TRUE ){
		ecore_idler_add(__cam_app_display_error_popup_idler, ad);
	}

	DEBUG_TRACE("END");

	return TRUE;
}

gboolean cam_handle_create(void *data)
{
	CAM_TA_ACUM_ITEM_BEGIN("------cam_handle_create", 0);
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	debug_fenter(LOG_CAM);
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	if (ad->camapp_handle && cam_handle) {
		cam_handle_free(ad);
	}

	camapp = (CamAppData *)malloc(sizeof(CamAppData));
	cam_retv_if(camapp == NULL, FALSE);
	memset(camapp, 0x00, sizeof(CamAppData));

	cam_handle = camapp;
	ad->camapp_handle = camapp;
	CAM_TA_ACUM_ITEM_END("------cam_handle_create", 0);

	return TRUE;
}

gboolean cam_handle_free(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	debug_fenter(LOG_CAM);
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	cam_config_save();

	if (camapp && cam_handle) {
		if (camapp->conti_image) {
			evas_object_del(camapp->conti_image);
			camapp->conti_image = NULL;
		}

		if (camapp->filename) {
			free(camapp->filename);
			camapp->filename = NULL;
		}

		if (camapp->thumbnail_name) {
			free(camapp->thumbnail_name);
			camapp->thumbnail_name = NULL;
		}
		cam_continuous_shot_data_free(ad);
		if (camapp) {
			free(camapp);
			camapp = NULL;
		}

		DEBUG_TRACE();
		ad->camapp_handle = NULL;
		cam_handle = NULL;
	}

	return TRUE;
}

gboolean cam_toolbar_menu_config_init(void *data, int mode) {
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	int i = 0;

#ifdef CAMERA_MACHINE_I686
	for (i = CAM_MENU_BAR_LEFT_1; i < CAM_MENU_BAR_LEFT_MAX_NUM; i++) {
		char buf[16+1] = { '\0', };
		snprintf(buf, 16, "toolbar_%d", i);
		ad->toolbar_menu_arrays[i].menu_type = CAM_MENU_EMPTY;
	}
#else
	for (i = CAM_MENU_BAR_LEFT_1; i < CAM_MENU_BAR_LEFT_MAX_NUM; i++) {
		char buf[16+1] = { '\0', };
		snprintf(buf, 16, "toolbar_%d", i);
		ad->toolbar_menu_arrays[i].menu_type = cam_config_get_int(buf, CAM_MENU_EMPTY);

		if (ad->toolbar_menu_arrays[i].menu_type == CAM_MENU_SELF_PORTRAIT) {
			if (cam_mm_is_support_front_camera() == FALSE)
				ad->toolbar_menu_arrays[i].menu_type = CAM_MENU_EMPTY;
		}
	}
#endif

	return TRUE;
}

gboolean cam_toolbar_menu_config_update(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	int i = 0;
	for (i = CAM_MENU_BAR_LEFT_1; i < CAM_MENU_BAR_LEFT_MAX_NUM; i++) {
		char buf[16+1] = { '\0', };
		snprintf(buf, 16, "toolbar_%d", i);
		int tmp_type = cam_config_get_int(buf, CAM_MENU_EMPTY);
		if (ad->toolbar_menu_arrays[i].menu_type != tmp_type) {
			cam_config_set_int(buf, ad->toolbar_menu_arrays[i].menu_type);
		}
	}
	return TRUE;
}

gboolean cam_handle_init(void *data, int mode)
{
	struct appdata *ad = data;
	CamAppData *camapp = NULL;
	int charging = 0;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	cam_info(LOG_UI, "mode : %d ", mode);
	camapp->camera_mode = mode;
	cam_config_set_int_by_type(CAM_CONFIG_TYPE_COMMON, PROP_MODE_NAME, mode);

	cam_app_set_config_group(camapp->camera_mode);
	/* load init value from ini file */
	/*   camapp->camera_mode = cam_config_get_int(PROP_MODE_NAME, MODE_DEFAULT); */

	vconf_get_int(VCONFKEY_SETAPPL_DEFAULT_MEM_CAMERA_INT, &(camapp->storage));

	camapp->anti_shake = cam_config_get_int(PROP_AHS_NAME, AHS_DEFAULT);

	camapp->self_portrait = FALSE;

	/* use shot mode as default value */
	camapp->recording_mode = RECMODE_DEFAULT;
	camapp->shooting_mode = SHOTMODE_DEFAULT;

	camapp->scene_mode = cam_config_get_int(PROP_SCENE_MODE_NAME, PG_MODE_DEFAULT);
	camapp->iso = cam_config_get_int(PROP_ISO_NAME, ISO_DEFAULT);
	/*camapp->af_mode = cam_config_get_int(PROP_AF_NAME, AF_DEFAULT); */
	camapp->af_mode = AF_DEFAULT;
	/* camapp->white_balance = cam_config_get_int(PROP_WB_NAME, WB_DEFAULT); */
	camapp->white_balance = WB_DEFAULT;

	camapp->flash = cam_config_get_int(PROP_FLASH_NAME, FLASH_DEFAULT);

	/*batterylevel*/
	if (cam_utils_check_battery_warning_low()) {
		camapp->flash = CAM_FLASH_OFF;
	}
	camapp->guideline = cam_config_get_boolean(PROP_GUIDELINE_NAME, GUIDE_LINE_DEFAULT);
	DEBUG_TRACE("camapp->guideline = %d" ,camapp->guideline);
	camapp->effect = EFFECT_DEFAULT;

	camapp->wdr = cam_config_get_int(PROP_WDR_NAME, WDR_DEFAULT);
	camapp->auto_exposure = cam_config_get_int(PROP_METERING_NAME, AE_DEFAULT);

	camapp->photo_resolution = cam_config_get_int(PROP_PHOTO_RESOLUTION_NAME, IMAGE_RESOLUTION_DEFAULT);
	camapp->video_resolution = cam_config_get_int(PROP_VIDEO_RESOLUTION_NAME, REC_RESOLUTION_DEFAULT);

	camapp->auto_contrast = FALSE;
	camapp->image_quality = QUALITY_DEFAULT;
	camapp->video_quality = QUALITY_DEFAULT;
	camapp->audio_recording = AUDIOREC_DEFAULT;
	camapp->review = cam_config_get_boolean(PROP_REVIEW_NAME, FALSE);

	camapp->battery_level = cam_utils_get_battery_level();
	charging = cam_utils_get_charging_status();
	if (charging == 1)
		camapp->battery_charging = charging;
	else
		camapp->battery_charging = 0;

#ifdef USE_CAMERA_APP_SHUTTER_SOUND
	camapp->shutter_sound = SHUTTER_SOUND_DEFAULT;
#endif
	/*sound*/

	cam_mm_set_shutter_sound(SOUND_DEFAULT);
	camapp->shutter_sound = SHUTTER_SOUND_DEFAULT;	/* on */

	/* below item had been saved in ini file */
	camapp->zoom_mode = ZOOM_DEFAULT;
	camapp->image_count = IMAGE_COUNT_DEFAULT;
	camapp->size_limit_type = CAM_MM_SIZE_LIMIT_TYPE_BYTE;
	camapp->size_limit = REC_SIZE_LIMIT_DEFAULT;
	camapp->timer = TIMER_DEFAULT;
	camapp->fps = FPS_DEFAULT;

	camapp->continuous_shot_data = NULL;

	camapp->enable_touch_af = TRUE;

	camapp->outdoor_visibility = FALSE;

	camapp->burst_shot = cam_config_get_boolean(PROP_BURST_SHOT_NAME, BURST_SHOT_DEFAULT);

	camapp->device_type = CAM_DEVICE_MEGA;

	camapp->volume_key = cam_config_get_int(PROP_VOLUME_KEY_NAME, CAM_VOLUME_KEY_ZOOM);

	camapp->save_as_flip = FALSE;

	/*init toolbar menu config */
	cam_toolbar_menu_config_init((void*)ad, mode);

	/* init reserved setting data */
	camapp->reserved_setting_data.front_photo_resolution = cam_config_get_int(PROP_SELF_PHOTO_RESOLUTION_NAME, SELF_IMAGE_RESOLUTION_DEFAULT);
	camapp->reserved_setting_data.front_video_resolution = cam_config_get_int(PROP_SELF_VIDEO_RESOLUTION_NAME, SELF_REC_RESOLUTION_DEFAULT);
	camapp->reserved_setting_data.rear_photo_resolution = cam_config_get_int(PROP_PHOTO_RESOLUTION_NAME, IMAGE_RESOLUTION_DEFAULT);
	camapp->reserved_setting_data.rear_video_resolution = cam_config_get_int(PROP_VIDEO_RESOLUTION_NAME, REC_RESOLUTION_DEFAULT);
	camapp->reserved_setting_data.front_shooting_mode = CAM_SELF_SINGLE_MODE;
	camapp->reserved_setting_data.front_recording_mode = CAM_RECORD_SELF;
	camapp->reserved_setting_data.rear_shooting_mode = SHOTMODE_DEFAULT;
	camapp->reserved_setting_data.rear_recording_mode = RECMODE_DEFAULT;
	camapp->reserved_setting_data.front_effect = EFFECT_DEFAULT;
	camapp->reserved_setting_data.rear_effect = EFFECT_DEFAULT;
	camapp->reserved_setting_data.front_wb = WB_DEFAULT;
	camapp->reserved_setting_data.rear_wb = WB_DEFAULT;

	return TRUE;
}

gboolean cam_handle_value_set(void *data, int type, const GValue *value)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	cam_debug(LOG_CAM, "type : %d", type);

	switch (type) {
	case PROP_MODE:
		{
			gint current = 0;
			gint tempval = g_value_get_int(value);

			current = camapp->camera_mode;

			//camapp->camera_mode = tempval;
			if (!cam_mode_change(ad, tempval)) {
				cam_critical(LOG_CAM, "MODE CHANGE IS FAILED by MIDDLE WARE");
				camapp->camera_mode = current;
				cam_app_notice_popup(data, "MODE CHANGE FAILED !!", cam_app_timeout_notice_response_cb);
			}
		}
		break;

	case PROP_SELF_PORTRAIT:
		{
			GValue set_value = { 0 };
			gboolean tempval = g_value_get_boolean(value);

			/* stop preview and destory mmfw handle */
			if (!cam_app_preview_stop()) {
				cam_critical(LOG_MM, "cam_app_preview_stop faild");
				return FALSE;
			}

			if (!cam_mm_destory()) {
				cam_critical(LOG_MM, "cam_mm_destory faild");
				return FALSE;
			}

			if (camapp->self_portrait == TRUE) {
				camapp->device_type = CAM_DEVICE_VGA;
			} else {
				camapp->device_type = CAM_DEVICE_MEGA;
			}

			DEBUG_TRACE("device_type = %d", camapp->device_type);

			cam_config_set_boolean(PROP_SELF_PORTRAIT_NAME, tempval);

			if (!cam_mm_create(camapp->device_type, camapp->camera_mode)) {
				cam_critical(LOG_MM, "cam_mm_create failed");
				cam_app_notice_popup(ad, "cam_app_preview_start faild ", cam_app_timeout_notice_response_cb);
				return FALSE;
			}

			ResetCaps();
			define_mouse_callback(ad);

			/* get reserved setting value */
			if (camapp->self_portrait == FALSE) {
				camapp->photo_resolution = camapp->reserved_setting_data.rear_photo_resolution;
				camapp->video_resolution = camapp->reserved_setting_data.rear_video_resolution;
				camapp->shooting_mode = camapp->reserved_setting_data.rear_shooting_mode;
				camapp->recording_mode = camapp->reserved_setting_data.rear_recording_mode;
			} else {
				camapp->photo_resolution = camapp->reserved_setting_data.front_photo_resolution;
				camapp->video_resolution = camapp->reserved_setting_data.front_video_resolution;
				camapp->shooting_mode = camapp->reserved_setting_data.front_shooting_mode;
				camapp->recording_mode = camapp->reserved_setting_data.front_recording_mode;
			}

			/* set shot, rec mode */
			CAM_GVALUE_SET_INT(set_value, camapp->shooting_mode);
			cam_handle_value_set(ad, PROP_SHOT_MODE, &set_value);
			CAM_GVALUE_SET_INT(set_value, camapp->recording_mode);
			cam_handle_value_set(ad, PROP_REC_MODE, &set_value);

			camapp->zoom_mode = ZOOM_DEFAULT;

			/* start preview */
			if (!cam_app_init_attribute(ad, camapp->camera_mode)) {
				cam_critical(LOG_MM, "cam_app_init_attribute failed");
			}

			cam_continuous_af_start(ad);
			if (!cam_app_preview_start(ad)) {
				cam_critical(LOG_MM, "cam_app_preview_start failed");
				cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA"), cam_app_timeout_notice_response_cb);
				return FALSE;
			}

			settings_guideline_refresh(ad);

			if(camapp->af_mode == CAM_FOCUS_FACE){
				/*start face detection*/
				if (cam_mm_is_supported_face_detection()) {
					cam_mm_start_camera_face_detection(camapp->face_detect_cb, (void *)ad);
					if (!cam_mm_set_preview_cb(cam_face_detection_focus_start_stream, (void*)ad)) {
						DEBUG_TRACE("preview callback set error");
					}
					cam_app_run_video_stream();
				} else {
					DEBUG_TRACE("not support face detect mode");
				}
			}
		}
		break;

	case PROP_SHOT_MODE:
		{
			gint tempval = g_value_get_int(value);
			gint cur_mode = camapp->shooting_mode;

			camapp->shooting_mode = tempval;

			if (!cam_shooting_mode_change(ad)) {
				cam_critical(LOG_UI, "shot mode set fail");
				camapp->shooting_mode = cur_mode;
				return FALSE;
			}

			if (camapp->self_portrait == FALSE) {
				camapp->reserved_setting_data.rear_shooting_mode = tempval;
			} else {
				camapp->reserved_setting_data.front_shooting_mode = tempval;
			}

			cam_app_focus_guide_update(ad);
		}
		break;
	case PROP_REC_MODE:
		{
			gint tempval = g_value_get_int(value);
			int video_resolution = 0;
			GValue set_value = { 0, };
			g_value_init(&set_value, G_TYPE_INT);

			camapp->recording_mode = tempval;

			if (camapp->self_portrait == FALSE) {
				camapp->reserved_setting_data.rear_recording_mode = tempval;
			} else {
				camapp->reserved_setting_data.front_recording_mode = tempval;
			}

			if (camapp->recording_mode == CAM_RECORD_NORMAL) {
				video_resolution = cam_config_get_int(PROP_VIDEO_RESOLUTION_NAME, REC_RESOLUTION_DEFAULT);
				g_value_set_int(&set_value, video_resolution);
			} else if (camapp->recording_mode == CAM_RECORD_SLOW || camapp->recording_mode == CAM_RECORD_FAST) {
				g_value_set_int(&set_value, CAM_RESOLUTION_QVGA);
			} else if (camapp->recording_mode == CAM_RECORD_SELF) {
				video_resolution = cam_config_get_int(PROP_SELF_VIDEO_RESOLUTION_NAME, SELF_REC_RESOLUTION_DEFAULT);
				g_value_set_int(&set_value, video_resolution);
			} else if (camapp->recording_mode == CAM_RECORD_MMS || camapp->recording_mode == CAM_RECORD_SELF_MMS) {
				g_value_set_int(&set_value, CAM_RESOLUTION_QCIF);
			}

			cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &set_value);
/*
			if (!cam_recording_mode_change(ad, tempval)) {
				cam_critical(LOG_UI, "rec mode change fail - mode[%d]", tempval);
				return FALSE;
			}
*/
		}
		break;
	case PROP_SCENE_MODE:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_program_mode(tempval)) {
				cam_warning(LOG_UI, "program mode set fail");
				return FALSE;
			}
			camapp->scene_mode = tempval;

			/* set flash */
			int flash = CAM_FLASH_OFF;
			if(camapp->scene_mode == CAM_SCENE_NONE){
				flash = cam_config_get_int(PROP_SCENE_MODE_NAME, PG_MODE_DEFAULT);
			}else if(camapp->scene_mode == CAM_SCENE_CANDLELIGHT){
				flash = CAM_FLASH_ON;
			}else {
				flash = CAM_FLASH_OFF;
			}
			GValue set_value = { 0, };
			g_value_init(&set_value, G_TYPE_INT);
			g_value_set_int(&set_value, flash);
			cam_handle_value_set(ad, PROP_FLASH, &set_value);

		}
		break;
	case PROP_PHOTO_RESOLUTION:
		{
			gint tempval = g_value_get_int(value);

			DEBUG_TRACE("*******************************************************");
			DEBUG_TRACE("value set : PROP_RESOLUTION setting");
			DEBUG_TRACE(" tempval = %d ", tempval);
			DEBUG_TRACE("CAM_RESOLUTION_W = %d ,CAM_RESOLUTION_H=%d ", CAM_RESOLUTION_W(tempval), CAM_RESOLUTION_H(tempval));
			DEBUG_TRACE("*******************************************************");

			if (!cam_app_reset_resolution(ad, CAM_RESOLUTION_W(tempval), CAM_RESOLUTION_H(tempval), FALSE)) {
				cam_warning(LOG_UI, "resolution set fail");
				return FALSE;
			}

			settings_guideline_refresh(ad);

			camapp->photo_resolution = tempval;

			if (camapp->self_portrait == FALSE) {
				camapp->reserved_setting_data.rear_photo_resolution = tempval;
				if (camapp->camera_mode == CAM_CAMERA_MODE) {
					cam_config_set_int(PROP_PHOTO_RESOLUTION_NAME, tempval);
				}
			} else {
				camapp->reserved_setting_data.front_photo_resolution = tempval;
				cam_config_set_int(PROP_SELF_PHOTO_RESOLUTION_NAME, tempval);
			}

			cam_app_get_preview_offset_coordinate(ad);
			ad->remained_count = cam_system_get_still_count_by_resolution(ad);
			indicator_update_remain_count(ad);
		}
		break;
	case PROP_VIDEO_RESOLUTION:
		{
			gint tempval = g_value_get_int(value);

			camapp->video_resolution = tempval;

			if (camapp->self_portrait == FALSE) {
				camapp->reserved_setting_data.rear_video_resolution = tempval;
				if (camapp->recording_mode == CAM_RECORD_NORMAL) {
					cam_config_set_int(PROP_VIDEO_RESOLUTION_NAME, tempval);
				}
			} else {
				camapp->reserved_setting_data.front_video_resolution = tempval;
				if (camapp->recording_mode == CAM_RECORD_SELF) {
					cam_config_set_int(PROP_SELF_VIDEO_RESOLUTION_NAME, tempval);
				}
			}
		}
		break;
	case PROP_FPS:
		{		/*  fps may not set it alone */
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_fps(tempval)) {
				cam_warning(LOG_UI, "fps set fail");
				return FALSE;
			}
			camapp->fps = tempval;
		}
		break;
	case PROP_BRIGHTNESS:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_brightness(tempval)) {
				cam_warning(LOG_UI, "brightness set fail");
				return FALSE;
			}
			camapp->brightness = tempval;
		}
		break;
	case PROP_WB:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_white_balance(tempval)) {
				cam_warning(LOG_UI,
					    "white balance set fail: %d",
					    tempval);
				return FALSE;
			}

			camapp->white_balance = tempval;

			if (camapp->self_portrait)
				camapp->reserved_setting_data.front_wb = tempval;
			else
				camapp->reserved_setting_data.rear_wb = tempval;

		}
		break;
	case PROP_ISO:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_iso(tempval)) {
				cam_warning(LOG_UI, "iso set fail");
				return FALSE;
			}
			camapp->iso = tempval;
			cam_config_set_int(PROP_ISO_NAME, tempval);
		}
		break;
	case PROP_AUTO_CONTRAST:
		{
			gboolean tempval = g_value_get_boolean(value);
			if (!cam_mm_enable_auto_contrast(tempval)) {
				cam_warning(LOG_UI, "contrast set fail");
				return FALSE;
			}
			camapp->auto_contrast = tempval;
			cam_config_set_int(PROP_AUTO_CONTRAST_NAME, tempval);
		}
		break;
	case PROP_METERING:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_auto_exposure(tempval)) {
				cam_warning(LOG_UI, "auto_exposure set fail");
				return FALSE;
			}
			camapp->auto_exposure = tempval;
			cam_config_set_int(PROP_METERING_NAME, tempval);
		}
		break;
	case PROP_EFFECT:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_effect(tempval)) {
				cam_warning(LOG_UI, "effect set fail : %d",
					    tempval);
				return FALSE;
			}
			camapp->effect = tempval;

			if (camapp->self_portrait == FALSE) {
				camapp->reserved_setting_data.rear_effect = tempval;
			} else {
				camapp->reserved_setting_data.front_effect = tempval;
			}
		}
		break;
	case PROP_AF_MODE:
		{
			gint tempval = g_value_get_int(value);
			gint oldval = cam_config_get_int(PROP_AF_NAME, CAM_FOCUS_AUTO);
			if (oldval == CAM_FOCUS_FACE && tempval != CAM_FOCUS_FACE) {
				cam_mm_stop_camera_face_detection();
				cam_app_stop_video_stream();
			}

			if (tempval == CAM_FOCUS_FACE) {
				if (!cam_mm_set_focus_mode(CAMERA_ATTR_AF_NORMAL)) {
					cam_warning(LOG_UI, "detect mode set fail");
					return FALSE;
				}

				/*start face detection*/
				if (cam_mm_is_supported_face_detection()) {
					cam_mm_start_camera_face_detection(camapp->face_detect_cb, (void *)ad);
					if (!cam_mm_set_preview_cb(cam_face_detection_focus_start_stream, (void*)ad)) {
						DEBUG_TRACE("preview callback set error");
					}
					cam_app_run_video_stream();
				} else {
					DEBUG_TRACE("not support face detect mode");
				}


			} else if ((tempval == CAM_FOCUS_AUTO) || (tempval == CAM_FOCUS_MACRO)) {
				if (!cam_mm_set_focus_mode(tempval)) {
					cam_warning(LOG_UI, "af mode set fail");
					return FALSE;
				}

				if (!cam_mm_set_preview_cb(camapp->preview_cb, (void*)ad)) {
					DEBUG_TRACE("preview callback set error");
				}

			} else {
				cam_warning(LOG_UI, "unknow af mode : %d", tempval);
				return FALSE;
			}
			camapp->af_mode = tempval;
			cam_app_focus_guide_update(ad);
			if (camapp->camera_mode == CAM_CAMERA_MODE && camapp->shooting_mode == CAM_SINGLE_MODE){
				cam_config_set_int(PROP_AF_NAME, tempval);
			}
		}
		break;
	case PROP_AHS:
		{
			gboolean tempval = g_value_get_boolean(value);

			if (!cam_mm_set_anti_hand_shake(tempval)) {
				cam_warning(LOG_UI, "anti_shake set fail");
				return FALSE;
			}

			camapp->anti_shake = tempval;
			cam_config_set_int(PROP_AHS_NAME, tempval);
		}
		break;
	case PROP_WDR:/*auto contrast*/
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_wdr(tempval)) {
				cam_warning(LOG_UI, "wdr set fail");
				return FALSE;
			}
			camapp->wdr = tempval;
			cam_config_set_int(PROP_WDR_NAME, tempval);
		}
		break;
	case PROP_FLASH:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_flash(tempval)) {
				cam_warning(LOG_UI, "flash set fail");
				return FALSE;
			}
			camapp->flash = tempval;
			/*fix me ,why only when in camera single mode ,
				save the FLASH setting value to config file*/
			if ((camapp->camera_mode == CAM_CAMERA_MODE
			     && camapp->shooting_mode == CAM_SINGLE_MODE)
			    || camapp->camera_mode == CAM_CAMCORDER_MODE) {
				cam_config_set_int(PROP_FLASH_NAME, tempval);
			}
		}
		break;
	case PROP_TIMER:
		{
			gint tempval = g_value_get_int(value);
			camapp->timer = tempval;
		}
		break;
	case PROP_IMAGE_QUALITY:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_image_enc_quality(tempval)) {
				cam_warning(LOG_UI,
					    "image quality[%d] set fail",
					    tempval);
				return FALSE;
			}
			camapp->image_quality = tempval;
		}
		break;
	case PROP_VIDEO_QUALITY:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_app_set_video_quality(ad, tempval)) {
				cam_warning(LOG_UI,
					    "video quality[%d] set fail",
					    tempval);
				return FALSE;
			}
			camapp->video_quality = tempval;
		}
		break;
	case PROP_AUDIO_REC:
		{
			gboolean tempval = g_value_get_boolean(value);
			if (!cam_mm_set_audio_recording(tempval)) {
				cam_warning(LOG_UI, "audio_recording set fail");
				return FALSE;
			}
			camapp->audio_recording = tempval;
		}
		break;
	case PROP_AUDIO_QUALITY:
		{
			gint tempval = g_value_get_int(value);
			camapp->audio_quality = tempval;
		}
		break;
	case PROP_BATTERY_CHARG:
		{
			gint tempval_charging = g_value_get_int(value);

			DEBUG_TRACE("charging = %d", tempval_charging);
			camapp->battery_charging = tempval_charging;
			camapp->battery_level = cam_utils_get_battery_level();
			indicator_update_battery(ad, camapp->battery_level);
		}
		break;
	case PROP_BATTERY_LEVEL:
		{
			gint tempval = g_value_get_int(value);
			camapp->battery_charging = cam_utils_get_charging_status();
			camapp->battery_level = tempval;
			indicator_update_battery(ad, camapp->battery_level);

		}
		break;
	case PROP_ZOOM:
		{
			gint tempval = g_value_get_int(value);
			DEBUG_TRACE("tempval:%d", tempval);
			if (!cam_mm_set_zoom(tempval)) {
				cam_warning(LOG_UI, "zoom set fail");
				return FALSE;
			}
			/*camapp->zoom_mode = tempval;*/ /*note: zoom_mode is zoom level, is not same this value*/
		}
		break;
	case PROP_STORAGE:
		{
			gint tempval = g_value_get_int(value);

			camapp->storage = tempval;

			vconf_set_int(VCONFKEY_SETAPPL_DEFAULT_MEM_CAMERA_INT, camapp->storage);
//			cam_config_set_int(PROP_STORAGE_NAME, tempval);

			indicator_update_storage(ad);
		}
		break;
	case PROP_GUIDELINE:
		{
			gboolean tempval = g_value_get_boolean(value);

			camapp->guideline = tempval;
			cam_config_set_boolean(PROP_GUIDELINE_NAME, tempval);
		}
		break;
	case PROP_GPS:
		{
			gboolean tempval = g_value_get_boolean(value);

			if (tempval) {
				camapp->need_gps_popup = TRUE;
				if (!cam_app_lbs_start(ad))
					return FALSE;

				return TRUE;
			} else {
				if (ad->gps_animation_timer)
					REMOVE_TIMER(ad->gps_animation_timer);
				if (!cam_app_lbs_stop(ad))
					return FALSE;

				return TRUE;
			}
		}
		break;
	case PROP_GPS_LEVEL:
		{
			gint tempval = g_value_get_int(value);

			camapp->gps_level = tempval;
			indicator_update_gps_level(ad);
		}
		break;
	case PROP_REVIEW:
		{
			gboolean tempval = g_value_get_boolean(value);
			camapp->review = tempval;
			cam_config_set_boolean(PROP_REVIEW_NAME, tempval);
		}
		break;
	case PROP_IMAGE_COUNT:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_mm_set_image_count(tempval)) {
				cam_warning(LOG_UI, "image_count set fail");
				return FALSE;
			}
			camapp->image_count = tempval;
		}
		break;
	case PROP_SHUTTER_SOUND:
		{
			gint tempval = g_value_get_int(value);
			camapp->shutter_sound = tempval;
		}
		break;
	case PROP_SIZE_LIMIT:
		{
			gint tempval = g_value_get_int(value);
			if (!cam_app_set_size_limit(tempval, camapp->size_limit_type)) {
				cam_warning(LOG_UI, "size_limit set fail");
				return FALSE;
			}
			camapp->size_limit = tempval;
		}
		break;
	case PROP_SIZE_LIMIT_TYPE:
		{
			gint tempval = g_value_get_int(value);
			camapp->size_limit_type = tempval;
		}
		break;
	case PROP_REC_TIME:
		{
			guint tempval = g_value_get_uint(value);
			camapp->rec_elapsed = tempval;
		}
		break;
	case PROP_REC_FILE_SIZE:
		{
			guint tempval = g_value_get_uint(value);
			camapp->rec_filesize = tempval;
		}
		break;
	case PROP_OUTDOOR_VISIBILITY:
		{
			gboolean tempval = g_value_get_boolean(value);
			cam_mm_set_outdoor_visibility(tempval);
			camapp->outdoor_visibility = tempval;
		}
		break;
	case PROP_VOLUME_KEY:
		{
			gint tempval = g_value_get_int(value);
			camapp->volume_key = tempval;
			cam_config_set_int(PROP_VOLUME_KEY_NAME, tempval);
		}
		break;
	case PROP_SAVE_AS_FLIP:
		{
			gboolean tempval = g_value_get_boolean(value);

			if (camapp->camera_mode == CAM_CAMERA_MODE) {
				cam_app_preview_stop();
				cam_mm_set_image_flip(tempval);
				cam_app_preview_start(ad);
			}

			camapp->save_as_flip= tempval;
		}
		break;
	case PROP_BURST_SHOT:
		{
			gboolean tempval = g_value_get_boolean(value);

			camapp->burst_shot = tempval;
			cam_config_set_boolean(PROP_BURST_SHOT_NAME, tempval);
		}
		break;
	default:
		cam_warning(LOG_UI, "unknow type :%d ", type);
		return FALSE;
		break;
	}
	/* indicator should be updated here!!! */
/*      change_indicator_mode_icons(ad); */
	return TRUE;
}

/*note: in this function ,just do data logic,please do not add any EFL code in it*/
gboolean cam_app_mode_change(void *data, int to_mode)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retv_if(ad == NULL, FALSE);
	CamAppData *camapp = ad->camapp_handle;
	cam_retv_if(camapp == NULL, FALSE);

	debug_fenter(LOG_UI);

	ad->timer_activated = FALSE;
	ad->emit_continuous_shutter = FALSE;;
	/*camapp->guideline = FALSE;*/
	cam_app_timeout_checker_remove();
	/* draw to_mode icon in preview area */
#ifdef USE_CAMERA_APP_SHUTTER_SOUND
	if (ad->play_rec_sound != 0)
		return TRUE;
#endif

	if (cam_mm_get_state() == CAMERA_STATE_CAPTURING
		&& (camapp->camera_mode == CAM_CAMERA_MODE)) {
		cam_mm_capture_stop(true, CAM_CAMERA_MODE);
	}

	/*  stop preview and destory mmfw handle */
	if (!cam_app_preview_stop()) {
		cam_critical(LOG_MM, "cam_app_preview_stop faild");
		goto MODE_CHANGE_FAILED;

	}

	/* Idler of capture callback management. wh01.cho@samsung.com. 2010-12-15. */
	cam_utils_remove_idler_all(ad);

	if (to_mode == CAM_CAMCORDER_MODE) {

		camapp->camera_mode = CAM_CAMCORDER_MODE;

		GValue value = { 0, };
		g_value_init(&value, G_TYPE_INT);

		ad->last_camera_zoom_mode = camapp->zoom_mode;

		switch(camapp->recording_mode)
		{
		case CAM_RECORD_SLOW:
		case CAM_RECORD_FAST:
			{
				ad->camapp_handle->enable_touch_af = FALSE;
				camapp->video_resolution = CAM_RESOLUTION_QVGA;
				camapp->photo_resolution = cam_app_get_max_image_size_by_ratio(ad, camapp->video_resolution);

				double rate = 0.0;

				if (camapp->recording_mode == CAM_RECORD_SLOW) {
					g_value_set_int(&value, SLOW_MOTION_REC_FPS);
					rate = SLOW_MOTION_PLAY_FPS;
				} else {
					g_value_set_int(&value, FAST_MOTION_REC_FPS);
					rate = FAST_MOTION_PLAY_FPS;
				}

				if (!cam_mm_set_recording_motion(rate)) {
					cam_critical(LOG_UI, "slow motion set fail");
					return FALSE;
				}

				if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}

				#if 0
				g_value_set_int(&value, CAM_RESOLUTION_QVGA);
				if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}
				#endif

				g_value_set_int(&value, REC_SIZE_LIMIT_DEFAULT);
				if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
					cam_critical(LOG_UI, "size limit set fail");
					return FALSE;
				}

				if (camapp->zoom_mode != 1) {
					camapp->zoom_mode = 1;

					CAM_GVALUE_SET_INT(value, 10);
					if (!cam_handle_value_set(ad, PROP_ZOOM, &value)) {
						cam_critical(LOG_UI, "zoom set fail");
						return FALSE;
					}
				}
			}
			break;
		case CAM_RECORD_SELF:
			{
				ad->camapp_handle->enable_touch_af = FALSE;
				camapp->video_resolution = cam_config_get_int(PROP_SELF_VIDEO_RESOLUTION_NAME, SELF_REC_RESOLUTION_DEFAULT);
				camapp->photo_resolution = cam_app_get_max_image_size_by_ratio(ad, camapp->video_resolution);

				g_value_set_int(&value, FPS_DEFAULT);

				if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}

				#if 0
				g_value_set_int(&value, CAM_RESOLUTION_VGA);
				if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
					cam_critical(LOG_UI, "resolution set fail");
					return FALSE;
				}
				#endif

				g_value_set_int(&value, REC_SIZE_LIMIT_DEFAULT);
				if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
					cam_critical(LOG_UI, "size limit set fail");
					return FALSE;
				}

				if (!cam_mm_reset_recording_motion_fps()) {
					cam_critical(LOG_UI,
							 "slow motion fps set fail");
					return FALSE;
				}
			}
			break;
		case CAM_RECORD_MMS:
		case CAM_RECORD_SELF_MMS:
			{
				ad->camapp_handle->enable_touch_af = TRUE;
				camapp->video_resolution = CAM_RESOLUTION_QCIF;
				camapp->photo_resolution = cam_app_get_max_image_size_by_ratio(ad, camapp->video_resolution);

				g_value_set_int(&value, FPS_SLOW);
				if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}

				#if 0
				g_value_set_int(&value, CAM_RESOLUTION_QCIF);
				if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
					cam_critical(LOG_UI, "resolution set fail");
					return FALSE;
				}
				#endif

				g_value_set_int(&value, CAM_REC_MMS_MAX_SIZE);
				if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
					cam_critical(LOG_UI, "size limit set fail");
					return FALSE;
				}

				if (!cam_mm_reset_recording_motion_fps()) {
					cam_critical(LOG_UI,
							 "slow motion fps set fail");
					return FALSE;
				}
			}
			break;
		case CAM_RECORD_NORMAL:
			{
				ad->camapp_handle->enable_touch_af = TRUE;
				camapp->video_resolution = cam_config_get_int(PROP_VIDEO_RESOLUTION_NAME, REC_RESOLUTION_DEFAULT);
				camapp->photo_resolution = cam_app_get_max_image_size_by_ratio(ad, camapp->video_resolution);

				g_value_set_int(&value, FPS_DEFAULT);
				if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}

				#if 0
				g_value_set_int(&value, resolution_n);
				if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
					cam_critical(LOG_UI, "resolution set fail");
					return FALSE;
				}
				#endif

				g_value_set_int(&value, REC_SIZE_LIMIT_DEFAULT);
				if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
					cam_critical(LOG_UI, "size limit set fail");
					return FALSE;
				}

				if (!cam_mm_reset_recording_motion_fps()) {
					cam_critical(LOG_UI,
							 "slow motion fps set fail");
					return FALSE;
				}
			}
			break;
		default:
			break;
		}
	} else {
		camapp->camera_mode = CAM_CAMERA_MODE;
		camapp->zoom_mode = ad->last_camera_zoom_mode;

		switch (camapp->shooting_mode) {
		case CAM_SINGLE_MODE:
			ad->camapp_handle->enable_touch_af = TRUE;
			camapp->photo_resolution = cam_config_get_int(PROP_PHOTO_RESOLUTION_NAME, IMAGE_RESOLUTION_DEFAULT);
			break;
		case CAM_SELF_SINGLE_MODE:
			ad->camapp_handle->enable_touch_af = FALSE;
			camapp->photo_resolution = cam_config_get_int(PROP_SELF_PHOTO_RESOLUTION_NAME, SELF_IMAGE_RESOLUTION_DEFAULT);
			break;
		default:
			break;
		}
	}

	if (!cam_callback_init(ad)) {
		cam_critical(LOG_MM, "cam_init_mm_callback failed");
		goto MODE_CHANGE_FAILED;

	}
	DEBUG_TRACE("camera mode = %d", to_mode);
	if (!cam_app_init_attribute(ad, to_mode)) {
		cam_critical(LOG_MM, "cam_app_init_attribute failed");
	}

	if (!cam_app_preview_start(ad)) {
		cam_critical(LOG_MM, "cam_app_preview_start failed");
		goto MODE_CHANGE_FAILED;

	}
	cam_app_timeout_checker_init(ad);

	return TRUE;

MODE_CHANGE_FAILED:
	cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA"), cam_app_timeout_notice_response_cb);
	return FALSE;

}

gboolean cam_mode_change(void *data, int to_mode)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retv_if(ad == NULL, FALSE);
	CamAppData *camapp = ad->camapp_handle;
	cam_retv_if(camapp == NULL, FALSE);

	debug_fenter(LOG_UI);

	cam_elm_cache_flush();

	evas_object_hide(ad->timer_icon_edje);
	REMOVE_TIMER(ad->timer_timer);
	ad->timer_activated = FALSE;
	ad->emit_continuous_shutter = FALSE;
	DEL_EVAS_OBJECT(ad->timer_icon_edje);
	DEL_EVAS_OBJECT(ad->guideline_edje);
	/*camapp->guideline = FALSE;*/
	cam_app_timeout_checker_remove();
	/* draw to_mode icon in preview area */
#ifdef USE_CAMERA_APP_SHUTTER_SOUND
	if (ad->play_rec_sound != 0)
		return TRUE;
#endif

	if (cam_mm_get_state() == CAMERA_STATE_CAPTURING
		&& (camapp->camera_mode == CAM_CAMERA_MODE)) {
		cam_mm_capture_stop(true, CAM_CAMERA_MODE);
	}

	cam_app_destroy_progressbar(ad);
	toolbar_shot_guide_popup_destory(ad);

	/*  stop preview and destory mmfw handle */
	if (!cam_app_preview_stop()) {
		cam_critical(LOG_MM, "cam_app_preview_stop faild");
		goto MODE_CHANGE_FAILED;

	}

	/* Idler of capture callback management. wh01.cho@samsung.com. 2010-12-15. */
	cam_utils_remove_idler_all(ad);

	if (to_mode == CAM_CAMCORDER_MODE) {

		camapp->camera_mode = CAM_CAMCORDER_MODE;

		GValue value = { 0, };
		g_value_init(&value, G_TYPE_INT);

		ad->last_camera_zoom_mode = camapp->zoom_mode;

		switch(camapp->recording_mode)
		{
		case CAM_RECORD_SLOW:
		case CAM_RECORD_FAST:
			{
				ad->camapp_handle->enable_touch_af = FALSE;
				camapp->video_resolution = CAM_RESOLUTION_QVGA;
				camapp->photo_resolution = cam_app_get_max_image_size_by_ratio(ad, camapp->video_resolution);

				double rate = 0.0;

				if (camapp->recording_mode == CAM_RECORD_SLOW) {
					g_value_set_int(&value, SLOW_MOTION_REC_FPS);
					rate = SLOW_MOTION_PLAY_FPS;
				} else {
					g_value_set_int(&value, FAST_MOTION_REC_FPS);
					rate = FAST_MOTION_PLAY_FPS;
				}

				if (!cam_mm_set_recording_motion(rate)) {
					cam_critical(LOG_UI, "slow motion set fail");
					return FALSE;
				}

				if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}

				#if 0
				g_value_set_int(&value, CAM_RESOLUTION_QVGA);
				if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}
				#endif

				g_value_set_int(&value, REC_SIZE_LIMIT_DEFAULT);
				if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
					cam_critical(LOG_UI, "size limit set fail");
					return FALSE;
				}

				if (camapp->zoom_mode != 1) {
					camapp->zoom_mode = 1;

					CAM_GVALUE_SET_INT(value, 10);
					if (!cam_handle_value_set(ad, PROP_ZOOM, &value)) {
						cam_critical(LOG_UI, "zoom set fail");
						return FALSE;
					}
				}
			}
			break;
		case CAM_RECORD_SELF:
			{
				ad->camapp_handle->enable_touch_af = FALSE;
				camapp->video_resolution = cam_config_get_int(PROP_SELF_VIDEO_RESOLUTION_NAME, SELF_REC_RESOLUTION_DEFAULT);
				camapp->photo_resolution = cam_app_get_max_image_size_by_ratio(ad, camapp->video_resolution);

				g_value_set_int(&value, FPS_DEFAULT);

				if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}

				#if 0
				g_value_set_int(&value, CAM_RESOLUTION_VGA);
				if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
					cam_critical(LOG_UI, "resolution set fail");
					return FALSE;
				}
				#endif

				g_value_set_int(&value, REC_SIZE_LIMIT_DEFAULT);
				if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
					cam_critical(LOG_UI, "size limit set fail");
					return FALSE;
				}

				if (!cam_mm_reset_recording_motion_fps()) {
					cam_critical(LOG_UI,
							 "slow motion fps set fail");
					return FALSE;
				}
			}
			break;
		case CAM_RECORD_MMS:
		case CAM_RECORD_SELF_MMS:
			{
				ad->camapp_handle->enable_touch_af = TRUE;
				camapp->video_resolution = CAM_RESOLUTION_QCIF;
				camapp->photo_resolution = cam_app_get_max_image_size_by_ratio(ad, camapp->video_resolution);

				g_value_set_int(&value, FPS_SLOW);
				if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}

				#if 0
				g_value_set_int(&value, CAM_RESOLUTION_QCIF);
				if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
					cam_critical(LOG_UI, "resolution set fail");
					return FALSE;
				}
				#endif

				g_value_set_int(&value, CAM_REC_MMS_MAX_SIZE);
				if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
					cam_critical(LOG_UI, "size limit set fail");
					return FALSE;
				}

				if (!cam_mm_reset_recording_motion_fps()) {
					cam_critical(LOG_UI,
							 "slow motion fps set fail");
					return FALSE;
				}
			}
			break;
		case CAM_RECORD_NORMAL:
			{
				ad->camapp_handle->enable_touch_af = TRUE;
				camapp->video_resolution = cam_config_get_int(PROP_VIDEO_RESOLUTION_NAME, REC_RESOLUTION_DEFAULT);
				camapp->photo_resolution = cam_app_get_max_image_size_by_ratio(ad, camapp->video_resolution);

				g_value_set_int(&value, FPS_DEFAULT);
				if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
					cam_critical(LOG_UI, "fps set fail");
					return FALSE;
				}

				#if 0
				g_value_set_int(&value, resolution_n);
				if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
					cam_critical(LOG_UI, "resolution set fail");
					return FALSE;
				}
				#endif

				g_value_set_int(&value, REC_SIZE_LIMIT_DEFAULT);
				if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
					cam_critical(LOG_UI, "size limit set fail");
					return FALSE;
				}

				if (!cam_mm_reset_recording_motion_fps()) {
					cam_critical(LOG_UI,
							 "slow motion fps set fail");
					return FALSE;
				}
			}
			break;
		default:
			break;
		}
	} else {
		camapp->camera_mode = CAM_CAMERA_MODE;
		camapp->zoom_mode = ad->last_camera_zoom_mode;

		switch (camapp->shooting_mode) {
		case CAM_SINGLE_MODE:
			ad->camapp_handle->enable_touch_af = TRUE;
			camapp->photo_resolution = cam_config_get_int(PROP_PHOTO_RESOLUTION_NAME, IMAGE_RESOLUTION_DEFAULT);
			break;
		case CAM_SELF_SINGLE_MODE:
			ad->camapp_handle->enable_touch_af = FALSE;
			camapp->photo_resolution = cam_config_get_int(PROP_SELF_PHOTO_RESOLUTION_NAME, SELF_IMAGE_RESOLUTION_DEFAULT);
			break;
		default:
			break;
		}
	}

	if (!cam_callback_init(ad)) {
		cam_critical(LOG_MM, "cam_init_mm_callback failed");
		goto MODE_CHANGE_FAILED;

	}
	DEBUG_TRACE("camera mode = %d", to_mode);
	if (!cam_app_init_attribute(ad, to_mode)) {
		cam_critical(LOG_MM, "cam_app_init_attribute failed");
	}

	cam_app_get_preview_offset_coordinate(ad);

	cam_reset_focus_mode(ad);

	if (!cam_app_preview_start(ad)) {
		cam_critical(LOG_MM, "cam_app_preview_start failed");
		goto MODE_CHANGE_FAILED;

	}
	cam_app_timeout_checker_init(ad);

	return TRUE;

MODE_CHANGE_FAILED:
	cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA"), cam_app_timeout_notice_response_cb);
	return FALSE;
}

gboolean cam_recording_mode_change(void *data, int rec_mode)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	//CamDeviceType device_type = CAM_DEVICE_MEGA;
	GValue value = { 0 };
	int video_dev = 0;
	gboolean cam_reset = FALSE;

	debug_fenter(LOG_CAM);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	cam_app_timeout_checker_remove();

	g_value_init(&value, G_TYPE_INT);

	cam_mm_get_video_device(&video_dev);
	if (((camapp->recording_mode == CAM_RECORD_SELF || camapp->recording_mode == CAM_RECORD_SELF_MMS )&& video_dev == CAM_DEVICE_MEGA)
	    || ((camapp->recording_mode != CAM_RECORD_SELF || camapp->recording_mode == CAM_RECORD_SELF_MMS) && video_dev == CAM_DEVICE_VGA)) {

		/*  stop preview and destory mmfw handle */
		cam_reset = TRUE;
		if (!cam_app_preview_stop()) {
			cam_critical(LOG_MM, "cam_app_preview_stop faild");
			return FALSE;
		}
		if (!cam_mm_destory()) {
			cam_critical(LOG_MM, "cam_mm_destory faild");
			return FALSE;
		}
#if 0
		if (camapp->recording_mode == CAM_RECORD_SELF ||camapp->recording_mode == CAM_RECORD_SELF_MMS ) {
			device_type = CAM_DEVICE_VGA;
		} else {
			device_type = CAM_DEVICE_MEGA;
		}
#endif
		if (!cam_mm_create(camapp->device_type, camapp->camera_mode)) {
			cam_critical(LOG_MM, "cam_mm_create failed");
			cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA"), cam_app_timeout_notice_response_cb);
			return FALSE;
		}
		cam_mm_get_video_size( &camapp->default_preview_width, &camapp->default_preview_height);
		DEBUG_TRACE("default_width = %d,default_height = %d", camapp->default_preview_width, camapp->default_preview_height);

	}else {
		if (!cam_app_preview_stop()) {
			cam_critical(LOG_MM, "cam_app_preview_stop faild");
			return FALSE;
		}
	}
	if (rec_mode == CAM_RECORD_SLOW || rec_mode == CAM_RECORD_FAST) {
		ad->camapp_handle->enable_touch_af = FALSE;

		double rate = 0.0;

		if (rec_mode == CAM_RECORD_SLOW) {
			g_value_set_int(&value, SLOW_MOTION_REC_FPS);
			rate = SLOW_MOTION_PLAY_FPS;
		} else {
			g_value_set_int(&value, FAST_MOTION_REC_FPS);
			rate = FAST_MOTION_PLAY_FPS;
		}

		if (!cam_mm_set_recording_motion(rate)) {
			cam_critical(LOG_UI, "slow motion set fail");
			return FALSE;
		}

		if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
			cam_critical(LOG_UI, "fps set fail");
			return FALSE;
		}

		g_value_set_int(&value, CAM_RESOLUTION_QVGA);
		if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
			cam_critical(LOG_UI, "resolution set fail");
			return FALSE;
		}
		g_value_set_int(&value, REC_SIZE_LIMIT_DEFAULT);
		if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
			cam_critical(LOG_UI, "size limit set fail");
			return FALSE;
		}

		if (camapp->zoom_mode != 1) {
			camapp->zoom_mode = 1;

			GValue value = { 0, };

			CAM_GVALUE_SET_INT(value, 10);
			if (!cam_handle_value_set(ad, PROP_ZOOM, &value)) {
				cam_critical(LOG_UI, "zoom set fail");
				return FALSE;
			}
		}

		camapp->recording_mode = rec_mode;

	} else {
		ad->camapp_handle->enable_touch_af = TRUE;

		if(rec_mode == CAM_RECORD_SELF) {

			ad->camapp_handle->enable_touch_af = FALSE;
			g_value_set_int(&value, FPS_SLOW);
			if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
				cam_critical(LOG_UI, "fps set fail");
				return FALSE;
			}

			int resolution = cam_config_get_int(PROP_SELF_VIDEO_RESOLUTION_NAME, SELF_REC_RESOLUTION_DEFAULT);

			g_value_set_int(&value, resolution);
			if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
				cam_critical(LOG_UI, "resolution set fail");
				return FALSE;
			}

			g_value_set_int(&value, REC_SIZE_LIMIT_DEFAULT);
			if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
				cam_critical(LOG_UI, "size limit set fail");
				return FALSE;
			}

			if (!cam_mm_reset_recording_motion_fps()) {
				cam_critical(LOG_UI,
					     "slow motion fps set fail");
				return FALSE;
			}
			camapp->recording_mode = CAM_RECORD_SELF;
		} else if (rec_mode == CAM_RECORD_MMS ||rec_mode == CAM_RECORD_SELF_MMS ) {
			g_value_set_int(&value, FPS_SLOW);
			if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
				cam_critical(LOG_UI, "fps set fail");
				return FALSE;
			}

			g_value_set_int(&value, CAM_RESOLUTION_QCIF);
			if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
				cam_critical(LOG_UI, "resolution set fail");
				return FALSE;
			}

			g_value_set_int(&value, CAM_REC_MMS_MAX_SIZE);
			if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
				cam_critical(LOG_UI, "size limit set fail");
				return FALSE;
			}

			if (!cam_mm_reset_recording_motion_fps()) {
				cam_critical(LOG_UI,
					     "slow motion fps set fail");
				return FALSE;
			}
			if (rec_mode == CAM_RECORD_MMS)
				camapp->recording_mode = CAM_RECORD_MMS;
			else
				camapp->recording_mode = CAM_RECORD_SELF_MMS;

		} else {
			int resolution_n =
			    cam_config_get_int(PROP_VIDEO_RESOLUTION_NAME,  REC_RESOLUTION_DEFAULT);

			g_value_set_int(&value, FPS_DEFAULT);
			if (!cam_handle_value_set(ad, PROP_FPS, &value)) {
				cam_critical(LOG_UI, "fps set fail");
				return FALSE;
			}

			g_value_set_int(&value, resolution_n);
			if (!cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &value)) {
				cam_critical(LOG_UI, "resolution set fail");
				return FALSE;
			}

			g_value_set_int(&value, REC_SIZE_LIMIT_DEFAULT);
			if (!cam_handle_value_set(ad, PROP_SIZE_LIMIT, &value)) {
				cam_critical(LOG_UI, "size limit set fail");
				return FALSE;
			}

			if (!cam_mm_reset_recording_motion_fps()) {
				cam_critical(LOG_UI,
					     "slow motion fps set fail");
				return FALSE;
			}
			camapp->recording_mode = CAM_RECORD_NORMAL;

		}
		if (cam_reset) {
			if (!cam_app_init_attribute(ad, camapp->camera_mode)) {
				cam_critical(LOG_MM, "cam_app_init_attribute failed");
//				return FALSE;
			}
		} else {
			if (!cam_app_set_recording_mode(ad, rec_mode)) {
				DEBUG_TRACE("cam_app_set_recording_mode failed");
//				return FALSE;
			}
		}
	}
	cam_app_get_preview_offset_coordinate(ad);

	if (!cam_callback_init(ad)) {
		cam_critical(LOG_MM, "cam_init_mm_callback failed");
		cam_app_notice_popup(ad, "PREVIEW START FAILED !!", cam_app_timeout_notice_response_cb);
		return FALSE;
	}

	cam_continuous_af_start(ad);
	if (!cam_app_preview_start(ad)) {
		cam_critical(LOG_MM, "cam_app_preview_start failed");
		cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA"), cam_app_timeout_notice_response_cb);
		return FALSE;
	}

	cam_app_timeout_checker_init(ad);

	return TRUE;

}

static gboolean cam_app_set_capture_format_shooting_mode(int mode)
{
	switch (mode) {
	case CAM_SINGLE_MODE:
	case CAM_SELF_SINGLE_MODE:
		if (!cam_mm_set_capture_format(CAMERA_PIXEL_FORMAT_JPEG))
			return FALSE;
		break;
	default:
		break;
	}

	cam_debug(LOG_UI,
		  "\n################# shooting mode set return success : %d\n",
		  mode);

	return TRUE;
}

static void cam_shooting_mode_reset(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	debug_fenter(LOG_CAM);
	cam_retm_if(ad == NULL, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp_handle is NULL");

	cam_app_destroy_progressbar(ad);

	return;
}

gboolean cam_shooting_mode_change(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	GValue value = { 0 };

	debug_fenter(LOG_CAM);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	cam_elm_cache_flush();

	cam_app_stop_video_stream();
	cam_app_timeout_checker_remove();
	cam_shooting_mode_reset(ad);

	g_value_init(&value, G_TYPE_INT);

	cam_debug(LOG_CAM, "Shooting mode = %d ", camapp->shooting_mode);

	cam_continuous_shot_data_free(ad);

	if (ad->shot_mode_guide_popup)
		toolbar_shot_guide_popup_destory(ad);
	ad->emit_continuous_shutter = FALSE;
	switch (camapp->shooting_mode) {
	case CAM_SINGLE_MODE:
		{
			int resolution = 0, flash = 0, auto_focus = 0, scene_mode = 0, wb = 0, effect = 0;
			resolution = cam_config_get_int(PROP_PHOTO_RESOLUTION_NAME, IMAGE_RESOLUTION_DEFAULT);
			flash = cam_config_get_int(PROP_FLASH_NAME, FLASH_DEFAULT);
			auto_focus = cam_config_get_int(PROP_AF_NAME, AF_DEFAULT);
			scene_mode = cam_config_get_int(PROP_SCENE_MODE_NAME, PG_MODE_DEFAULT);
			wb = camapp->reserved_setting_data.rear_wb;
			effect = camapp->reserved_setting_data.rear_effect;

			/* set resolution */
			g_value_set_int(&value, resolution);
			cam_handle_value_set(ad, PROP_PHOTO_RESOLUTION, &value);

			/* set flash  */
			g_value_set_int(&value, flash);
			cam_handle_value_set(ad, PROP_FLASH, &value);

			/* set auto focus */
			g_value_set_int(&value, auto_focus);
			cam_handle_value_set(ad, PROP_AF_MODE, &value);

			/* set scene */
			g_value_set_int(&value, scene_mode);
			cam_handle_value_set(ad, PROP_SCENE_MODE, &value);

			/* set wb */
			g_value_set_int(&value, wb);
			cam_handle_value_set(ad, PROP_WB, &value);

			/* set effect */
			g_value_set_int(&value, effect);
			cam_handle_value_set(ad, PROP_EFFECT, &value);

			/* set capture count */
			g_value_set_int(&value, IMAGE_COUNT_DEFAULT);
			cam_handle_value_set(ad, PROP_IMAGE_COUNT, &value);
		}
		break;

	case CAM_SELF_SINGLE_MODE:
		{
			int resolution, effect, wb = 0;

			resolution = cam_config_get_int(PROP_SELF_PHOTO_RESOLUTION_NAME, SELF_IMAGE_RESOLUTION_DEFAULT);
			effect = camapp->reserved_setting_data.front_effect;
			wb = camapp->reserved_setting_data.front_wb;

			/* set resolution */
			g_value_set_int(&value, resolution);
			cam_handle_value_set(ad, PROP_PHOTO_RESOLUTION, &value);

			/* set flash off */
			g_value_set_int(&value, CAM_FLASH_OFF);
			cam_handle_value_set(ad, PROP_FLASH, &value);

			/* set auto focus */
			g_value_set_int(&value, CAM_FOCUS_AUTO);
			cam_handle_value_set(ad, PROP_AF_MODE, &value);

			/* set scene to NONE */
			g_value_set_int(&value, CAM_SCENE_NONE);
			cam_handle_value_set(ad, PROP_SCENE_MODE, &value);

			/* set effect */
			g_value_set_int(&value, effect);
			cam_handle_value_set(ad, PROP_EFFECT, &value);

			/* set capture count */
			g_value_set_int(&value, IMAGE_COUNT_DEFAULT);
			cam_handle_value_set(ad, PROP_IMAGE_COUNT, &value);

			// set wb
			g_value_set_int(&value, wb);
			cam_handle_value_set(ad, PROP_WB, &value);
		}
		break;
	default:
		break;
	}

	if (!cam_callback_init(ad)) {
		cam_critical(LOG_MM, "cam_init_mm_callback failed");
		cam_app_notice_popup(ad, "PREVIEW START FAILED !!", cam_app_timeout_notice_response_cb);
		return FALSE;
	}

	cam_app_timeout_checker_init(ad);
	return TRUE;
}

gboolean __cam_single_shot_reg_file(char *file_path)
{
	GError *error = NULL;

	if (file_path) {
		DEBUG_TRACE("register file : %s", file_path);

		if (!cam_file_register(file_path, &error)) {
			cam_critical(LOG_FILE, "cam_file_register fail");
			if (error != NULL) {
				if (error->message != NULL) {
					cam_critical(LOG_FILE,
						     "cam_file_register error [%s]",
					    	 error->message);
				} else {
					cam_critical(LOG_FILE,
						     "cam_file_register error but error message is NULL");
				}
				g_error_free(error);
				error = NULL;
			}
		}
	} else {
		cam_warning(LOG_FILE, " file path is NULL...");

		return FALSE;
	}

	return TRUE;
}

static void cam_app_timer_update_count(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	cam_debug(LOG_UI, "timer count ... [ %d ]", ad->timer_count);

	char count_string[3] = "";

	elm_object_part_content_unset(ad->ug_base, "timer_layout");

	if (ad->timer_icon_edje == NULL) {
		switch (ad->target_direction) {
		case CAM_TARGET_DIRECTION_LANDSCAPE:
		case CAM_TARGET_DIRECTION_LANDSCAPE_INVERSE:
			ad->timer_icon_edje = cam_app_load_edj(ad->ug_base, CAM_UTILS_EDJ_NAME, "timer_icon_landscape");
			break;
		case CAM_TARGET_DIRECTION_PORTRAIT:
		case CAM_TARGET_DIRECTION_PORTRAIT_INVERSE:
			ad->timer_icon_edje = cam_app_load_edj(ad->ug_base, CAM_UTILS_EDJ_NAME, "timer_icon_portrait");
			break;
		default:
			DEBUG_TRACE("Invalid direction type!!!");
		}

		cam_retm_if(ad->timer_icon_edje == NULL, "timer_icon_edje is NULL");
		elm_object_part_content_set(ad->ug_base, "timer_layout", ad->timer_icon_edje);
	}

	snprintf(count_string, sizeof(count_string), "%d", ad->timer_count);

	edje_object_part_text_set(_EDJ(ad->timer_icon_edje), "text", count_string);

	evas_object_show(ad->timer_icon_edje);

	return;
}
static Eina_Bool cam_app_gps_timer_cb(void *data)
{
	DEBUG_TRACE(" ");
	struct appdata *ad = (struct appdata *)data;
	cam_retv_if(ad == NULL, ECORE_CALLBACK_CANCEL);
	CamAppData *camapp = ad->camapp_handle;
        if (camapp == NULL) {
                ad->gps_animation_timer = NULL;
                return ECORE_CALLBACK_CANCEL;
        }

	int gps_level = CAM_LBS_STATE_DISABLE;
	static int count =0;

	gps_level = cam_lbs_get_state(); //real gps level
	if (gps_level >=CAM_LBS_STATE_SERVICE_ENABLE) {
		camapp->gps = TRUE;
		camapp->gps_level = cam_lbs_get_state();

		if (ad->gps_animation_timer)
			ad->gps_animation_timer = NULL;

		return ECORE_CALLBACK_CANCEL;
	}

	indicator_update_gps_level(ad);
	if (camapp->gps_level == CAM_LBS_STATE_ACCURANCY_DETAILED ) {
		camapp->gps_level = CAM_LBS_STATE_SERVICE_START;
	}

	if (count > GPS_TIME_OUT) {
		count = 0;
		camapp->gps = FALSE;
		cam_lbs_stop();
		camapp->gps_level = cam_lbs_get_state();
		indicator_update_gps(ad);	/* update gps icon */
		if(!cam_mm_remove_geo_tag())
			DEBUG_TRACE("cam_mm_remove_geo_tag failed");

		if (ad->gps_animation_timer)
			ad->gps_animation_timer = NULL;

		return ECORE_CALLBACK_CANCEL;
	}
	camapp->gps_level ++;
	count ++;

	return ECORE_CALLBACK_RENEW;
}

static Eina_Bool cam_app_timer_cb(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retv_if(ad == NULL, ECORE_CALLBACK_CANCEL);

	CamAppData *camapp = NULL;

	camapp = ad->camapp_handle;
	if (camapp == NULL) {
		cam_critical(LOG_UI, "camapp_handle is NULL");

		if (ad->timer_timer)
			ad->timer_timer = NULL;
		return ECORE_CALLBACK_CANCEL;
	}

	ad->timer_count = ad->timer_count - 1;

	if (ad->timer_count > 0) {
		cam_debug(LOG_UI, "timer continue ... ");
		cam_app_timer_update_count(ad);
		if (camapp->shutter_sound != CAM_SETTINGS_SOUND_OFF)
			cam_sound_play(CAM_SOUND_EFFECT_TICK, ad);
		return ECORE_CALLBACK_RENEW;
	} else {
		cam_debug(LOG_UI, "timer terminated ...");

		ad->timer_activated = false;

		if (ad->timer_icon_edje != NULL) {
			evas_object_del(ad->timer_icon_edje);
			ad->timer_icon_edje = NULL;
		}

		cam_toolbar_update(ad);

		if (camapp->camera_mode == CAM_CAMERA_MODE) {
			cam_set_orient_value(ad);
			if (!cam_image_capture_start(ad))
				cam_critical(LOG_UI, "cam_image_capture_start failed");
		} else {
			if (!cam_video_record_start(ad))
				cam_critical(LOG_UI, "cam_video_record_start failed");
		}

		if (ad->timer_timer)
			ad->timer_timer = NULL;

		return ECORE_CALLBACK_CANCEL;
	}
}

static void cam_app_start_timer(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp_handle is NULL");

	ad->timer_activated = true;

	switch (camapp->timer) {
	case CAM_SETTINGS_TIMER_2SEC:
		ad->timer_count = 2;
		break;
	case CAM_SETTINGS_TIMER_5SEC:
		ad->timer_count = 5;
		break;
	case CAM_SETTINGS_TIMER_10SEC:
		ad->timer_count = 10;
		break;

	case CAM_SETTINGS_TIMER_OFF:
	default:
		CAM_UI_LOG("can not reach here");
		return;
	}

	if (camapp->default_capture_mode == CAM_CAPTURE_BURST)
		return;

	cam_toolbar_update(ad);

	cam_app_timer_update_count(ad);

	if (ad->timer_timer != NULL) {
		ecore_timer_del(ad->timer_timer);
		ad->timer_timer = NULL;
	}

	ad->timer_timer = ecore_timer_add(1.0, cam_app_timer_cb, ad);
}

void cam_app_cancel_timer(void *data)
{
	struct appdata *ad = (struct appdata *)data;

	ad->timer_activated = FALSE;

	REMOVE_TIMER(ad->timer_timer);
	DEL_EVAS_OBJECT(ad->timer_icon_edje);

	cam_toolbar_update(ad);
}

static void _popup_cancel_cb(void *data, Evas_Object *obj, void *event_info)
{
	/* cam_app_free_blocking_popup(); */
	Evas_Object *notify = (Evas_Object *)data;
	cam_popup_remove(notify);
	/* evas_object_del(notify); */
}

gboolean cam_image_capture_start(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	gint64 remain = 0;
	gboolean ret = TRUE;

	debug_fenter(LOG_UI);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");
	CAM_TA_ACUM_ITEM_BEGIN("    cam_image_capture_start", 0);
	if (camapp->af_mode == CAM_FOCUS_FACE) {
		cam_app_stop_video_stream();
	}
	DEBUG_TRACE("camapp->burst_shot %d", camapp->burst_shot);
	DEBUG_TRACE("camapp->shooting_mode %d", camapp->shooting_mode);
	DEBUG_TRACE("camapp->default_capture_mode %d", camapp->default_capture_mode);
	remain = cam_system_get_still_count_by_resolution(ad);

	if(remain <= 0){
		cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_BODY_UNABLE_TO_SAVE_NOT_ENOUGH_MEMORY"), cam_app_popup_response_cb);
		CAM_TA_ACUM_ITEM_END("    cam_image_capture_start", 0);
		return FALSE;
	}

	if (camapp->gps) {
		int gps_level = CAM_LBS_STATE_DISABLE;
		gps_level = cam_lbs_get_state();

		if (gps_level >=CAM_LBS_STATE_SERVICE_ENABLE) {
			double longitude = -1.0;
			double latitude = -1.0;
			double altitude = -1.0;
			time_t time_stamp = -1.0;
			if (cam_lbs_get_current_position(&longitude, &latitude, &altitude, &time_stamp)) {
				DEBUG_TRACE("GEO TAG [longitude = %d, latitude = %d, altitude = %d]", longitude, latitude, altitude);
				if (!cam_mm_set_gps_data(latitude, longitude, (double)altitude))
					DEBUG_TRACE("cam_mm_set_gps_data failed");
			}
		}
	}
	cam_set_orient_value(ad);

	if (camapp->camera_mode == CAM_CAMERA_MODE) {
		switch (camapp->shooting_mode) {
		case CAM_SINGLE_MODE:
		case CAM_SELF_SINGLE_MODE:
			if (camapp->burst_shot == TRUE && camapp->default_capture_mode == CAM_CAPTURE_BURST) {
				camapp->capture_cb = (camera_capturing_cb)cam_continuous_shot_capture_callback;
				cam_continuous_shot_capture_start(ad);
			} else {
				camapp->capture_cb = (camera_capturing_cb)__cam_capture_cb;
				ret = cam_mm_capture_start(camapp->capture_cb, camapp->capture_completed_cb, (void*)ad);
			}
			break;
		default:
			ret = cam_mm_capture_start(camapp->capture_cb, camapp->capture_completed_cb, (void*)ad); /*capture on recoring */
			break;
		}
	}else if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		ret = cam_mm_capture_start(camapp->capture_cb, camapp->capture_completed_cb, (void*)ad);
	}

	CAM_TA_ACUM_ITEM_END("    cam_image_capture_start", 0);
	CAM_TA_ACUM_ITEM_BEGIN("    capture_start to capturecallback", 0);
	return ret;
}

static gboolean cam_image_capture_stop(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	debug_fenter(LOG_UI);
	ad->stop_continuous_shot = FALSE;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	if (camapp->shooting_mode == CAM_SINGLE_MODE && camapp->default_capture_mode == CAM_CAPTURE_BURST) {
		ad->stop_continuous_shot = TRUE;
	}

	return TRUE;
}

Eina_Bool cam_image_capture_handle_idler(void *itm)
{
	CamIdlerItem *item = (CamIdlerItem *) itm;
	struct appdata *ad = NULL;
	cam_retvm_if(!item, ECORE_CALLBACK_CANCEL, "CamIdlerItem is NULL");

	ad = (struct appdata *)item->data;
	cam_retvm_if(!ad, ECORE_CALLBACK_CANCEL, "appdata is NULL");

	cam_info(LOG_UI, "call idler[ %p] ", item->idler);
	ad->capture_cb_list = g_list_remove(ad->capture_cb_list, item->idler);
	if (item->idler) {
		ecore_idler_del(item->idler);
		item->idler = NULL;
	}
	free(item);
	item = NULL;
	return cam_image_capture_handle(ad);
}
static Eina_Bool __cam_app_hide_rect_image(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");
	HIDE_EVAS_OBJECT(ad->rect_image);
	return ECORE_CALLBACK_CANCEL;
}

Eina_Bool cam_capture_on_recording_handle(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");
	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, ECORE_CALLBACK_CANCEL,
		     "camapp_handle is NULL");
	gboolean preview_skip = FALSE;

	if (camapp->filename) {
		cam_debug(LOG_SYS, "#########camapp->filename=%s", camapp->filename);
		CAM_TA_ACUM_ITEM_BEGIN("    send signal to register thread", 0);
		g_queue_push_tail(ad->file_reg_queue, strdup(camapp->filename));
		pthread_cond_signal(&ad->file_reg_cond);
		CAM_TA_ACUM_ITEM_END("    send signal to register thread", 0);
	} else {
		cam_app_notice_popup(ad, "Your storage have trouble ", cam_app_popup_response_cb);
	}
	if (!cam_mm_capture_stop (preview_skip, CAM_CAMERA_MODE)) {
		cam_critical(LOG_MM, " cam_mm_capture_stop error ");
	}
	ecore_timer_add(0.50, __cam_app_hide_rect_image, ad);

	return ECORE_CALLBACK_CANCEL;
}

static Eina_Bool __cam_run_image_viewer_idler(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retv_if(camapp == NULL, ECORE_CALLBACK_CANCEL);

	gboolean launch_special_view = FALSE;

	if (!cam_app_run_image_viewer_ug(ad, camapp->filename, launch_special_view)) {
		cam_critical(LOG_UI, "cam_app_run_image_viewer_ug failed");
	}

	return ECORE_CALLBACK_CANCEL;
}

static void* __cam_run_image_viewer_thread_run(void *data)
{
	struct appdata *ad = (struct appdata *)data;

	if(ad == NULL){
		pthread_exit(NULL);
		return NULL;
	}
	CamAppData *camapp = ad->camapp_handle;

	if(camapp == NULL){
		pthread_exit(NULL);
		return NULL;
	}

	while (ad->is_capture_animation_processing) {
//		DEBUG_TRACE("wait capture animation!");
	}

	ecore_idler_add(__cam_run_image_viewer_idler, (void *)ad);

	pthread_exit(NULL);
	return NULL;
}

static Ecore_Timer *progress_timer = NULL;

Eina_Bool cam_image_capture_handle(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	debug_fenter(LOG_UI);

	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, ECORE_CALLBACK_CANCEL, "camapp_handle is NULL");

	CAM_TA_ACUM_ITEM_END("    captured message to cam_image_capture_handle", 0);
	CAM_TA_ACUM_ITEM_BEGIN("    cam_image_capture_handle", 0);

	pthread_t run_image_viewer_thread;

	switch (camapp->shooting_mode) {

	case CAM_SINGLE_MODE:
	case CAM_SELF_SINGLE_MODE:
		DEBUG_TRACE("start single shot capture. capture mode %d", camapp->default_capture_mode);

		cam_critical(LOG_UI, "completed");

		if( camapp->default_capture_mode == CAM_CAPTURE_SINGLE ||camapp->burst_shot == FALSE) {
			if (camapp->filename) {
				cam_debug(LOG_SYS, "#########camapp->filename=%s", camapp->filename);
				CAM_TA_ACUM_ITEM_BEGIN("	send signal to register thread", 0);
				g_queue_push_tail(ad->file_reg_queue, strdup(camapp->filename));
				pthread_cond_signal(&ad->file_reg_cond);
				CAM_TA_ACUM_ITEM_END("	  send signal to register thread", 0);
				cam_app_update_thumbnail();
			} else {
				cam_app_notice_popup(ad, "Your storage have trouble ", cam_app_popup_response_cb);
			}
		} else {
			if (camapp->continuous_shot_data == NULL) {
				cam_critical(LOG_SYS, " continuous_shot_data is NULL");
				return ECORE_CALLBACK_CANCEL;
			}

			int i = 0;

			camapp->continuous_shot_data->capture_status = CAM_CONTI_SHOT_STATUS_STOPPED;

			if (camapp->filename)
				free(camapp->filename);

			camapp->filename = strdup(camapp->continuous_shot_data->file_path[camapp->continuous_shot_data->shot_num - 1]);

			cam_app_destroy_progressbar(ad);
			if (camapp->continuous_shot_data->error != NULL) {
				cam_debug(LOG_SYS, " Start to unlink captured files");

				/*  unlink all captured files */
				for (i = 0; i < camapp->continuous_shot_data->shot_num; i++) {
					if (camapp->continuous_shot_data->file_path[i]
					    && !access(camapp->continuous_shot_data->file_path[i], F_OK)) {
						unlink(camapp->continuous_shot_data->file_path[i]);
					}
				}

				cam_debug(LOG_SYS, " Unlink done");
				cam_app_notice_popup(ad, camapp->continuous_shot_data->error->message, cam_app_popup_response_cb);
			} else {
				cam_critical(LOG_UI, "start to register continuous shot");

			}

			#if 1 /*TODO: need ui guide, for display popup*/
			elm_progressbar_value_set(ad->progress_popup_bar, 1.0);
			if (progress_timer) {
				ecore_timer_del(progress_timer);
			}
			ad->is_processing = FALSE;
			cam_popup_delete(ad);
#endif

			cam_continuous_shot_data_free(ad);
			cam_toolbar_update(ad);
			cam_app_update_thumbnail();
			camapp->default_capture_mode = CAM_CAPTURE_SINGLE;
			cam_reset_focus_mode(ad);
		}


		if (camapp->review) {
			if (pthread_create(&run_image_viewer_thread, NULL, __cam_run_image_viewer_thread_run, (void *)ad) < 0) {
				cam_critical(LOG_CAM, "create run_image_viewer_thread failed");
				return ECORE_CALLBACK_CANCEL;
			}
		}

		break;

	default:
		cam_debug(LOG_UI, " Not matched shooting mode [%d]",
			  camapp->shooting_mode);
		break;
	}
	ad->remained_count--;
	indicator_update_remain_count(ad);

	if (camapp->af_mode == CAM_FOCUS_FACE) { /*note: face focus mode, if start capture,stop draw rect*/
		cam_app_run_video_stream();
	}

	CAM_TA_ACUM_ITEM_END("    cam_image_capture_handle", 0);

	return ECORE_CALLBACK_CANCEL;
}

gboolean cam_camera_touch_af_press(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	debug_fenter(LOG_UI);

	camapp->focus_mode = CAM_FOCUS_MODE_TOUCH_AUTO;

	if (!ad->camapp_handle->key_lock) {
		ad->camapp_handle->key_lock = TRUE;
		if (!cam_camera_key_half_press(ad)) {
			DEBUG_TRACE("cam_camera_key_half_press failed state");
			ad->camapp_handle->key_lock = FALSE;
			camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;
			return FALSE;
		}
		ad->camapp_handle->key_lock = FALSE;
	}
	else
		camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;

	return TRUE;
}

gboolean cam_camera_key_half_press(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	debug_fenter(LOG_UI);

	unsigned int capacity;
	GetCamDevFuncCaps(&capacity, (void*)ad);

	if (!(capacity & CAM_CP_FUNC_FOCUS_MODE))
		return FALSE;

	if (camapp->af_mode != CAM_FOCUS_FACE) {
		cam_mm_stop_focusing();

		if (!cam_mm_set_af_area(ad->af_x, ad->af_y, ad->camera_focus_w, ad->camera_focus_h)) {
			DEBUG_TRACE("cam_mm_set_af_area failed");
			return FALSE;
		}
		DEBUG_TRACE("focus mode = %d", camapp->focus_mode);

		if (!cam_mm_start_focusing(camapp->focus_mode)) {
			cam_critical(LOG_MM, " cam_mm_start_focusing error " );
			return FALSE;
		}
	}
	return TRUE;
}

gboolean cam_camera_key_half_release(void *data)
{
	debug_fenter(LOG_UI);
	return TRUE;
}

gboolean cam_do_capture(void* data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	int state = 0;

	debug_fenter(LOG_UI);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	if (ad->is_rotating)
		return FALSE;/*note: now is rotating*/
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");
	CAM_TA_ACUM_ITEM_BEGIN("  cam_camera_key_press", 0);

	if (ad->continuous_af_timer) {
		REMOVE_TIMER(ad->continuous_af_timer);
		ad->continuous_af_timer = ecore_timer_add(FOCUS_FOCUSED_TIME_OUT, __cam_continuous_af_timer_cb, ad);
	}

	if (camapp->camera_mode == CAM_CAMERA_MODE) {
		state = cam_mm_get_state();
		cam_debug(LOG_UI, " state = %d", state);
		switch (state) {
		case CAMERA_STATE_PREVIEW:
		case CAMERA_STATE_CAPTURED:
			if (ad->timer_activated) {
				CAM_UI_LOG("timer activated!");
				cam_app_cancel_timer(ad);
				if (!cam_image_capture_start(ad)) {
					return FALSE;
				}
			} else if (camapp->timer > CAM_SETTINGS_TIMER_OFF) {
				CAM_UI_LOG("timer start");
				cam_app_start_timer(ad);
			} else if (!cam_image_capture_start(ad)) {
				return FALSE;
			}

			break;
		case CAMERA_STATE_CAPTURING:
			cam_debug(LOG_UI, "capturing state");
			return TRUE;
			break;
		case CAMERA_STATE_NONE:
		case CAMERA_STATE_CREATED:
			return FALSE;
			break;
		default:
			return FALSE;
			break;

		}
	} else if (camapp->camera_mode == CAM_CAMCORDER_MODE) {


		state = cam_mm_get_state();
		cam_debug(LOG_UI, " state = %d", state);
		switch (state) {
		case RECORDER_STATE_RECORDING:
		case RECORDER_STATE_PAUSED:
			if(!cam_image_capture_start(ad)) {
				HIDE_EVAS_OBJECT(ad->rect_image);
				return FALSE;
			}
			break;
		case RECORDER_STATE_NONE:
		case RECORDER_STATE_CREATED:
		case RECORDER_STATE_READY:
			return FALSE;
		default:
			return FALSE;
			break;

		}
	}

	return TRUE;
}

gboolean cam_do_record(void* data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	int state = 0;

	debug_fenter(LOG_UI);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	if (ad->is_rotating)
		return FALSE;/*note: now is rotating*/
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");
	CAM_TA_ACUM_ITEM_BEGIN("  cam_camera_key_press", 0);

	if (ad->continuous_af_timer) {
		REMOVE_TIMER(ad->continuous_af_timer);
		ad->continuous_af_timer = ecore_timer_add(FOCUS_FOCUSED_TIME_OUT, __focus_guide_destroy, ad);
	}

	if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		state = cam_mm_get_state();
		cam_critical(LOG_UI, " state = %d", state);
		switch (state) {
		case RECORDER_STATE_READY:
			{
				if (ad->timer_activated) {
					CAM_UI_LOG("timer activated!");
					cam_app_cancel_timer(ad);
					if (!cam_video_record_start(ad)) {
						return FALSE;
					}
				} else if (camapp->timer > CAM_SETTINGS_TIMER_OFF) {
					CAM_UI_LOG("timer start");
					cam_app_start_timer(ad);
				} else if (!cam_video_record_start(ad)) {
					return FALSE;
				}
			}
			break;
		case RECORDER_STATE_RECORDING:
			cam_critical(LOG_UI, "RECORDER_STATE_NONE ");
			return FALSE;
			break;
		case RECORDER_STATE_NONE:
			cam_critical(LOG_UI, "RECORDER_STATE_NONE ");
			return FALSE;
			break;
		case RECORDER_STATE_CREATED:
			cam_critical(LOG_UI, "RECORDER_STATE_CREATED ");
			return FALSE;
			break;
		case RECORDER_STATE_PAUSED:
			cam_critical(LOG_UI, "RECORDER_STATE_PAUSED ");
			return FALSE;
			break;
		default:
			return FALSE;
			break;

		}
	}

	return TRUE;
}

gboolean cam_camera_key_press(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	debug_fenter(LOG_UI);

	int state = 0;

	if (ad->is_rotating)
		return FALSE;/*note: now is rotating*/

	CAM_TA_ACUM_ITEM_BEGIN("  cam_camera_key_press", 0);

	if (ad->continuous_af_timer) {
		REMOVE_TIMER(ad->continuous_af_timer);

		if (camapp->camera_mode == CAM_CAMCORDER_MODE)
			ad->continuous_af_timer = ecore_timer_add(FOCUS_FOCUSED_TIME_OUT, __focus_guide_destroy, ad);
		else
			ad->continuous_af_timer = ecore_timer_add(FOCUS_FOCUSED_TIME_OUT, __cam_continuous_af_timer_cb, ad);
	}

	if (camapp->camera_mode == CAM_CAMERA_MODE) {
		state = cam_mm_get_state();
		cam_debug(LOG_UI, " state = %d", state);
		switch (state) {
		case CAMERA_STATE_PREVIEW:
		case CAMERA_STATE_CAPTURED:
			if (ad->timer_activated) {
				CAM_UI_LOG("timer activated!");
			} else if (camapp->timer >
				   CAM_SETTINGS_TIMER_OFF) {
				CAM_UI_LOG("timer start");
				cam_app_start_timer(ad);
			} else if (!cam_image_capture_start(ad)) {
				return FALSE;
			}
			break;
		case CAMERA_STATE_CAPTURING:
			cam_debug(LOG_UI, "capturing state");
			return TRUE;
			break;
		case CAMERA_STATE_NONE:
		case CAMERA_STATE_CREATED:
			return FALSE;
			break;
		default:
			return FALSE;
			break;

		}
	} else if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		state = cam_mm_get_state();
		cam_debug(LOG_UI, " state = %d", state);
		switch (state) {
		case RECORDER_STATE_READY:
			{
				if (ad->timer_activated) {
					CAM_UI_LOG("timer activated!");
				} else if (camapp->timer >
					   CAM_SETTINGS_TIMER_OFF) {
					CAM_UI_LOG("timer start");
					cam_app_start_timer(ad);
				} else if (!cam_video_record_start(ad)) {
					return FALSE;
				}
			}
			break;
		case RECORDER_STATE_RECORDING:
#if 1
			camapp->rec_stop_type = CAM_REC_STOP_NORMAL;
			if (!cam_video_record_stop(ad)) {
				return FALSE;
			}
			return FALSE;
#endif
			break;
		case RECORDER_STATE_NONE:
		case RECORDER_STATE_CREATED:
		case RECORDER_STATE_PAUSED:
			return FALSE;
			break;
		default:
			return FALSE;
			break;

		}
	} else {
		cam_critical(LOG_MM, "Unknow camera mode");
		return FALSE;
	}
	CAM_TA_ACUM_ITEM_END("  cam_camera_key_press", 0);
	return TRUE;
}

gboolean cam_camera_key_release(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	int state = 0;

	debug_fenter(LOG_UI);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	if (camapp->camera_mode == CAM_CAMERA_MODE) {

		state = cam_mm_get_state();
		cam_debug(LOG_UI, " state = %d", state);
		switch (state) {
		case CAMERA_STATE_CAPTURING:
			if (!cam_image_capture_stop(ad)) {
				return FALSE;
			}
			return TRUE;
			break;
		case CAMERA_STATE_PREVIEW:
		case CAMERA_STATE_CREATED:
		case CAMERA_STATE_NONE:
		case CAMERA_STATE_CAPTURED:
			return FALSE;
			break;
		default:
			return FALSE;
			break;

		}
	} else if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
#if 0
		state = cam_mm_get_state();
		switch (state) {
		case MM_CAMCORDER_STATE_PREPARE:
			if (!cam_video_record_start(ad)) {
				return FALSE;
			}
			break;
		case MM_CAMCORDER_STATE_RECORDING:
			if (!cam_video_record_stop(ad)) {
				return FALSE;
			}
			return FALSE;
			break;
		case MM_CAMCORDER_STATE_NONE:
		case MM_CAMCORDER_STATE_NULL:
		case MM_CAMCORDER_STATE_READY:
		case MM_CAMCORDER_STATE_CAPTURING:
		case MM_CAMCORDER_STATE_PAUSED:
			return FALSE;
			break;
		default:
			return FALSE;
			break;

		}
#endif
	} else {
		cam_critical(LOG_MM, "Unknow camera mode");
		return FALSE;
	}

	return TRUE;
}

void cam_reset_focus_coordinate(void* data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	ad->af_x = (ad->win_width / 2) - ad->preview_offset_x;
	ad->af_y = (ad->win_height / 2) - ad->preview_offset_y;

	ad->af_x = (ad->af_x * ad->camfw_video_width) / ad->preview_w;
	ad->af_y = (ad->af_y * ad->camfw_video_height) / ad->preview_h;

	/* init */
	ad->touch_lcd_x = (ad->win_height / 2);
	ad->touch_lcd_y = (ad->win_width / 2);

	ad->af_start_x = 0;
	ad->af_start_y = 0;

	switch (ad->rot_current) {
	case APP_DEVICE_ORIENTATION_0:
		{
			ad->af_start_x = ad->touch_lcd_x;
			ad->af_start_y = ad->touch_lcd_y;
		}
		break;
	case APP_DEVICE_ORIENTATION_180:
		{
			ad->af_start_x = ad->win_height - ad->touch_lcd_x;
			ad->af_start_y = ad->win_width - ad->touch_lcd_y;
		}
		break;
	case APP_DEVICE_ORIENTATION_270:
		{
			ad->af_start_x = ad->touch_lcd_y;
			ad->af_start_y = ad->win_height - ad->touch_lcd_x;
		}
		break;
	case APP_DEVICE_ORIENTATION_90:
		{
			ad->af_start_x = ad->win_width - ad->touch_lcd_y;
			ad->af_start_y = ad->touch_lcd_x;
		}
		break;
	default:
		break;
	}

	/* adjust */
	DEBUG_TRACE("ad->af_start_x=%f, ad->af_start_y=%f", ad->af_start_x, ad->af_start_y);

	ad->camera_focus_w = CAMERA_FOCUS_W * elm_config_scale_get();
	ad->camera_focus_h = CAMERA_FOCUS_H * elm_config_scale_get();
	DEBUG_TRACE("ad->camera_focus_w=%f, ad->camera_focus_h=%f", ad->camera_focus_w, ad->camera_focus_h);

	ad->af_start_x = ad->af_start_x - (ad->camera_focus_w / 2);
	ad->af_start_y = ad->af_start_y - (ad->camera_focus_h / 2);
	DEBUG_TRACE("af area box start x,y =[%f,%f]\n", ad->af_start_x, ad->af_start_y);

	if (ad->rot_current == APP_DEVICE_ORIENTATION_270
	    || ad->rot_current == APP_DEVICE_ORIENTATION_90) {
		if (ad->af_start_x < ad->preview_offset_x) {
			ad->af_start_x = ad->preview_offset_x;
		}
		if (ad->af_start_y < ad->preview_offset_y) {
			ad->af_start_y = ad->preview_offset_y;
		}
		if ((ad->af_start_x + ad->camera_focus_w) >
		    (ad->preview_w + ad->preview_offset_x)) {
			ad->af_start_x =
			    (ad->preview_w + ad->preview_offset_x) -
			    ad->camera_focus_w;
		}
		if ((ad->af_start_y + ad->camera_focus_h) >
		    (ad->preview_h + ad->preview_offset_y)) {
			ad->af_start_y =
			    (ad->preview_h + ad->preview_offset_y) -
			    ad->camera_focus_h;
		}

	} else {
		if (ad->af_start_y < ad->preview_offset_x) {
			ad->af_start_y = ad->preview_offset_x;
		}
		if (ad->af_start_x < ad->preview_offset_y) {
			ad->af_start_x = ad->preview_offset_y;
		}
		if ((ad->af_start_y + ad->camera_focus_h) >
		    (ad->preview_w + ad->preview_offset_x)) {
			ad->af_start_y =
			    (ad->preview_w + ad->preview_offset_x) -
			    ad->camera_focus_h;
		}
		if ((ad->af_start_x + ad->camera_focus_w) >
		    (ad->preview_h + ad->preview_offset_y)) {
			ad->af_start_x =
			    (ad->preview_h + ad->preview_offset_y) -
			    ad->camera_focus_w;
		}
	}


}

Eina_Bool cam_continuous_af_start(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");

	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, ECORE_CALLBACK_CANCEL, "camapp_handle is NULL");

	/* cam_mm_set_af_area include init focusing */
	DEBUG_TRACE("start continuous AF");
	if (cam_mm_set_af_area(ad->af_x, ad->af_y, ad->camera_focus_w, ad->camera_focus_h)) {
		DEBUG_TRACE("cam_mm_set_af_area success!");
		/*focus guide update*/
	} else {
		DEBUG_TRACE("cam_mm_set_af_area error!");
	}

	camapp->focus_mode = CAM_FOCUS_MODE_CONTINUOUS;

	if (!cam_mm_start_focusing(camapp->focus_mode)) {
		cam_critical(LOG_MM, "cam_mm_start_focusing error");
	}

	return ECORE_CALLBACK_CANCEL;
}

Eina_Bool cam_volume_key_press(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	if (camapp == NULL) {
		if (ad->longpress_timer)
			ad->longpress_timer = NULL;
		return ECORE_CALLBACK_CANCEL;
	}

	if (ad->cancel_key_press == TRUE) {
		if (ad->longpress_timer)
			ad->longpress_timer = NULL;
		return ECORE_CALLBACK_CANCEL;
	}

	if(ad->is_rotating){
		cam_critical(LOG_MM, "rotating...");
		if (ad->longpress_timer)
			ad->longpress_timer = NULL;
		return ECORE_CALLBACK_CANCEL;
	}

	if (camapp->touch_af_state == CAM_TOUCH_AF_STATE_DOING) {
		cam_critical(LOG_UI, "touch_af_state is [%d], do not zoom", camapp->touch_af_state);
		return ECORE_CALLBACK_CANCEL;
	}

	DEL_EVAS_OBJECT(ad->focus_edje);
	cam_mm_stop_focusing();

	int state = 0;
	gboolean up_key = ad->up_key;
	debug_fenter(LOG_UI);

	state = cam_mm_get_state();
	cam_debug(LOG_UI, " state = %d", state);
	if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		switch (state) {
		case RECORDER_STATE_RECORDING:
		case RECORDER_STATE_PAUSED:
		case RECORDER_STATE_READY:
			{
				if (!camapp->zoom_lock
				    && camapp->recording_mode != CAM_RECORD_SLOW) {
					zoom_in(ad, up_key, 1);
				}
			}
			break;
		case RECORDER_STATE_NONE:
		case RECORDER_STATE_CREATED:
			break;
		default:
			break;
		}
	} else if(camapp->camera_mode == CAM_CAMERA_MODE) {
		switch (state) {
		case CAMERA_STATE_PREVIEW:
		case CAMERA_STATE_CAPTURED:
			{
				if (!camapp->zoom_lock
				    && camapp->recording_mode != CAM_RECORD_SLOW) {
					zoom_in(ad, up_key, 1);
				}

			}
			break;
		case CAMERA_STATE_NONE:
		case CAMERA_STATE_CREATED:
		case CAMERA_STATE_CAPTURING:
			break;
		default:
			break;
		}

	}


	if (ad->longpress_timer)
		ecore_timer_interval_set(ad->longpress_timer, ZOOM_LONG_PRESS_INTERVAL);

	return ECORE_CALLBACK_RENEW;
}

static gboolean cam_power_key_press(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	power_lock_state(POWER_STATE_SCREEN_OFF, 0);

	debug_fenter(LOG_UI);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	if (ad->mm_state < CAMERA_STATE_PREVIEW) {
		goto lock_and_exit;
	} else if (ad->mm_state == CAMERA_STATE_PREVIEW) {
		goto lock_and_exit;
	} else if (ad->mm_state > CAMERA_STATE_PREVIEW) {
		if (camapp->camera_mode == CAM_CAMERA_MODE) {
			DEBUG_TRACE("camera mode");
		} else {
			camapp->rec_stop_type = CAM_REC_STOP_POWER_KEY;
			if (!cam_video_record_stop(ad)) {
				DEBUG_TRACE("record stop fail");
			}
		}
	}
	return TRUE;

 lock_and_exit:
	power_unlock_state(POWER_STATE_SCREEN_OFF);

	return TRUE;
}
#if 0
static gboolean __cam_end_key_grab_init(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	Ecore_X_Display *disp = NULL;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	cam_retvm_if(ad->main_xid <= 0, FALSE, "main_xid <= 0");

	disp = ecore_x_display_get();
	cam_retvm_if(disp == NULL, FALSE, "ecore_x_display_get fail");

	if (utilx_grab_key(disp, ad->main_xid, KEY_END, SHARED_GRAB) == -1) {
		cam_critical(LOG_SYS, "%s key grap fail", KEY_END);
	}

	return TRUE;
}
#endif
gboolean cam_key_grab_init(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	Ecore_X_Display *disp = NULL;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	cam_retvm_if(ad->main_xid <= 0, FALSE, "main_xid <= 0");
	int success = 0;
	int ret = TRUE;

	if (ad->isGrabed)
		return TRUE;

	DEBUG_TRACE("key_grab_init############################");

	ad->cancel_key_press = FALSE;

	disp = ecore_x_display_get();
	cam_retvm_if(disp == NULL, FALSE, "ecore_x_display_get fail");

	/* volume key */
	if (utilx_grab_key(disp, ad->main_xid, KEY_VOLUMEUP, TOP_POSITION_GRAB) != success) {
		cam_critical(LOG_SYS, "%s key grap fail", KEY_VOLUMEUP);
		ret = FALSE;
	}
	if (utilx_grab_key(disp, ad->main_xid, KEY_VOLUMEDOWN, TOP_POSITION_GRAB) != success) {
		cam_critical(LOG_SYS, "%s key grap fail", KEY_VOLUMEDOWN);
		ret = FALSE;
	}

	#if 0
	if (vconf_set_int(VCONFKEY_STARTER_USE_VOLUME_KEY, 1))
		cam_critical(LOG_SYS, "VCONFKEY_STARTER_USE_VOLUME_KEY set fail");
	#endif

	/* camera key */
	if (utilx_grab_key(disp, ad->main_xid, KEY_CAMERA, TOP_POSITION_GRAB)  != success) {
		cam_critical(LOG_SYS, "%s key grap fail", KEY_CAMERA);
		ret = FALSE;
	}
	if (utilx_grab_key(disp, ad->main_xid, KEY_CONFIG, TOP_POSITION_GRAB)  != success) {
		cam_critical(LOG_SYS, "%s key grap fail", KEY_CONFIG);
		ret = FALSE;
	}
	/* power key */
	if (utilx_grab_key(disp, ad->main_xid, KEY_POWER, SHARED_GRAB) != success) {
		cam_critical(LOG_SYS, "%s key grap fail", KEY_POWER);
		ret = FALSE;
	}

	/* etc */
	if (utilx_grab_key(disp, ad->main_xid, KEY_SEND, SHARED_GRAB) != success) {
		cam_critical(LOG_SYS, "%s key grap fail", KEY_SEND);
		ret = FALSE;
	}
	if (utilx_grab_key(disp, ad->main_xid, KEY_END, SHARED_GRAB) != success) {
		cam_critical(LOG_SYS, "%s key grap fail", KEY_END);
		ret = FALSE;
	}

	ad->isGrabed = TRUE;
	return ret;
}

gboolean cam_key_grab_deinit(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	Ecore_X_Display *disp = NULL;
	int success = 0;
	int ret = TRUE;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	cam_retvm_if(ad->main_xid <= 0, FALSE, "main_xid <= 0");

	if (!ad->isGrabed)
		return TRUE;
	DEBUG_TRACE("key_grab_deinit############################");

	disp = ecore_x_display_get();
	cam_retvm_if(disp == NULL, FALSE, "ecore_x_display_get fail");

	/* volume key */
	if (utilx_ungrab_key(disp, ad->main_xid, KEY_VOLUMEUP) != success){
		cam_critical(LOG_SYS, "%s key ungrap fail", KEY_VOLUMEUP);
		ret = FALSE;
	}
	if (utilx_ungrab_key(disp, ad->main_xid, KEY_VOLUMEDOWN) != success){
		cam_critical(LOG_SYS, "%s key ungrap fail", KEY_VOLUMEDOWN);
		ret = FALSE;
	}

	/* camera key */
	if (utilx_ungrab_key(disp, ad->main_xid, KEY_CAMERA) != success){
		cam_critical(LOG_SYS, "%s key ungrap fail", KEY_CAMERA);
		ret = FALSE;

	}
	if (utilx_ungrab_key(disp, ad->main_xid, KEY_CONFIG) != success){
		cam_critical(LOG_SYS, "%s key ungrap fail", KEY_CONFIG);
		ret = FALSE;
	}

	/* power key */
	if (utilx_ungrab_key(disp, ad->main_xid, KEY_POWER) != success){
		cam_critical(LOG_SYS, "%s key ungrap fail", KEY_POWER);
		ret = FALSE;
	}
	if (utilx_ungrab_key(disp, ad->main_xid, KEY_PAUSE) != success){
		cam_critical(LOG_SYS, "%s key ungrap fail", KEY_PAUSE);
		ret = FALSE;
	}

	/* etc */
	if (utilx_ungrab_key(disp, ad->main_xid, KEY_SEND) != success){
		cam_critical(LOG_SYS, "%s key ungrap fail", KEY_SEND);
		ret = FALSE;
	}
	if (utilx_ungrab_key(disp, ad->main_xid, KEY_SELECT) != success){
		cam_critical(LOG_SYS, "%s key ungrap fail", KEY_SELECT);
		ret = FALSE;
	}
	if (utilx_ungrab_key(disp, ad->main_xid, KEY_END) != success){
		cam_critical(LOG_SYS, "%s key ungrap fail", KEY_END);
		ret = FALSE;
	}

	ad->isGrabed = FALSE;
	return ret;
}

gboolean cam_app_key_event_init(void *data)
{
	struct appdata *ad = (struct appdata *)data;

	DEBUG_TRACE("cam_app_key_event_init");

	if (ad == NULL) {
		cam_critical(LOG_UI, "appdata is NULL, maybe not created");
		return FALSE;
	}
	if (ad->key_down == NULL) {
		ad->key_down =
		    ecore_event_handler_add(ECORE_EVENT_KEY_DOWN, cam_hard_key_down, ad);
	}
	if (ad->key_up == NULL) {
		ad->key_up =
		    ecore_event_handler_add(ECORE_EVENT_KEY_UP, cam_hard_key_up, ad);
	}

	return TRUE;
}

gboolean cam_app_key_event_deinit(void *data)
{
	struct appdata *ad = (struct appdata *)data;

	DEBUG_TRACE("cam_app_key_event_deinit");

	if (ad == NULL) {
		cam_critical(LOG_UI, "appdata is NULL, maybe not created");
		return FALSE;
	}
	if (ad->key_down) {
		ecore_event_handler_del(ad->key_down);
		ad->key_down = NULL;
	}
	if (ad->key_up) {
		ecore_event_handler_del(ad->key_up);
		ad->key_up = NULL;
	}

	return TRUE;
}

Eina_Bool cam_hard_key_down(void *data, int type, void *event_info)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_DONE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, ECORE_CALLBACK_DONE, "camapp_handle is NULL");

	Ecore_Event_Key *kd = (Ecore_Event_Key *) event_info;
	cam_debug(LOG_UI, "Key name : %s", kd->keyname);

	if (ad->confirm_popup) {
		cam_debug(LOG_UI, "confirm popup exist. ignore key event");
		return ECORE_CALLBACK_DONE;
	}

	if (ad->zoom_edje)
		unload_zoom_edje(ad);

	if (ad->ev_edje)
		unload_ev_edje(ad);

	if (ad->setting_ctxpopup || ad->toolbar_setting_popup) {
		ad->displayed_setting_popup = DISPLAY_NONE_POPUP;
		cam_toolbar_setting_popup_destroy(ad);
	}

	if (ad->edit_shortcuts_popup)
		toolbar_destroy_shortcuts_popup(ad);

	cam_app_timeout_checker_update();

	/*  Camera key Press */
	if (0 == strcmp(kd->keyname, KEY_CANCEL)) {
		ad->cancel_key_press = TRUE;
	}
	if (0 == strcmp(kd->keyname, KEY_CONFIG)) {	/* camera key - full */
		if (!camapp->key_lock) {
			camapp->key_lock = TRUE;
			CAM_TA_ACUM_ITEM_BEGIN("Total capture time", 0);
			CAM_TA_ACUM_ITEM_BEGIN
			    ("        camera key to capture start", 0);
			if (!cam_camera_key_press(ad)) {
				cam_warning(LOG_UI, "cam_camera_key_press failed");
			}
			camapp->key_lock = FALSE;
		}
	}
	/*  Camera key HALF press */
	else if (0 == strcmp(kd->keyname, KEY_CAMERA)) {	/* camera key - half */
		if (!camapp->key_lock) {
			camapp->key_lock = TRUE;

			if (!cam_camera_key_half_press(ad)) {
				cam_warning(LOG_UI, "cam_camera_key_half_press failed");
			}
			camapp->key_lock = FALSE;
		}
	} else if (0 == strcmp(kd->keyname, KEY_VOLUMEUP)) {
		if (camapp->volume_key == CAM_VOLUME_KEY_ZOOM) {
			if (!camapp->key_lock) {
				camapp->key_lock = TRUE;
				ad->up_key = TRUE;
				cam_volume_key_press(ad);
				cam_add_longpress_key_timer(ad);
				camapp->key_lock = FALSE;
			}
		} else {
			cam_toolbar_shutter_button_cb(ad, NULL, "press_shutter_sig", "hard_key");
		}
	} else if (0 == strcmp(kd->keyname, KEY_VOLUMEDOWN)) {
		if (camapp->volume_key == CAM_VOLUME_KEY_ZOOM) {
			if (!camapp->key_lock) {
				camapp->key_lock = TRUE;
				ad->up_key = FALSE;
				cam_volume_key_press(ad);
				cam_add_longpress_key_timer(ad);
				camapp->key_lock = FALSE;
			}
		} else {
			if (!ad->is_recording) {
				cam_toolbar_recording_button_cb(ad, NULL, "click_shutter_sig", "hard_key");
			} else {
				cam_toolbar_recording_stop_button_cb(ad, NULL, "click_shutter_sig", "hard_key");
			}
		}
	} else if (0 == strcmp(kd->keyname, KEY_SELECT)) {

	} else if ((0 == strcmp(kd->keyname, KEY_SELECT))
		   && ad->launching_mode == CAM_LAUNCHING_MODE_EXTERNAL) {
		if (!camapp->key_lock) {
			camapp->key_lock = TRUE;
		}
	} else if (0 == strcmp(kd->keyname, KEY_POWER)) {
#if 0
		if (!camapp->key_lock) {
			camapp->key_lock = TRUE;
			power_unlock_state(POWER_STATE_NORMAL);
			cam_power_key_press(ad);
			camapp->key_lock = FALSE;
		}
#endif
	}

	return ECORE_CALLBACK_DONE;
}

Eina_Bool cam_hard_key_up(void *data, int type, void *event_info)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_DONE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, ECORE_CALLBACK_DONE, "camapp_handle is NULL");

	Ecore_Event_Key *kd = (Ecore_Event_Key *) event_info;
	cam_debug(LOG_UI, "Key name : %s", kd->keyname);

	if (ad->confirm_popup) {
		cam_debug(LOG_UI, "confirm popup exist. ignore key event");
		return ECORE_CALLBACK_DONE;
	}

	cam_app_timeout_checker_update();

	if (0 == strcmp(kd->keyname, KEY_CANCEL)) {
		ad->cancel_key_press = FALSE;
	}

	if(ad->cancel_key_press == TRUE) {
		if (ad->longpress_timer) { /*volume key long press */
			cam_del_longpress_key_timer(ad);
		}
		return ECORE_CALLBACK_DONE;
	}

	if (0 == strcmp(kd->keyname, KEY_CONFIG)) {	/* camera key - full  */
		if (!camapp->key_lock) {
			camapp->key_lock = TRUE;
			if (!cam_camera_key_release(ad)) {
				cam_warning(LOG_UI, "cam_camera_key_release failed");
			}
			camapp->key_lock = FALSE;
		}
	} else if (0 == strcmp(kd->keyname, KEY_CAMERA)) {	/* camera key - half */
		if (!camapp->key_lock) {
			camapp->key_lock = TRUE;
			if (!cam_camera_key_half_release(ad)) {
				cam_warning(LOG_UI, "cam_camera_key_release failed");
			}
			camapp->key_lock = FALSE;
		}
	} else if (0 == strcmp(kd->keyname, KEY_VOLUMEUP)
		   || 0 == strcmp(kd->keyname, KEY_VOLUMEDOWN)) {
		if (camapp->volume_key == CAM_VOLUME_KEY_ZOOM) {
			if (!camapp->key_lock) {
				camapp->key_lock = TRUE;
				cam_del_longpress_key_timer(ad);
				camapp->key_lock = FALSE;
			}
		} else {
			cam_toolbar_shutter_button_cb(ad, NULL, "release_shutter_sig", "hard_key");
		}
	}
	return ECORE_CALLBACK_DONE;
}

Eina_Bool cam_mouse_button_down(void *data, void *event_info)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, EINA_FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, EINA_FALSE, "camapp_handle is NULL");

	if (ad->pinch_edje) {
		if (ad->focus_edje)
			edje_object_signal_emit(_EDJ(ad->focus_edje), "focus,hide", "program");
		return FALSE;
	}

	Evas_Event_Mouse_Down *md = (Evas_Event_Mouse_Down *) event_info;

	switch (ad->rot_current) {
	case APP_DEVICE_ORIENTATION_0:
		{
			ad->touch_lcd_x = md->canvas.x; /* LCD x */
			ad->touch_lcd_y = md->canvas.y; /* LCD y */
		}
		break;
	case APP_DEVICE_ORIENTATION_180:
		{
			ad->touch_lcd_x = ad->win_height - md->canvas.x; /* LCD x */
			ad->touch_lcd_y = ad->win_width - md->canvas.y; /* LCD y */
		}
		break;
	case APP_DEVICE_ORIENTATION_270:
		{
			ad->touch_lcd_x = ad->win_height - md->canvas.y; /* LCD x */
			ad->touch_lcd_y = md->canvas.x; /* LCD y */

		}
		break;
	case APP_DEVICE_ORIENTATION_90:
		{
			ad->touch_lcd_x = md->canvas.y; /* LCD x */
			ad->touch_lcd_y = ad->win_width - md->canvas.x; /* LCD y */
		}
		break;
	default:
		break;
	}

	ad->af_x = ad->touch_lcd_y - ad->preview_offset_x;
	ad->af_y = ad->preview_h - ad->touch_lcd_x;

	ad->af_x = (ad->af_x * ad->camfw_video_width) / ad->preview_w;
	ad->af_y = (ad->af_y * ad->camfw_video_height) / ad->preview_h;

	DEBUG_TRACE("*************************************************************************************");
	DEBUG_TRACE("touched lcd x,y=[%d,%d] af x,y=[%d,%d]\n", ad->touch_lcd_x, ad->touch_lcd_y, ad->af_x, ad->af_y);
	DEBUG_TRACE("*************************************************************************************");

	int state = cam_mm_get_state();
	if (!(camapp->camera_mode == CAM_CAMERA_MODE && state == CAMERA_STATE_CAPTURING) ){
		if (camapp->enable_touch_af == TRUE
			&& camapp->touch_af_state == CAM_TOUCH_AF_STATE_NONE) {
			REMOVE_TIMER(ad->continuous_af_timer);
			cam_app_draw_af_box(ad);

			camapp->focus_state = CAM_FOCUS_STATUS_RELEASED;
			cam_app_focus_guide_create(ad);
			cam_app_focus_guide_update(ad);
			cam_ui_effect_utils_set_zoom_effect(ad->focus_edje,
								CAM_FOCUS_EDJE_ZOOM_EFFECT_START_RATE,
								CAM_FOCUS_EDJE_ZOOM_EFFECT_END_RATE,
								CAM_FOCUS_EDJE_ZOOM_EFFECT_DURATION);
			camapp->touch_af_state = CAM_TOUCH_AF_STATE_READY;
		}
	} else
		DEBUG_TRACE("camera mode[%d], camera state[%d] not available focus",camapp->camera_mode,state);

	return EINA_TRUE;
}

Eina_Bool cam_mouse_button_up(void *data, void *event_info)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, EINA_FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, EINA_FALSE, "camapp is NULL");

	if (ad->pinch_edje) {
		if (ad->focus_edje)
			edje_object_signal_emit(_EDJ(ad->focus_edje), "focus,hide", "program");
		return FALSE;
	}

	if (camapp->touch_af_state == CAM_TOUCH_AF_STATE_READY) {
		camapp->touch_af_state = CAM_TOUCH_AF_STATE_DOING;
		cam_app_draw_af_box(ad);
		evas_object_show(ad->focus_edje);
		cam_ui_effect_utils_set_zoom_effect(ad->focus_edje,
								CAM_FOCUS_EDJE_ZOOM_EFFECT_END_RATE,
								CAM_FOCUS_EDJE_ZOOM_EFFECT_START_RATE,
								CAM_FOCUS_EDJE_ZOOM_EFFECT_DURATION);

		if (camapp->camera_mode == CAM_CAMCORDER_MODE && ad->is_recording) {
			if (ad->caf_button)
				cam_toolbar_show_cafbutton(ad, TRUE);
		}

		cam_camera_touch_af_press(ad);
	}
	return EINA_TRUE;
}

void cam_app_set_config_group(gint mode)
{
	cam_debug(LOG_UI, "mode : %d", mode);

	if (mode == CAM_CAMERA_MODE) {
		cam_config_set_group_name(CAM_CONFIG_TYPE_PREVIEW, "still");
	} else {
		cam_config_set_group_name(CAM_CONFIG_TYPE_PREVIEW, "video");
	}

	debug_fleave(LOG_UI);

	return;
}

int cam_app_get_latest_mode(void)
{
	cam_config_set_group_name(CAM_CONFIG_TYPE_COMMON, "common");
	int last_mode =
	    cam_config_get_int_by_type(CAM_CONFIG_TYPE_COMMON, "mode",
				       CAM_CAMERA_MODE);

	debug_msg(LOG_UI, "last mode:%d", last_mode);
	return last_mode;
}

const gchar *cam_app_get_target_path(void)
{
	CamAppData *camapp = NULL;

	camapp = cam_handle_get();

	if (camapp) {

		const gchar *default_path = NULL;
		switch (camapp->storage) {
		case CAM_STORAGE_INTERNAL:
			default_path = cam_file_get_internal_image_path();
			break;
		case CAM_STORAGE_EXTERNAL:
			default_path = cam_file_get_external_image_path();
			break;
		default:
			cam_critical(LOG_UI, "Unknow storage type : %d", camapp->storage);
			break;
		}

		cam_debug(LOG_UI, "target path : [%s]", default_path);
		return default_path;
	} else {
		cam_critical(LOG_UI, "camapp handle is NULL");
		return NULL;
	}
}

gchar *cam_app_get_last_filename(void)
{
	CamAppData *camapp = NULL;
	gchar *last_file_path = NULL;
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	cam_retvm_if(ad == NULL, NULL, "appdata is NULL");

	camapp = cam_handle_get();
	cam_retvm_if(camapp == NULL, NULL, "cam_handle is NULL");

	last_file_path = cam_file_get_last_file_path(ad, cam_app_get_target_path());

	if (last_file_path) {
		cam_debug(LOG_UI, "last_file_path  : %s", last_file_path);
	} else {
		cam_critical(LOG_UI, "last_file_path is NULL");
		return NULL;
	}
	return last_file_path;
}

gchar *cam_app_get_next_filename(CamFileExtention extension)
{

	CamAppData *camapp = NULL;
	gchar *new_filename = NULL;
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	cam_retvm_if(ad == NULL, NULL, "appdata is NULL");

	camapp = cam_handle_get();
	cam_retvm_if(camapp == NULL, NULL, "cam_handle is NULL");
	int mm_state = 0;
	mm_state = cam_mm_get_state();

	if( extension == CAM_FILE_EXTENTION_IMAGE){
		new_filename = cam_file_get_next_filename(cam_app_get_target_path(), INAGE_FILE_NAME, IMAGE_FILE_EXTENSION);
	} else {
		if ((camapp->recording_mode == CAM_RECORD_MMS)
				|| (camapp->recording_mode == CAM_RECORD_SELF_MMS))
			new_filename = cam_file_get_next_filename(cam_app_get_target_path(), VIDEO_FILE_NAME, VIDEO_FILE_EXTENSION_3GP);
		else
			new_filename = cam_file_get_next_filename(cam_app_get_target_path(), VIDEO_FILE_NAME, VIDEO_FILE_EXTENSION_MP4);
	}

	if (new_filename) {
		cam_debug(LOG_UI, "next filename : %s", new_filename);
	} else {
		cam_critical(LOG_UI, "new_filename is NULL");
	}

	return new_filename;
}

static void __cam_preview_cb(camera_preview_data_s *preview_frame, void *user_data)
{

	cam_retm_if(user_data == NULL, "data is null");
	struct appdata *ad = (struct appdata *)user_data;

	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is null");
}

static void __cam_state_change_cb(camera_state_e previous, camera_state_e current,
        bool by_policy, void *user_data)
{
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;
	ad = (struct appdata *)user_data;
	cam_retm_if(ad == NULL, "camapp is null");
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is null");
	DEBUG_TRACE("current= %d, previous = %d, ad->enable_mode_change = %d",  current, previous, ad->enable_mode_change);

	if (current == CAMERA_STATE_PREVIEW) {
		ad->enable_mode_change = TRUE;
	} else {
		ad->enable_mode_change = FALSE;
	}

	DEBUG_TRACE("current= %d, previous = %d, ad->enable_mode_change = %d", current, previous, ad->enable_mode_change);
	cam_app_camera_state_manager(previous, current, by_policy);

}

static void __cam_focus_cb(camera_focus_state_e state, void *user_data)
{
	struct appdata *ad = (struct appdata *)user_data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is NULL");

	cam_debug(LOG_MM, " Focus state changed to [%d]", state);

	if (ad->ug_state == CAM_UG_PAUSE_STATE)
		return;

	camapp->focus_state = state ;

	if (ad->is_rotating == FALSE) {
		if (evas_object_visible_get(ad->focus_edje) == TRUE)
			cam_app_focus_guide_update(ad);
	}

	switch (state) {
	case CAMERA_FOCUS_STATE_RELEASED:
		cam_debug(LOG_MM, "release");
		break;
	case CAMERA_FOCUS_STATE_ONGOING:
		cam_debug(LOG_MM, "ongoing");
		break;
	case CAMERA_FOCUS_STATE_FOCUSED:
		cam_debug(LOG_MM, "focused");
		if (camapp->camera_mode == CAM_CAMERA_MODE && ad->mm_state < CAMERA_STATE_CAPTURING) {
			if ((camapp->focus_mode == CAM_FOCUS_MODE_TOUCH_AUTO
					|| camapp->focus_mode == CAM_FOCUS_MODE_HALFSHUTTER)
				&& camapp->shutter_sound != CAM_SETTINGS_SOUND_OFF)
					cam_sound_play (CAM_SOUND_EFFECT_AF_OK, ad);

			if (camapp->focus_mode == CAM_FOCUS_MODE_TOUCH_AUTO) {
				if (camapp->touch_af_state == CAM_TOUCH_AF_STATE_READY
					||camapp->touch_af_state == CAM_TOUCH_AF_STATE_DOING)
					camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;

				REMOVE_TIMER(ad->continuous_af_timer);
				ad->continuous_af_timer = ecore_timer_add(FOCUS_FOCUSED_TIME_OUT, __cam_continuous_af_timer_cb, ad);
			}

		} else if (camapp->camera_mode == CAM_CAMCORDER_MODE && ad->mm_state <= RECORDER_STATE_RECORDING) {
			if (camapp->focus_mode == CAM_FOCUS_MODE_TOUCH_AUTO
				&& camapp->shutter_sound != CAM_SETTINGS_SOUND_OFF
				&& ad->mm_state != RECORDER_STATE_RECORDING)
					cam_sound_play (CAM_SOUND_EFFECT_AF_OK, ad);

			if (camapp->focus_mode == CAM_FOCUS_MODE_TOUCH_AUTO) {
				if (camapp->touch_af_state == CAM_TOUCH_AF_STATE_READY
					||camapp->touch_af_state == CAM_TOUCH_AF_STATE_DOING)
					camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;
			}

			REMOVE_TIMER(ad->continuous_af_timer);

			if (ad->is_recording)
				ad->continuous_af_timer = ecore_timer_add(FOCUS_FOCUSED_TIME_OUT, __focus_guide_destroy, ad);
		} else {
			camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;
		}
		break;
	case CAMERA_FOCUS_STATE_FAILED:
		cam_debug(LOG_MM, "failed");
		if (camapp->camera_mode == CAM_CAMERA_MODE && ad->mm_state < CAMERA_STATE_CAPTURING) {
			if ((camapp->focus_mode == CAM_FOCUS_MODE_TOUCH_AUTO
					|| camapp->focus_mode == CAM_FOCUS_MODE_HALFSHUTTER)
				&& camapp->shutter_sound != CAM_SETTINGS_SOUND_OFF)
					cam_sound_play (CAM_SOUND_EFFECT_AF_FAIL, ad);

			if (camapp->focus_mode == CAM_FOCUS_MODE_TOUCH_AUTO) {
				if (camapp->touch_af_state == CAM_TOUCH_AF_STATE_READY
					||camapp->touch_af_state == CAM_TOUCH_AF_STATE_DOING)
					camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;

				REMOVE_TIMER(ad->continuous_af_timer);
				ad->continuous_af_timer = ecore_timer_add(FOCUS_FOCUSED_TIME_OUT, __cam_continuous_af_timer_cb, ad);
			}
		} else if (camapp->camera_mode == CAM_CAMCORDER_MODE && ad->mm_state <= RECORDER_STATE_RECORDING) {
			if (camapp->focus_mode == CAM_FOCUS_MODE_TOUCH_AUTO
				&& camapp->shutter_sound != CAM_SETTINGS_SOUND_OFF
				&& ad->mm_state != RECORDER_STATE_RECORDING)
					cam_sound_play (CAM_SOUND_EFFECT_AF_FAIL, ad);

			if (camapp->focus_mode == CAM_FOCUS_MODE_TOUCH_AUTO) {
				if (camapp->touch_af_state == CAM_TOUCH_AF_STATE_READY
					||camapp->touch_af_state == CAM_TOUCH_AF_STATE_DOING)
					camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;
			}

			REMOVE_TIMER(ad->continuous_af_timer);

			if (ad->is_recording)
				ad->continuous_af_timer = ecore_timer_add(FOCUS_FOCUSED_TIME_OUT, __focus_guide_destroy, ad);
		} else {
			camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;
		}
		break;
	default:
		break;
	}
}

static void __cam_capture_cb(camera_image_data_s* image,
	camera_image_data_s* postview,
	camera_image_data_s* thumbnail,
	void *user_data)
{
	struct appdata *ad = (struct appdata *)user_data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is NULL");
	if (camapp->af_mode == CAM_FOCUS_FACE) {
		cam_app_stop_video_stream();
	}
	gchar *filename = NULL;
	FILE *fp = NULL;
	if ((image->format == CAMERA_PIXEL_FORMAT_YUYV)
	    || (image->format == CAMERA_PIXEL_FORMAT_NV12)) {
		cam_debug(LOG_UI,
			  "got raw data - format [%d] data [%p], length [%d], width [%d], height [%d]",
			  image->format, image->data, image->size, image->width,
			  image->height);
		/* encode data */
		/* MMImageJpegEncodeToFile(filename, src->data, src->width,src->height, src->format, 90); */
	} else if (image->format == CAMERA_PIXEL_FORMAT_JPEG) {
		cam_debug(LOG_UI,
			  "got JPEG data - data [%p], length [%d], width [%d], height [%d]",
			  image->data, image->size, image->width, image->height);
		if (camapp->camera_mode == CAM_CAMERA_MODE
			&& camapp->shooting_mode == CAM_SELF_SINGLE_MODE) {
			;
		} else {
			cam_app_create_screennail_and_start_animation(user_data);
		}

		/* save file */
		filename = cam_app_get_next_filename(CAM_FILE_EXTENTION_IMAGE);
		if (filename == NULL) {
			cam_critical(LOG_SYS, " Get next filename FAILED");
			return;
		}

		fp = fopen(filename, "w+");
		if (fp == NULL) {
			cam_critical(LOG_SYS, "FileOPEN error!!");
			return;
		} else {
			cam_debug(LOG_SYS, "FileOPEN success");
			if (fwrite(image->data, image->size, 1, fp) != 1) {
				cam_critical(LOG_SYS, "File write error!!");
				fclose(fp);
				return;
			}
			/*fsync(fp->_fileno);*/
			/*block for increasing formance of shot-to-shot */
			cam_debug(LOG_SYS, "File write success");
			fclose(fp);
		}
		if (camapp->filename)
			free(camapp->filename);
		camapp->filename = strdup(filename);
		free(filename);
		filename = NULL;
	}
}

void cam_app_create_capture_complete_ui_idlers(void *data)
{
        struct appdata *ad = (struct appdata *)data;
        cam_ret_if(ad == NULL);
	CamIdlerItem *item = NULL;
	item = (CamIdlerItem *)g_malloc(sizeof(CamIdlerItem));
	cam_ret_if(item == NULL);

	if (item) {
		item->data = data;
		item->idler = ecore_idler_add(cam_image_capture_handle_idler, item);

		if (item->idler)
			ad->capture_cb_list = g_list_append(ad->capture_cb_list, item->idler);

		cam_info(LOG_UI, "image capture idler add : %p ", item->idler);
	}
}

static Eina_Bool __cam_app_progressbar_timer(void *data)
{
        double value=0.0;

        Evas_Object *progressbar = (Evas_Object*) data;
        if (progressbar == NULL) {
                progress_timer = NULL;
                return ECORE_CALLBACK_CANCEL;
        }

        value = elm_progressbar_value_get(progressbar);
        if (value == 1.0) value = 0.0;
        value = value + 0.025;
        elm_progressbar_value_set(progressbar, value);

        return ECORE_CALLBACK_RENEW;
}


void cam_app_create_burst_popup(void *data)
{
#if 1/*TODO: need ui guide, for display popup*/
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;

	ad = (struct appdata *)data;
	cam_ret_if(ad == NULL);
	camapp = ad->camapp_handle;
	cam_ret_if(camapp == NULL);

	if (cam_is_enabled_menu((void*)ad, CAM_MENU_BURST_SHOT_MODE) &&
			(camapp->burst_shot == TRUE) && camapp->continuous_shot_data) {
		ad->is_processing = TRUE;
		REMOVE_TIMER(ad->continuous_af_timer);
		cam_mm_stop_focusing();
		cam_toolbar_update_shutter_button(ad, TOOLBAR_ITEM_STATE_DIM);

		if (!cam_popup_for_burst_create(ad)) {/*TODO: need ui guide for this popup*/
			cam_debug(LOG_UI, "cam_progress_popup_create() fail");
			return;
		}

		if (!cam_popup_add_progress_bar(ad))
			cam_debug(LOG_UI, "cam_popup_add_progress_bar() fail");

		if (!cam_popup_set_text(ad, dgettext(PACKAGE, "IDS_CAM_BODY_PROCESSING_ING")))
			cam_debug(LOG_UI, "cam_progress_popup_set_text() fail");
	}
	progress_timer = ecore_timer_add(0.01, __cam_app_progressbar_timer, ad->progress_popup_bar);
#endif

}

static void __cam_capture_completed_cb(void *user_data)
{
	DEBUG_TRACE();
	struct appdata *ad = (struct appdata *)user_data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "cam_handle is NULL");

	if (camapp->af_mode == CAM_FOCUS_FACE) {
		cam_app_run_video_stream();
	}

	if (camapp->camera_mode == CAM_CAMERA_MODE) {
        if (cam_is_enabled_menu((void*)ad, CAM_MENU_BURST_SHOT_MODE) &&
				(camapp->burst_shot == TRUE) &&	camapp->continuous_shot_data) {
			cam_utils_request_main_pipe_handler(ad, NULL, CAM_MAIN_PIPE_OP_TYPE_BURST_SHOT_DISPLAY_POPUP);
			cam_continuous_shot_finish_save_image();
        } else {
			 cam_utils_request_main_pipe_handler(ad, NULL, CAM_MAIN_PIPE_OP_TYPE_BEST_SHOT_IMAGE_HANDLE);
	   }

		DEBUG_TRACE("camapp->focus_mode %d ", camapp->focus_mode);
		if (camapp->focus_mode == CAM_FOCUS_MODE_HALFSHUTTER) {
			REMOVE_TIMER(ad->continuous_af_timer);
			ad->continuous_af_timer = ecore_timer_add(FOCUS_FOCUSED_TIME_OUT, __cam_continuous_af_timer_cb, ad);
		}
		DEBUG_TRACE("camapp->burst_shot %d ", camapp->burst_shot);
		DEBUG_TRACE("camapp->default_capture_mode %d ", camapp->default_capture_mode);
		DEBUG_TRACE("ad->stop_continuous_shot %d ", ad->stop_continuous_shot);

		if (cam_is_enabled_menu((void*)ad, CAM_MENU_BURST_SHOT_MODE)
				&& camapp->burst_shot == TRUE
				&& camapp->default_capture_mode == CAM_CAPTURE_BURST) {
			DEBUG_TRACE("TEST");
		}

		if (ad->ug_state == CAM_UG_PAUSE_STATE){
			cam_critical(LOG_MM, "CAM_UG_PAUSE_STATE");
			return;
		}

		if (!cam_app_preview_start(ad)) {
			cam_critical(LOG_MM, "cam_app_preview_start failed");
			cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA"), cam_app_timeout_notice_response_cb);
			return;
		}
	}else if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		DEBUG_TRACE("MM_MESSAGE_CAMCORDER_VIDEO_SNAPSHOT_CAPTURED");
		ecore_idler_add(cam_capture_on_recording_handle, ad);
	}
	DEBUG_TRACE();
}
static void __cam_interrupted_cb(camera_policy_e policy, camera_state_e previous, camera_state_e current, void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	DEBUG_TRACE("policy is [%d]",policy);

	switch (policy) {
	case CAMERA_POLICY_SOUND:
		DEBUG_TRACE("occur incoming call");
		break;
	case CAMERA_POLICY_SECURITY:
		cam_app_mdm_syspopup(ad);
		break;
	default:
		break;
	}
}

static void __rec_interrupted_cb(recorder_policy_e policy, recorder_state_e previous, recorder_state_e current, void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	DEBUG_TRACE("policy is [%d]",policy);

	switch (policy) {
	case RECORDER_POLICY_SOUND:
		DEBUG_TRACE("occur incoming call");
		break;
	case RECORDER_POLICY_SECURITY:
		cam_app_mdm_syspopup(ad);
		break;
	default:
		break;
	}
}

static void __cam_error_cb(int error, camera_state_e current_state, void *user_data)
{
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;

	ad = (struct appdata *)user_data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is NULL");

	int state = 0;
	state = current_state;
	cam_warning(LOG_MM,"MM ERROR occurs : code [%x], state [%d]",error, state);

	char msg[1024] = { '\0', };

	snprintf(msg, sizeof(msg), "Internal error %x", error);
	cam_app_notice_popup(ad, msg, cam_app_timeout_notice_response_cb);

}

static void __recorder_state_cb(recorder_state_e previous , recorder_state_e current , bool by_policy, void *user_data)
{
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;

	ad = (struct appdata *)user_data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is NULL");
	if (current == RECORDER_STATE_READY) {
		ad->enable_mode_change = TRUE;
	} else {
		ad->enable_mode_change = FALSE;
	}
	cam_app_recorder_state_manager(previous, current, by_policy);
}

void __recording_status_cb(unsigned long long elapsed_time, unsigned long long file_size, void *user_data)
{
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;
	ad = (struct appdata *)user_data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is NULL");
	/* update current time */
	DEBUG_TRACE();
	guint elapsed = 0;
	guint filesize = 0;
	elapsed = elapsed_time / 1000;
	filesize = file_size;
	if (camapp->rec_elapsed < elapsed) {
		GValue value = { 0, };

		cam_debug(LOG_UI, "time updated: %u ", elapsed);
		CAM_GVALUE_SET_UINT(value, elapsed);
		cam_handle_value_set(ad, PROP_REC_TIME, &value);
	}
	if (camapp->rec_filesize < filesize) {
		GValue value = { 0, };

		cam_debug(LOG_UI, "filesize updated: %u ", filesize);
		CAM_GVALUE_SET_UINT(value, filesize);
		cam_handle_value_set(ad, PROP_REC_FILE_SIZE, &value);
	}
}

void __recording_limit_reached_cb(recorder_recording_limit_type_e type, void *user_data)
{
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;
	ad = (struct appdata *)user_data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is NULL");

	DEBUG_TRACE("");
	if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		if (type == RECORDER_RECORDING_LIMIT_FREE_SPACE)
			camapp->rec_stop_type = CAM_REC_STOP_NO_SPACE;
		else if (type == RECORDER_RECORDING_LIMIT_TIME
				|| type == RECORDER_RECORDING_LIMIT_SIZE)
			camapp->rec_stop_type = CAM_REC_STOP_TIME_LIMIT;
		else {
			DEBUG_TRACE("invalid type:%d", type);
			camapp->rec_stop_type = CAM_REC_STOP_TIME_LIMIT;
		}
		ad->recording_commit = ecore_idler_add(cam_video_idler_record_stop, ad);
	}
}

gboolean cam_callback_init(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	debug_fenter(LOG_UI);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "cam_handle is NULL");
	camapp->error_cb = __cam_error_cb;
	camapp->focus_cb = __cam_focus_cb;
	camapp->state_cb = __cam_state_change_cb;
	camapp->preview_cb = __cam_preview_cb;
	camapp->capture_completed_cb = __cam_capture_completed_cb;
	camapp->cam_interrupted_cb = __cam_interrupted_cb;

	camapp->recording_status_cb = __recording_status_cb;
	camapp->recording_state_changed_cb = __recorder_state_cb;
	camapp->recording_limit_reached_cb = __recording_limit_reached_cb;
	camapp->rec_interrupted_cb = __rec_interrupted_cb;

	/*set face detect cb*/
	camapp->face_detect_cb = cam_face_detection_focus_face_detected_cb;
	camapp->capture_cb = __cam_capture_cb;

	int ret = 1;
	if (camapp->camera_mode == CAM_CAMERA_MODE) {
		/*ret &= cam_mm_recorder_unset_state_changed_cb();*/
		ret &= cam_mm_set_preview_cb(camapp->preview_cb, (void*)ad);
		ret &= cam_mm_set_focus_changed_cb(camapp->focus_cb, (void*)ad);
		ret &= cam_mm_set_state_changed_cb(camapp->state_cb, (void*)ad);
		ret &= cam_mm_set_error_cb(camapp->error_cb, (void*)ad);
		ret &= cam_mm_set_camera_interrupted_cb(camapp->cam_interrupted_cb, (void*)ad);
	} else if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		ret &= cam_mm_unset_state_changed_cb();
		ret &= cam_mm_set_focus_changed_cb(camapp->focus_cb, (void*)ad);
		ret &= cam_mm_recorder_set_state_changed_cb(camapp->recording_state_changed_cb, (void*)ad);
		ret &= cam_mm_recorder_set_recording_status_cb(camapp->recording_status_cb, (void*)ad);
		ret &= cam_mm_recorder_set_recording_limit_reached_cb(camapp->recording_limit_reached_cb, (void*)ad);
		ret &= cam_mm_set_recorder_interrupted_cb(camapp->rec_interrupted_cb, (void*)ad);
	}


	return ret;

}
gboolean cam_app_lbs_stop(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp is NULL");

	int ret = FALSE;

	ret = cam_lbs_stop();
	if(ret == FALSE) {
		DEBUG_TRACE("cam_app_lbs_stop failed");
		return FALSE;
	}
	camapp->gps = FALSE;
	camapp->gps_level = cam_lbs_get_state();
	indicator_update_gps(ad);	/* update gps icon */
	if (!cam_mm_remove_geo_tag())
		DEBUG_TRACE("cam_mm_remove_geo_tag failed");

	return TRUE;

}
gboolean cam_app_lbs_start(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp is NULL");

	int ret = FALSE;

	ret = cam_lbs_start(cam_app_update_gps_level, ad);
	if (ret == FALSE) {
		if(camapp->need_gps_popup == TRUE) {
			cam_app_gps_enable_popup(ad,
		      dgettext(PACKAGE, "IDS_CAM_POP_ENABLE_LOCATION_SERVICE_IN_SETTINGS_TO_USE_GPS_TAG"), NULL);
		}
		return FALSE;
	}
	camapp->gps = TRUE;

	REMOVE_TIMER(ad->gps_animation_timer);
	ad->gps_animation_timer = ecore_timer_add(0.5, cam_app_gps_timer_cb, ad);

	return TRUE;

}

static void cam_app_close_ug(void *data)
{
	cam_debug(LOG_UI, " ");
	struct appdata *ad = (struct appdata *)data;
	/* IDS problem */

	cam_info(LOG_UI, "ad->imageviewer_ug : %p", ad->imageviewer_ug);
	if (ad->imageviewer_ug) {
		ug_destroy(ad->imageviewer_ug);
		ad->imageviewer_ug = NULL;
	}
	if (ad->location_ug) {
		ug_destroy(ad->location_ug);
		ad->location_ug = NULL;
	}

	cam_file_init(NULL);
	return;
}

static void __ug_layout_cb(ui_gadget_h ug, enum ug_mode mode, void *priv)
{
	cam_debug(LOG_UI, " ");

	Evas_Object *base;

	if (!ug || !priv)
		return;

	base = ug_get_layout(ug);
	if (!base)
		return;

	switch (mode) {
	case UG_MODE_FULLVIEW:
		evas_object_size_hint_weight_set(base, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
		ug_disable_effect(ug);/*note: disable Image viewer ug effect*/
		evas_object_show(base);
		break;
	default:
		break;
	}
}

void __ug_result_cb(ui_gadget_h ug, service_h result, void *priv)
{
	cam_debug(LOG_UI, " ");

	struct appdata *ad = (struct appdata *)priv;
	cam_retm_if(ad == NULL, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "cam_handle is NULL");

	char *val = NULL;
	ad->path_in_return = false;

	if (ad->imageviewer_ug) {
		if (ad->launching_mode == CAM_LAUNCHING_MODE_EXTERNAL) {
			if (result == NULL) {
				return;
			}

			if ((ad->exe_args->caller) && (strcmp(ad->exe_args->caller, "contacts") == 0)) {
				service_h reply;
				service_create(&reply);

				service_get_extra_data(result, "crop_image_path", &val);
				service_add_extra_data(reply, "crop_image_path", val);
				service_get_extra_data(result, "image_path", &val);
				service_add_extra_data(reply, "image_path", val);

				service_reply_to_launch_request(reply, ad->service_handle, SERVICE_RESULT_SUCCEEDED);
				service_destroy(reply);

				ad->path_in_return = true;
			} else if ((ad->exe_args->caller) && (strcmp(ad->exe_args->caller, "ug-setting-call-efl") == 0)) {
				service_h reply;
				service_create(&reply);

				service_get_extra_data(result, "crop_image_path", &val);
				service_add_extra_data(reply, SERVICE_DATA_SELECTED, val);

				service_reply_to_launch_request(reply, ad->service_handle, SERVICE_RESULT_SUCCEEDED);
				service_destroy(reply);

				ad->path_in_return = true;
			} else {
				/* get result value. */
				service_get_extra_data(result, "Result", &val);

				if (strcmp(val, "Ok") == 0) {
					ad->path_in_return = true;
				}
				else if (strcmp(val, "Cancel") == 0) {
					ad->path_in_return = false;
				}
			}
		}
	}
}

void __ug_destroy_cb(ui_gadget_h ug, void *priv)
{
	cam_debug(LOG_UI, " ");

	if (!ug || !priv)
		return;

	struct appdata *ad = (struct appdata *)priv;
	cam_retm_if(ad == NULL, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is NULL");

	if (ad->path_in_return) {
		elm_win_lower(ad->win_main);
		cam_app_exit(ad);
	} else {
		ad->ug_is_deleting_process = TRUE;

		cam_app_timeout_checker_init(ad);

		if (ad->imageviewer_ug) {
			ug_destroy(ad->imageviewer_ug);
			ad->imageviewer_ug = NULL;
		}

		if (ad->location_ug) {
			ug_destroy(ad->location_ug);
			ad->location_ug = NULL;
			camapp->need_gps_popup = FALSE;
			if (!cam_app_lbs_start(ad)) {
				if (!cam_app_lbs_stop(ad))
					DEBUG_TRACE("The LBS failed to stop");
			}
		}

		cam_app_start_rotate(ad, false);

		ecore_idler_add(__ug_destory_postprocessing, ad);
	}

	return;
}

Eina_Bool __ug_destory_postprocessing(void *data)
{
	struct appdata *ad = data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	ad->ug_is_deleting_process = TRUE;
	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE,  "cam_handle is NULL");

	cam_app_focus_guide_create(ad);
	show_toolbar_edje(ad);

	if (!cam_file_check_exists(camapp->filename)) {
		free(camapp->filename);
		camapp->filename = NULL;
	}

	if (!cam_app_preview_start(ad)) {
		cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA"), cam_app_timeout_notice_response_cb);
	}

	cam_mm_set_mdnie_mode(TRUE);

	if (camapp->outdoor_visibility)
		cam_mm_set_outdoor_visibility(TRUE);

	power_lock_state(POWER_STATE_NORMAL, 0);

	if (camapp->camera_mode == CAM_CAMERA_MODE) {
		if(camapp->af_mode == CAM_FOCUS_FACE){
		/*start face detection*/
			if (cam_mm_is_supported_face_detection()) {
				cam_mm_start_camera_face_detection(camapp->face_detect_cb, (void *)ad);
				if (!cam_mm_set_preview_cb(cam_face_detection_focus_start_stream, (void*)ad)) {
					DEBUG_TRACE("preview callback set error");
				}
				cam_app_run_video_stream();
			} else {
				DEBUG_TRACE("not support face detect mode");
			}
		}
	}
	if (!cam_key_grab_init(ad))
		DEBUG_TRACE("cam_key_grab_init fail");
	cam_app_key_event_init(ad);

	cam_app_update_quickview_icon(ad);
	cam_file_init(NULL);
	ad->ug_is_deleting_process = FALSE;

	return ECORE_CALLBACK_CANCEL;
}

gboolean cam_app_run_location_ug(void *data)
{
	DEBUG_TRACE("START");

	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE,  "cam_handle is NULL");

	if (ad->ug_is_deleting_process) /*NOTE:before old ug is not deleted completely, should not create new ug*/
		return FALSE;

	if (ad->location_ug) {
		ug_destroy(ad->location_ug);
		ad->location_ug = NULL;
	}

	DEL_EVAS_OBJECT(ad->focus_edje);

	struct ug_cbs cbs = { 0, };

	cbs.layout_cb = __ug_layout_cb;
	cbs.result_cb = __ug_result_cb;
	cbs.destroy_cb = __ug_destroy_cb;
	cbs.priv = (void *)data;

	/* Create UI gadget */
	ad->location_ug = ug_create(NULL, LOCATION_UG_NAME, UG_MODE_FULLVIEW, NULL, &cbs);

	if (!ad->location_ug) {
		cam_critical(LOG_SYS, "location UI Gadget create fail...");
		return FALSE;
	} else {
		if (ad->location_ug) {
			cam_mm_set_mdnie_mode(FALSE);

			if (camapp->outdoor_visibility)
				cam_mm_set_outdoor_visibility(FALSE);

			cam_app_preview_stop();
			power_unlock_state(POWER_STATE_NORMAL);
		} else {
			cam_warning(LOG_UI, "Cannot create location_ug");
			cam_file_init(NULL);
			return FALSE;
		}
	}

	cam_app_timeout_checker_remove();

	return TRUE;
}
gboolean cam_app_run_image_viewer_ug(void *data, char *file_path, gboolean launch_special_view)
{
	DEBUG_TRACE("START");

	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE,"camapp is NULL");
	cam_retvm_if(file_path == NULL, FALSE, "file_path is NULL");

	if (ad->ug_is_deleting_process) /*NOTE:before old ug is not deleted completely, should not create new ug*/
		return FALSE;

	cam_debug(LOG_UI, "path :%s", file_path);

	if (ad->imageviewer_ug) {
		return FALSE;/*NOTE: ug is login, not create ug again.*/
	}
	if (ad->is_rotating == TRUE) {
		return FALSE; /*note: while rotating, could not create image view ug*/
	}

	DEL_EVAS_OBJECT(ad->focus_edje);

	struct ug_cbs cbs = { 0, };

	cbs.layout_cb = __ug_layout_cb;
	cbs.result_cb = __ug_result_cb;
	cbs.destroy_cb = __ug_destroy_cb;
	cbs.priv = (void *)data;

	/* param */
	if (ad->imageviewer_service)
		service_destroy(ad->imageviewer_service);

	int ret = service_create(&ad->imageviewer_service);
	if (ret != SERVICE_ERROR_NONE) {
		cam_critical(LOG_UI, "service_create error [%d]", ret);
		return FALSE;
	}

	if (ad->launching_mode == CAM_LAUNCHING_MODE_EXTERNAL) {
		if ((ad->exe_args->caller) && (strcmp(ad->exe_args->caller, "contacts") == 0)) {
			service_add_extra_data(ad->imageviewer_service, IMAGE_VIEWER_VIEW_MODE_KEY_NAME, "SETAS");
			service_add_extra_data(ad->imageviewer_service, IMAGE_VIEWER_SET_AS_TYPE, "CallerID");
		} else if ((ad->exe_args->caller) && (strcmp(ad->exe_args->caller, "ug-setting-call-efl") == 0)) {
			service_add_extra_data(ad->imageviewer_service, IMAGE_VIEWER_VIEW_MODE_KEY_NAME, "SETAS");
			service_add_extra_data(ad->imageviewer_service, IMAGE_VIEWER_SET_AS_TYPE, "VideoCallID");
			service_add_extra_data(ad->imageviewer_service, IMAGE_VIEWER_RESOLUTION, "176x144");
		} else {
			service_add_extra_data(ad->imageviewer_service, IMAGE_VIEWER_VIEW_MODE_KEY_NAME, "DISPLAY");
		}
	} else if (ad->launching_mode == CAM_LAUNCHING_MODE_NORMAL) {
		service_add_extra_data(ad->imageviewer_service, IMAGE_VIEWER_VIEW_MODE_KEY_NAME, "CAMERA");
	}

	service_add_extra_data(ad->imageviewer_service, IMAGE_VIEWER_FILE_PATH_KEY_NAME, file_path);

	/* Create UI gadget */
	ad->imageviewer_ug = ug_create(NULL, IMAGE_VIEWER_UG_NAME, UG_MODE_FULLVIEW, ad->imageviewer_service, &cbs);

	if (!ad->imageviewer_ug) {
		cam_critical(LOG_SYS, "image viewer UI Gadget create fail...");
		return FALSE;
	} else {
		if (ad->imageviewer_ug) {
			cam_app_key_event_deinit(ad);
			if(!cam_key_grab_deinit(ad)){
				DEBUG_TRACE("cam_key_grab_deinit fail");
			}
			cam_mm_set_mdnie_mode(FALSE);

			if (camapp->outdoor_visibility)
				cam_mm_set_outdoor_visibility(FALSE);

			cam_app_preview_stop();
			power_unlock_state(POWER_STATE_NORMAL);
		} else {
			cam_warning(LOG_UI, "Cannot create imageviewer ug");
			cam_file_init(NULL);
			return FALSE;
		}
	}

	if(camapp->af_mode == CAM_FOCUS_FACE){
		cam_face_detection_reset();
	}
	DEBUG_TRACE("END");

	cam_app_timeout_checker_remove();

	return TRUE;
}

gboolean cam_app_run_media_browser(void *data, gchar *filename)
{
	cam_debug(LOG_UI, "filename = %s", filename);
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	int state = 0;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "cam_handle is NULL");

	debug_fenter(LOG_UI);

	state = cam_mm_get_state();
	if (state > CAMERA_STATE_PREVIEW) {
		cam_warning(LOG_MM, "Invaild state : %d", state);
		return FALSE;
	}

	if (!cam_app_run_image_viewer_ug(ad, cam_app_get_last_filename(), FALSE)) {
		DEBUG_TRACE("cam_app_run_image_viewer_ug failed");
		return FALSE;
	}

	if (camapp->thumbnail_name) {	/*  Some image is deleted from image viewer and galler -> BS  */
		free(camapp->thumbnail_name);
		camapp->thumbnail_name = NULL;
	}

	return TRUE;
}

gboolean cam_app_clear_engine_data(void *data, gboolean release)
{
#ifndef	CAMERA_MACHINE_I686

	/* release is not used */
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;

	cam_debug(LOG_UI, "");

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "cam_handle is NULL");

#endif
	return TRUE;
}

gboolean cam_app_check_wide_resolution(int id)
{

	gfloat get_value = (HIWORD(id) * 3.0) / (LOWORD(id) * 4.0);
	if (ABS(get_value - 1.0) < CAM_EPSINON
	    || ABS((gfloat)((HIWORD(id) * 25.0) / (LOWORD(id) * 36.0)) - 1.0) < CAM_EPSINON) {
		return FALSE;
	}

	return TRUE;

}

gboolean cam_app_is_skip_video_stream()
{				/*if true , must finish function in stream callback function */
	return video_stream_skip_flag;
}

void cam_app_stop_video_stream()
{
	video_stream_skip_flag = TRUE;
}

void cam_app_run_video_stream()
{
	video_stream_skip_flag = FALSE;
}

Eina_Bool _auto_shot_idle_cb(void *data)
{
	debug_fenter(LOG_CAM);
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	gboolean capture_result = false;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "cam_handle is NULL");

	if (ad->auto_shot_idle) {
		ecore_idler_del(ad->auto_shot_idle);
		ad->auto_shot_idle = NULL;
	}

	cam_warning(LOG_CAM, "position state not enough");
	debug_fleave(LOG_CAM);

	return ECORE_CALLBACK_CANCEL;
}

gboolean cam_app_create_progressbar(void *data)
{
	struct appdata *ad = (struct appdata *)(data);
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	cam_debug(LOG_UI, "");

	cam_app_destroy_progressbar(ad);

	ad->progressbar = elm_progressbar_add(ad->ug_base);
	cam_retvm_if(ad->progressbar == NULL, FALSE, "Cannot create progressbar object\n");

	elm_object_style_set(ad->progressbar, "list_progress");
	evas_object_size_hint_align_set(ad->progressbar, EVAS_HINT_FILL, EVAS_HINT_FILL);

	evas_object_show(ad->progressbar);

	return TRUE;
}

gboolean cam_app_set_progressbar_value(void *data, double value)
{
	struct appdata *ad = (struct appdata *)(data);
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	if (ad->progressbar) {
		cam_debug(LOG_UI, " value [%f]", value);
		elm_progressbar_value_set(ad->progressbar, value);
	} else
		UI_TEST_LOG("");

	return TRUE;
}

gboolean cam_app_set_progressbar_text(void *data, const char *text)
{
	struct appdata *ad = (struct appdata *)(data);
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	cam_retv_if(text == NULL, FALSE);

	if (ad->progressbar_edje)
		edje_object_part_text_set(_EDJ(ad->progressbar_edje),
					  "progressbar_text", text);

	return TRUE;
}

gboolean cam_app_destroy_progressbar(void *data)
{
	struct appdata *ad = (struct appdata *)(data);
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	cam_debug(LOG_UI, " start");
	DEL_EVAS_OBJECT(ad->progressbar);
	DEL_EVAS_OBJECT(ad->progressbar_edje);
	cam_debug(LOG_UI, " done");

	return TRUE;
}

gboolean cam_app_hide_progressbar(void *data)
{
	struct appdata *ad = (struct appdata *)(data);
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	cam_debug(LOG_UI, " start");
	HIDE_EVAS_OBJECT(ad->progressbar);
	HIDE_EVAS_OBJECT(ad->progressbar_edje);
	cam_debug(LOG_UI, " done");

	return TRUE;
}

gboolean cam_app_timeout_checker_update()
{
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;
	gdouble c_time = 0.0;
	cam_debug(LOG_UI, "");

	ad = (struct appdata *)cam_appdata_get();
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "cam_handle is NULL");

	if (ad->timeout_checker) {
		c_time = _get_current_time();
		ecore_timer_delay(ad->timeout_checker,
				  (c_time - camapp->last_time));
		camapp->last_time = c_time;
	}

	return TRUE;
}

void cam_app_mdm_syspopup(void *data)
{
	struct appdata *ad = (struct appdata *)(data);
	cam_retm_if(ad == NULL, " appdata is NULL");
	bundle *b = NULL;
	b = bundle_create();
	if (b != NULL) {
		bundle_add(b, "_SYSPOPUP_CONTENT_", dgettext(PACKAGE, "IDS_CAM_POP_SECURITY_POLICY_RESTRICTS_USE_OF_CAMERA"));
		syspopup_launch("mdm-syspopup", b);
		bundle_free(b);
	}

	cam_app_exit(ad);
}

void cam_app_notice_popup(void *data, const char *msg,
			  void (*func) (void *data,
			  Evas_Object *obj,
			  void *event_info)
			  )
{
	struct appdata *ad = (struct appdata *)(data);
	cam_retm_if(ad == NULL, " appdata is NULL");
	cam_retm_if(ad->ug_base == NULL, " ad->ug_base is NULL");
	Evas_Object *popup = NULL;

	popup = elm_popup_add(ad->ug_base);
	if (popup == NULL)
		return;

	evas_object_size_hint_weight_set(popup, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	elm_object_text_set(popup, msg);
	/*elm_popup_mode_set(popup, ELM_POPUP_TYPE_ALERT);*/
	elm_popup_timeout_set(popup, 3.0);
	evas_object_smart_callback_add(popup, "timeout", func, data);
	ad->waring_popup = popup;
	evas_object_show(popup);
}

static void cam_app_capture_error_popup_response_cb(void *data, Evas_Object *obj, void *event_info)
{
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	cam_retm_if(ad == NULL, " appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, " camapp is NULL");
	if (obj)
		evas_object_del(obj);
	obj = NULL;

	cam_app_stop_capture(ad);
	cam_app_exit(ad);
}

void cam_app_gps_enable_popup(void *data, const char *msg,
			      Eina_Bool (*func) (void *data))
{
	struct appdata *ad = (struct appdata *)(data);
	cam_retm_if(ad == NULL, " appdata is NULL");
	cam_retm_if(ad->ug_base == NULL, " ad->ug_base is NULL");
	Evas_Object * popup = NULL;
	popup = elm_popup_add(ad->ug_base);
	if (popup == NULL)
		return;
	evas_object_size_hint_weight_set(popup, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);

	char popup_str[1024 + 1] = { '\0',};
	snprintf(popup_str, 1024, "%s%s%s", _("<font=SLP:style=Roman><color=#000000><align=center>"),
		msg, _("</align></color></font>"));

	elm_object_text_set(popup, popup_str);
	Evas_Object *btn1 = elm_button_add(popup);
	elm_object_text_set(btn1, dgettext(PACKAGE, "IDS_CAM_BODY_SETTINGS"));
	elm_object_part_content_set(popup, "button1", btn1);
	evas_object_smart_callback_add(btn1, "clicked", cam_app_gps_popup_response_ok_cb, (void*)ad);
	Evas_Object *btn2 = elm_button_add(popup);
	elm_object_text_set(btn2, dgettext("sys_string", "IDS_COM_SK_CANCEL"));
	elm_object_part_content_set(popup, "button2", btn2);
	evas_object_smart_callback_add(btn2, "clicked", cam_app_gps_popup_response_cancel_cb, (void*)ad);
	ad->confirm_popup = popup;

	evas_object_show(popup);

}

void cam_app_timeout_notice_response_cb(void *data, Evas_Object *obj,
					void *event_info)
{
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	cam_retm_if(ad == NULL, " appdata is NULL");

	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp_handle is NULL");

	if (obj){
		evas_object_del(obj);
		obj = NULL;
	}

	cam_app_stop_capture(ad);
	cam_app_exit(ad);
}

/*set flash close*/
void cam_close_flash_feature(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, " appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, " appdata is NULL");
	if (camapp->flash > CAM_FLASH_OFF) {
		GValue value = { 0 };
		CAM_GVALUE_SET_INT(value, CAM_FLASH_OFF);
		gint tempval = g_value_get_int(&value);
		if (!cam_mm_set_flash(tempval)) {
			cam_warning(LOG_UI, "flash set fail");
			return;
		}
		camapp->flash = tempval;
	}
}
/*lowbattery callback*/
void cam_app_lowbattery_close_flash_cb(void *data, Evas_Object *obj, void *event_info)
{
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	cam_retm_if(ad == NULL, " appdata is NULL");
	if (obj)
		evas_object_del(obj);
	obj = NULL;
	cam_close_flash_feature(ad);

	cam_toolbar_update(ad);
}

static Eina_Bool cam_app_timeout_checker_cb(void *data)
{
	struct appdata *ad = (struct appdata *)(data);
	CamAppData *camapp = NULL;
	gdouble diff = 0.0;

	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");
	camapp = ad->camapp_handle;
	if (camapp == NULL) {
		ad->timeout_checker = NULL;
		return ECORE_CALLBACK_CANCEL;
	}
	ad->timeout_checker = NULL;

	diff = _get_current_time() - camapp->last_time;

	if ((cam_mm_get_state() == CAMERA_STATE_PREVIEW)
	    && (diff >= CAMERA_APP_TIMEOUT)) {
		cam_debug(LOG_UI, "Close camera application!!! diff time:[%lf]", diff);
		ad->timeout_checker = NULL;
		camapp->last_time = 0;
		elm_win_lower(ug_get_window());
	}

	cam_debug(LOG_UI, "diff time : [%lf]", diff);
	return ECORE_CALLBACK_CANCEL;
}

gboolean cam_app_timeout_checker_init(void *data)
{
	struct appdata *ad = (struct appdata *)(data);
	CamAppData *camapp = NULL;

	debug_fenter(LOG_CAM);

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "cam_handle is NULL");

	if (ad->timeout_checker) {
		ecore_timer_del(ad->timeout_checker);
		ad->timeout_checker = NULL;
	}
	if (ad->timer_timer) {
		ad->timer_activated = false;
		DEL_EVAS_OBJECT(ad->timer_icon_edje);
		REMOVE_TIMER(ad->timer_timer);
	}
	if (ad->continuous_shot_timer) {
		REMOVE_TIMER(ad->continuous_shot_timer);
	}
	if (ad->check_af_timer) {
		REMOVE_TIMER(ad->check_af_timer);
	}
	if (ad->gps_animation_timer) {
		REMOVE_TIMER(ad->gps_animation_timer);
	}

	ad->timeout_checker = ecore_timer_add(CAMERA_APP_TIMEOUT, cam_app_timeout_checker_cb, ad);
	camapp->last_time = _get_current_time();

	return TRUE;
}

gboolean cam_app_timeout_checker_remove(void)
{
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;

	debug_fenter(LOG_CAM);

	ad = (struct appdata *)cam_appdata_get();
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "cam_handle is NULL");

	if (ad->timeout_checker) {
		ecore_timer_del(ad->timeout_checker);
		ad->timeout_checker = NULL;
	}
	camapp->last_time = 0;

	return TRUE;
}

#ifdef USE_FIFO_THREAD
void *cam_app_FIFO_thread_run(void *data)
{
	struct appdata *ad = (struct appdata *)data;

	int fd = 0;

	char buf[128] = { '\0', };

	cam_retvm_if(ad == NULL, NULL, "appdata is NULL");

	if (!access(CAM_FIFO_PATH, F_OK)) {
		unlink(CAM_FIFO_PATH);
	}

	if (-1 == mkfifo(CAM_FIFO_PATH, 0666)) {
		cam_critical(LOG_SYS, " Make CamApp FIFO failed.");
		cam_app_exit(ad);
		return NULL;
	}

	fd = open(CAM_FIFO_PATH, O_RDWR);
	if (fd < 0) {
		cam_critical(LOG_SYS, " Open CamApp FIFO failed.");
		cam_app_exit(ad);
		return NULL;
	}

	cam_debug(LOG_SYS, "Open CamApp FIFO [%s] success", CAM_FIFO_PATH);

	while (1) {
		memset(buf, 0x00, 128);

		cam_debug(LOG_SYS, " Wait CamApp FIFO write...");

		int count = read(fd, buf, 128);
		if (count == -1)
			cam_debug(LOG_SYS, " read error occur!");

		cam_debug(LOG_SYS, " Read from CamApp FIFO : [%s]", buf);

		if (!strcmp(buf, CAM_CAPTURE_AUTO_START)) {
			cam_debug(LOG_SYS, " #### Start _auto_shot_idle_cb");
			_auto_shot_idle_cb(data);
		} else if (!strcmp(buf, CAM_FIFO_CMD_EXIT)) {
			break;
		} else {
			/* Error */
			cam_warning(LOG_SYS, " Skip this...");
		}
	}

	close(fd);
	unlink(CAM_FIFO_PATH);

	cam_debug(LOG_SYS, " Exit CamApp FIFO thread...");

	return NULL;
}

void cam_app_FIFO_thread_exit()
{
	int fd = open(CAM_FIFO_PATH, O_WRONLY);
	char *str_write = CAM_FIFO_CMD_EXIT;

	if (fd < 0) {
		cam_critical(LOG_SYS, " Open CammApp FIFO file[%s] failed",
			     CAM_FIFO_PATH);
	} else {
		int count = write(fd, str_write, strlen(str_write));
		if (count == -1)
			cam_debug(LOG_SYS, " write error occur! ");
		close(fd);

		cam_debug(LOG_SYS, " Write [%s] to FIFO Done.", str_write);
	}
}

#endif

gboolean cam_app_create_file_register_thread(void *data)
{
	struct appdata *ad = (struct appdata *)data;

	int err = 0;
	cam_debug(LOG_SYS, "");

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	err = pthread_mutex_init(&(ad->file_reg_mutex), NULL);
	if (err != 0) {
		cam_critical(LOG_CAM,
			     "Create Camera file register mutex failed");
		return FALSE;
	}

	err = pthread_cond_init(&(ad->file_reg_cond), NULL);
	if (err != 0) {
		cam_critical(LOG_CAM,
			     "Create Camera file register cond failed");
		return FALSE;
	}

	ad->file_reg_queue = g_queue_new();
	if (ad->file_reg_queue == NULL) {
		cam_critical(LOG_CAM,
			     "Create Camera file register queue failed");
		return FALSE;
	}

	err = pthread_create(&(ad->file_reg_thread), NULL, cam_app_file_register_thread_run, (void *)ad);

	if (err != 0) {
		cam_critical(LOG_CAM,
			     "Create Camera file register thread failed");
		return FALSE;
	}

	return TRUE;
}

void *cam_app_file_register_thread_run(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	gboolean Exit_loop = FALSE;
	cam_debug(LOG_FILE, "");

	pthread_mutex_lock(&ad->file_reg_mutex);

	while (!Exit_loop) {
		cam_debug(LOG_FILE, " wait signal...");

		pthread_cond_wait(&ad->file_reg_cond, &ad->file_reg_mutex);

		cam_debug(LOG_FILE, " signal received");
		while (!g_queue_is_empty(ad->file_reg_queue)) {
			char *filename = NULL;
			filename = g_queue_pop_head(ad->file_reg_queue);
			DEBUG_TRACE("filename is %s", filename);
			if (strcmp(REG_THREAD_EXIT, filename) == 0) {
				free(filename);
				Exit_loop = TRUE;
				break;
			} else if (strcmp(UPDATE_THUMBNAIL, filename) == 0) {
                                /*TODO:*/
			} else if (strcmp(UPDATE_THUMBNAIL_NO_ANI, filename) == 0) {
                                 /*TODO:*/
			} else if (strcmp(REC_FILE_SAVE_REG, filename) == 0) {
				cam_rec_save_and_register_video_file(ad);
				free(filename);
				filename = NULL;
			} else {
				__cam_single_shot_reg_file(filename);
				free(filename);
				cam_debug(LOG_FILE, " register done.");
			}
		}
		/*TODO: update thumbnail*/

	}

	pthread_mutex_unlock(&ad->file_reg_mutex);

	pthread_mutex_destroy(&ad->file_reg_mutex);
	pthread_cond_destroy(&ad->file_reg_cond);

	cam_debug(LOG_SYS, " thread exit...");

	return NULL;
}

void cam_app_file_register_thread_exit(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	char *exit_cmd = NULL;

	if (ad->file_reg_queue != NULL) {
		exit_cmd = strdup(REG_THREAD_EXIT);
		g_queue_push_tail(ad->file_reg_queue, exit_cmd);
		pthread_cond_signal(&ad->file_reg_cond);
	}
	return;
}

gboolean cam_app_init_with_args(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	cam_retvm_if(ad->camapp_handle == NULL, FALSE, "camapp is NULL");

	cam_debug(LOG_SYS, "");
	if (ad->launching_mode == CAM_LAUNCHING_MODE_EXTERNAL) {
		ad->camapp_handle->camera_mode = ad->exe_args->cam_mode;
		if (CAM_CAMCORDER_MODE == ad->camapp_handle->camera_mode) {
			if (ad->exe_args->resolution == CAM_RESOLUTION_QCIF) {
				ad->camapp_handle->recording_mode = CAM_RECORD_MMS;
				ad->camapp_handle->video_resolution = CAM_RESOLUTION_QCIF;
				ad->camapp_handle->reserved_setting_data.rear_recording_mode = CAM_RECORD_MMS;
				ad->camapp_handle->reserved_setting_data.rear_video_resolution = CAM_RESOLUTION_QCIF;
				ad->camapp_handle->reserved_setting_data.front_recording_mode = CAM_RECORD_SELF_MMS;
				ad->camapp_handle->reserved_setting_data.front_video_resolution = CAM_RESOLUTION_QCIF;
				ad->camapp_handle->fps = FPS_SLOW;
				if (ad->exe_args->size_limit <= 0) {
					ad->camapp_handle->size_limit = CAM_REC_MMS_MAX_SIZE;
				} else {
					ad->camapp_handle->size_limit = ad->exe_args->size_limit;
				}
				ad->camapp_handle->size_limit_type = CAM_MM_SIZE_LIMIT_TYPE_BYTE;
			} else {
				ad->camapp_handle->recording_mode = CAM_RECORD_NORMAL;
				ad->camapp_handle->video_resolution = ad->exe_args->resolution;
				ad->camapp_handle->fps = FPS_DEFAULT;
				if (ad->exe_args->size_limit <= 0) {
					ad->camapp_handle->size_limit = CAM_REC_NORMAL_MAX_SIZE;
				} else {
					ad->camapp_handle->size_limit = ad->exe_args->size_limit;
				}
				ad->camapp_handle->size_limit_type = CAM_MM_SIZE_LIMIT_TYPE_BYTE;
			}
		} else {
			ad->camapp_handle->shooting_mode = CAM_SINGLE_MODE;
			ad->camapp_handle->default_capture_mode = CAM_CAPTURE_SINGLE;
			if (ad->exe_args->width <= 0
			    || ad->exe_args->height <= 0) {
				ad->camapp_handle->photo_resolution = CAM_RESOLUTION_VGA;
			} else {
				ad->camapp_handle->photo_resolution = CAM_RESOLUTION(ad->exe_args->width, ad->exe_args->height);
			}
		}
		ad->camapp_handle->review = ad->exe_args->review;
	} else {
		cam_debug(LOG_SYS, " camera launch mode is normal.");
		return FALSE;
	}

	cam_debug(LOG_SYS, " done");

	return TRUE;
}

Eina_Bool cam_app_focus_guide_create(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retv_if(ad == NULL, EINA_FALSE);

	/*NOTE: TODO, perhaps there is issue:
		while focus is animating, now delete focus_edje, what will occur?
	*/
	cam_ui_effect_utils_stop_zoom_effect();
	DEL_EVAS_OBJECT(ad->focus_edje);

	ad->focus_edje = cam_app_load_edj(ad->ug_base, CAM_UTILS_EDJ_NAME, "focus_image");

	if (ad->focus_edje == NULL) {
		cam_critical(LOG_UI, "focus_edje load failed ");
		return EINA_FALSE;
	}
	evas_object_show(ad->focus_edje);

#ifdef	CAMERA_MACHINE_I686
	evas_object_hide(ad->focus_edje);
#endif

	return EINA_TRUE;
}

static Eina_Bool __focus_guide_hide_timer_cb(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");

	if (ad->focus_guide_hide_timer)
		ad->focus_guide_hide_timer = NULL;

	if (ad->focus_edje)
		edje_object_signal_emit(_EDJ(ad->focus_edje), "focus,hide", "program");

	return ECORE_CALLBACK_CANCEL;
}

Eina_Bool cam_app_focus_guide_update(void *data)
{
	DEBUG_TRACE();
#ifndef	CAMERA_MACHINE_I686
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, EINA_FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(ad->camapp_handle == NULL, EINA_FALSE, "camapp is NULL");

	if (ad->focus_edje == NULL) {
		return EINA_FALSE;
	}

	REMOVE_TIMER(ad->focus_guide_hide_timer);

	/*note: relocation the focus edje*/
	evas_object_resize(ad->focus_edje, ad->camera_focus_w, ad->camera_focus_h);
	evas_object_move(ad->focus_edje, ad->af_start_x, ad->af_start_y);
	evas_object_show(ad->focus_edje);

	if (ad->imageviewer_ug) {
		edje_object_signal_emit(_EDJ(ad->focus_edje), "focus,hide", "program");
		return EINA_FALSE;
	}

	if (ad->confirm_popup) {
		edje_object_signal_emit(_EDJ(ad->focus_edje), "focus,hide", "program");
		return EINA_FALSE;
	}

	if (ad->is_processing) {
		edje_object_signal_emit(_EDJ(ad->focus_edje), "focus,hide", "program");
		return EINA_FALSE;
	}

	if (ad->setting_ctxpopup
		|| (ad->tip_popup)
		|| (ad->toolbar_setting_popup)
		|| (ad->edit_shortcuts_popup)) {
		cam_debug(LOG_UI, "do not need to update focus");
		edje_object_signal_emit(_EDJ(ad->focus_edje), "focus,hide", "program");
		return EINA_FALSE;
	}

	if (camapp->camera_mode == CAM_CAMERA_MODE
		&& ad->mm_state == CAMERA_STATE_CAPTURING) {
		return EINA_FALSE;
	}

	if (camapp->camera_mode == CAM_CAMERA_MODE
		&& (ad->mm_state < CAMERA_STATE_PREVIEW || camapp->af_mode == CAM_FOCUS_FACE)) {
		edje_object_signal_emit(_EDJ(ad->focus_edje), "focus,hide", "program");
		return EINA_FALSE;
	} else {
		if ((camapp->camera_mode == CAM_CAMCORDER_MODE)
			&& (camapp->recording_mode == CAM_RECORD_SLOW
			|| camapp->recording_mode == CAM_RECORD_FAST
			|| camapp->recording_mode == CAM_RECORD_SELF
			|| camapp->recording_mode == CAM_RECORD_SELF_MMS)) {
			edje_object_signal_emit(_EDJ(ad->focus_edje), "focus,hide", "program");
		} else {
			char signame[30] = { '\0', };
			const char *focus_state_name[4] = {
				"hide",
				"notready",
				"focused",
				"failed",
			};

			snprintf(signame, sizeof(signame), "%s,%s", "focus", focus_state_name[camapp->focus_state]);
			edje_object_signal_emit(_EDJ(ad->focus_edje), signame, "program");
		}

		if ((camapp->focus_state == CAMERA_FOCUS_STATE_FOCUSED) || (camapp->focus_state == CAMERA_FOCUS_STATE_FAILED))
			ad->focus_guide_hide_timer = ecore_timer_add(1.0, __focus_guide_hide_timer_cb, ad);
	}
#endif
	return EINA_TRUE;
}

static int cam_app_camera_state_manager(int previous, int current, gboolean by_asm)
{
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;

	cam_info(LOG_UI, "STATE_CHANGED : %d -> %d ", previous, current);

	ad = (struct appdata *)cam_appdata_get();
	cam_retv_if(ad == NULL, FALSE);

	camapp = ad->camapp_handle;
	cam_retv_if(camapp == NULL, FALSE);

	ad->mm_state = current;

	if (current == CAMERA_STATE_PREVIEW) {
		if (previous == CAMERA_STATE_CAPTURING) {
			CAM_TA_ACUM_ITEM_END("    capture stop to preview", 0);
			CAM_TA_ACUM_ITEM_END("Total capture time", 0);
			cam_debug(LOG_MM, "capture end, preview start");
		}
	}

	if (current == CAMERA_STATE_CAPTURING) {
		if (previous == CAMERA_STATE_PREVIEW) {
			cam_debug(LOG_MM, "capture start, preview end");
			if ((camapp->shooting_mode == CAM_SELF_SINGLE_MODE
					&& camapp->default_capture_mode == CAM_CAPTURE_SINGLE)){
				cam_app_create_screennail_and_start_animation(ad);
			}
		}
	}

	return 1;
}

static int cam_app_recorder_state_manager(int previous, int current, gboolean by_asm)
{
	struct appdata *ad = NULL;
	CamAppData *camapp = NULL;

	cam_info(LOG_UI, "STATE_CHANGED : %d -> %d ", previous, current);

	ad = (struct appdata *)cam_appdata_get();
	cam_retv_if(ad == NULL, FALSE);

	camapp = ad->camapp_handle;
	cam_retv_if(camapp == NULL, FALSE);

	ad->mm_state = current;

	if (((previous == RECORDER_STATE_RECORDING)
	    && (current != RECORDER_STATE_PAUSED))
	    ||((previous == RECORDER_STATE_PAUSED)
	    && (current != RECORDER_STATE_RECORDING))) {/*finished recording*/

		cam_info(LOG_UI, "Set gamma NORMAL");

		if (camapp->filename) {
			free(camapp->filename);
			camapp->filename = NULL;
		}

		if (cam_mm_get_filename(&camapp->filename, 0) == FALSE) { /*file size not used,so set to 0*/
			return FALSE;
		}
		cam_info(LOG_UI, "Recorded file name [%s] ", camapp->filename);

/*note: shooting mode change*/
#if 1
		/* change to camera mode*/
		/*
		*	TODO: if for any reason, not run here, there will be caused now now recording, but in record mode
		*	So: I suggest while click capture button: judge now state and whether recording.
		*/
		if(ad->launching_mode == CAM_LAUNCHING_MODE_NORMAL) {
			if (ad->ug_state != CAM_UG_PAUSE_STATE) {/*if now is pause state, so do not set mode, just set while resume*/
				if (cam_app_mode_change(ad, CAM_CAMERA_MODE) == FALSE)
					return FALSE;;

			}
		}
#endif
	/*TODO: I think state manager callback is called in thread, so we could do data logic here,
			and request ui operation to ecore_pipe*/
		cam_utils_request_main_pipe_handler(ad, NULL, CAM_MAIN_PIPE_OP_TYPE_VIDEO_CAPTURE_HANDLE);

	}
	return TRUE;
}

static Eina_Bool __cam_ug_destroy(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");

	ug_destroy_me(ad->camera_ug);

	return ECORE_CALLBACK_CANCEL;
}

gboolean cam_app_exit(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	ecore_idler_add(__cam_ug_destroy, ad);

	return TRUE;
}

static void cam_mmc_state_change_cb(keynode_t *key, void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	int mmc_state = vconf_keynode_get_int(key);

	cam_retm_if(ad == NULL, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp_handle is NULL");

	cam_debug(LOG_SYS, " start");

	if (mmc_state == VCONFKEY_SYSMAN_MMC_REMOVED
	    && camapp->storage == CAM_STORAGE_EXTERNAL) {

		GValue value = { 0 };
		int mm_state = cam_mm_get_state();

		if (mm_state == CAMERA_STATE_CAPTURING
		    && (camapp->shooting_mode == CAM_SINGLE_MODE
		    	&& camapp->default_capture_mode == CAM_CAPTURE_BURST)
		    &&camapp->camera_mode == CAM_CAMERA_MODE) {
			if (camapp->continuous_shot_data) {
				if (camapp->continuous_shot_data->error != NULL) {
					cam_debug(LOG_SYS, " error [%s,%d]", camapp->continuous_shot_data->error->message, camapp->continuous_shot_data->error->code);
					g_error_free(camapp->continuous_shot_data->error);
					camapp->continuous_shot_data->error = NULL;
				}

				camapp->continuous_shot_data->error = cam_error_new_literal(CAM_CONTI_SHOT_ERROR_MMC_REMOVED, dgettext(PACKAGE, "IDS_CAM_POP_MEMORY_CARD_REMOVED"));
			} else {
				cam_debug(LOG_SYS, " continuous_shot_data is NULL");
			}
		} else {
			if ((mm_state == RECORDER_STATE_RECORDING
			    || mm_state == RECORDER_STATE_PAUSED)
			    &&camapp->camera_mode == CAM_CAMCORDER_MODE) {
				cam_video_record_cancel(ad);
				cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_REMOVE_MMC_RECORDING"), cam_app_popup_response_cb);
			}
#ifndef	CAMERA_MACHINE_I686
			else if (mm_state != CAMERA_STATE_CAPTURING
				 && camapp->camera_mode == CAM_CAMERA_MODE) {
				if (cam_app_check_blocking_popup()) {
					cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_MEMORY_CARD_REMOVED"), cam_app_popup_response_cb);
				}
			}
#endif
		}

		CAM_GVALUE_SET_INT(value, CAM_STORAGE_INTERNAL);
		cam_handle_value_set(ad, PROP_STORAGE, &value);

		cam_info(LOG_UI, "MMC card is removed");
	}

	cam_toolbar_setting_popup_update(ad);
	indicator_update_storage(ad);
	return;
}

#ifdef CAMAPP_SIG_HANDLING
/**
* This function registers a user space signal handler for the signal SIGSEGV (Signal #11)
*
* @return		nothing
*/
static void cam_app_register_sigsegv(void)
{
	debug_fenter(LOG_SYS);

	/* cam_app_act.sa_flags = SA_SIGINFO | SA_NOCLDSTOP; */
	cam_app_act.sa_flags = SA_SIGINFO;
	cam_app_act.sa_handler = (void *)cam_app_sigsegv_handler;
	sigemptyset(&cam_app_act.sa_mask);

#ifdef ENABLE_CHECK_CAM_STATUS
	sigaction(SIGALRM, &cam_app_act, &cam_app_act_old);	/* register an action with a previous action */
#endif
	sigaction(SIGABRT, &cam_app_act, &cam_app_act_old);
	sigaction(SIGSEGV, &cam_app_act, &cam_app_act_old);
	sigaction(SIGILL, &cam_app_act, &cam_app_act_old);

	debug_fleave(LOG_SYS);
}

static void
cam_app_sigsegv_handler(int signal_no, siginfo_t *info, void *context)
{
	debug_fenter(LOG_SYS);

	cam_debug(LOG_SYS, "signal_no = %d", signal_no);

	if (signal_no == SIGALRM) {	/* if alarm, check the camera status. */
#ifdef ENABLE_CHECK_CAM_STATUS
		cam_app_check_status();
		alarm(CAM_CHECK_STATUS_INTERVAL_TIME);
#endif
		return;
	} else {
		sigaction(signal_no, &cam_app_act_old, NULL);	/*  register the previous action */
		raise(signal_no);
	}

	debug_fleave(LOG_SYS);
}

#endif

#ifdef ENABLE_CHECK_CAM_STATUS

static void cam_app_check_status()
{
	cam_debug(LOG_SYS, "check status");
}
#endif				/* ENABLE_CHECK_CAM_STATUS */

void cam_app_toggle_indicator(void *data, gboolean hide)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	indicator_toggle(ad, hide);

	return;
}

void cam_app_toggle_toolbar(void *data, gboolean hide)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	if (hide) {
		hide_toolbar_edje(ad);
	} else {
		show_toolbar_edje(ad);
	}

	return;
}

static void
cam_app_reset_settings_launch_cb(void *data, Evas_Object *obj, void *event_info)
{
	Evas_Object *notify = (Evas_Object *)data;
	GValue i_value = { 0, };
	GValue b_value = { 0, };
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	CamAppData *camapp = NULL;

	cam_debug(LOG_CAM, "!!!!!!!!!cam_app_reset_settings_launch_cb");

	cam_retm_if(ad == NULL, " appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, " cam_handle is NULL");

	cam_popup_remove(notify);
	hide_toolbar_edje(ad);

	cam_app_preview_stop();

	g_value_init(&i_value, G_TYPE_INT);
	g_value_init(&b_value, G_TYPE_BOOLEAN);

	/* auto focus */

	g_value_set_int(&i_value, AF_DEFAULT);
	cam_handle_value_set(ad, PROP_AF_MODE, &i_value);

	/* Timer */
	g_value_set_int(&i_value, TIMER_DEFAULT);
	cam_handle_value_set(ad, PROP_TIMER, &i_value);

	/* white balance */
	g_value_set_int(&i_value, WB_DEFAULT);
	cam_handle_value_set(ad, PROP_WB, &i_value);

	/* Effect */
	g_value_set_int(&i_value, EFFECT_DEFAULT);
	cam_handle_value_set(ad, PROP_EFFECT, &i_value);

	/* ISO */
	g_value_set_int(&i_value, ISO_DEFAULT);
	cam_handle_value_set(ad, PROP_ISO, &i_value);

	/* Metering */
	g_value_set_int(&i_value, AE_DEFAULT);
	cam_handle_value_set(ad, PROP_METERING, &i_value);

	/* Anti-shake */
	g_value_set_int(&i_value, AHS_DEFAULT);
	cam_handle_value_set(ad, PROP_AHS, &i_value);

	/* wild dynamic range */
	g_value_set_int(&i_value, WDR_DEFAULT);
	cam_handle_value_set(ad, PROP_WDR, &i_value);

	/* Image quality */
	g_value_set_int(&i_value, QUALITY_DEFAULT);
	cam_handle_value_set(ad, PROP_IMAGE_QUALITY, &i_value);

	/* Video quality */
	g_value_set_int(&i_value, QUALITY_DEFAULT);
	cam_handle_value_set(ad, PROP_VIDEO_QUALITY, &i_value);

	/* Guide Line */
	g_value_set_boolean(&b_value, FALSE);
	cam_handle_value_set(ad, PROP_GUIDELINE, &b_value);
	settings_guideline_refresh(ad);
	/* Review */
	g_value_set_boolean(&b_value, FALSE);
	cam_handle_value_set(ad, PROP_REVIEW, &b_value);

	/* GPS Connect */
	g_value_set_boolean(&b_value, FALSE);
	cam_handle_value_set(ad, PROP_GPS, &b_value);

	/* shutter sound */
	g_value_set_int(&i_value, SHUTTER_SOUND_DEFAULT);
	cam_handle_value_set(ad, PROP_SHUTTER_SOUND, &i_value);

	/* audio recording */
	g_value_set_boolean(&b_value, TRUE);
	cam_handle_value_set(ad, PROP_AUDIO_REC, &b_value);

	/* storage */
	g_value_set_int(&i_value, STORAGE_DEFAULT);
	cam_handle_value_set(ad, PROP_STORAGE, &i_value);

	/* brightness */
	g_value_set_int(&i_value, BRIGHTNESS_DEFAULT);
	cam_handle_value_set(ad, PROP_BRIGHTNESS, &i_value);

	/* Resolution */
	g_value_set_int(&i_value, IMAGE_RESOLUTION_DEFAULT);
	cam_handle_value_set(ad, PROP_PHOTO_RESOLUTION, &i_value);

	g_value_set_int(&i_value, REC_RESOLUTION_DEFAULT);
	cam_handle_value_set(ad, PROP_VIDEO_RESOLUTION, &i_value);

	if (ad->indicator_edje) {
		/* delete indicator */
		evas_object_hide(ad->indicator_edje);
		cam_indicator_destory(ad);
	}
	cam_indicator_create(ad);

	show_toolbar_edje(ad);

	if (!cam_app_preview_start(ad)) {
		cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA"), cam_app_timeout_notice_response_cb);
	}

}

void cam_app_reset_settings(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	cam_popup_question_add(ad->ug_base,
			       dgettext(PACKAGE, "IDS_CAM_POP_RESET_CAMERA_SETTINGS"),
			       dgettext("sys_string", "IDS_COM_SK_YES"),
			       cam_app_reset_settings_launch_cb,
			       dgettext("sys_string", "IDS_COM_SK_NO"),
			       _popup_cancel_cb);

}

static gboolean __cam_toolbar_new_thumbnail_create(Evas_Object **obj,
							struct appdata *ad,
							Evas_Coord *thumbnail_x,
							Evas_Coord *thumbnail_y,
							Evas_Coord *thumbnail_w,
							Evas_Coord *thumbnail_h)
{
	cam_retv_if(ad == NULL, FALSE);
	CamAppData *camapp = ad->camapp_handle;
	cam_retv_if(camapp == NULL, FALSE);
	cam_retv_if(obj == NULL, FALSE);
	cam_retv_if(ad->evas == NULL, FALSE);
	cam_retv_if(ad->toolbar.quickview_item.edje == NULL, FALSE);

	if(camapp->thumbnail_name == NULL) {
		*obj = NULL;
		return TRUE;
	}
	Evas_Object *new_thumbnail_img = elm_bg_add(ad->toolbar.quickview_item.edje);
	Evas_Coord x = 0, y = 0, w = 0, h = 0;
	Evas_Object *layout = NULL;
	Evas_Object *thumbnail_area = NULL;

	cam_retv_if(new_thumbnail_img == NULL, FALSE);
	elm_bg_file_set(new_thumbnail_img, camapp->thumbnail_name, NULL);

	layout = elm_layout_edje_get(ad->toolbar.quickview_item.edje);
	thumbnail_area = (Evas_Object *) edje_object_part_object_get(layout,"thumbnail_area");
	cam_retv_if(thumbnail_area == NULL, FALSE);
	evas_object_geometry_get(thumbnail_area, &x, &y, &w, &h);
	*thumbnail_x = x;
	*thumbnail_y = y;
	*thumbnail_w = w;
	*thumbnail_h = h;

	evas_object_resize(new_thumbnail_img, 0, 0);
	evas_object_move(new_thumbnail_img, x, y);
	evas_object_show(new_thumbnail_img);
	*obj = new_thumbnail_img;
	return TRUE;
}

static gboolean __filter_cam_app_pipe_handler(void *data, gint pipe_type)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	if (ad->ug_state == CAM_UG_TERMINATE_STATE
			|| ad->ug_state == CAM_UG_PAUSE_STATE) {
		switch (pipe_type) {
		case CAM_MAIN_PIPE_OP_TYPE_BEST_SHOT_IMAGE_HANDLE:
		case CAM_MAIN_PIPE_OP_TYPE_VIDEO_CAPTURE_HANDLE:
			return FALSE;
		default:
			break;
		}
		return TRUE;
	}
	return FALSE;
}

static void cam_app_pipe_handler(void *data, void *buffer, unsigned int nbyte)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	/* Caution */
	/* DO NOT free buffer in here */
	/* buffer is freed by ecore */

	if (buffer) {
		Ecore_Pipe_Data_Info * pipe_info = (Ecore_Pipe_Data_Info *)buffer;
		int main_pipe_type = pipe_info->cmd;
		DEBUG_TRACE("main_pipe_type %d", main_pipe_type);

		if (__filter_cam_app_pipe_handler(ad, main_pipe_type) == TRUE) {
			return;
		}

		switch (main_pipe_type) {
		case CAM_MAIN_PIPE_OP_TYPE_UPDATE_THUMBNAIL:
			{
				Evas_Object *new_thumbnail_image = NULL;
				Evas_Coord x = 0, y = 0, w = 0, h = 0;
				gboolean ret = FALSE;
				ret = __cam_toolbar_new_thumbnail_create(&new_thumbnail_image, ad, &x, &y, &w, &h);
				if (ret == FALSE || !new_thumbnail_image) {
					if (!new_thumbnail_image && ret) {
						DEL_EVAS_OBJECT(ad->toolbar.quickview_item.thumbnail_image);
					}
					return;
				}
				cam_ui_effect_utils_set_thumbnail_effect(new_thumbnail_image,
									x,
									y,
									w,
									h,
									CAM_THUMBNAIL_ANTIMATION_EFFECT_DURATION);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_UPDATE_THUMBNAIL_NO_ANI:
			{
				toolbar_update_quickview_thumbnail_no_animation(ad);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_ROTATE_ANIMATOR:
			{
				cam_ui_rotate_utils_rotate_start(ad, CAM_ROTATE_ICONS_ANTIMATION_DURATION);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_SHUTTER_ANIMATION:
			{
				cam_app_create_start_animation(ad);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_BURST_SHOT_UPDATE_PROGRESS:
			{
				cam_continuous_shot_update_progress_value(ad);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_BURST_SHOT_DISPLAY_POPUP:
			{
				cam_app_destroy_progressbar(ad);
				cam_app_create_burst_popup(ad);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_BEST_SHOT_IMAGE_HANDLE:
			{
				cam_image_capture_handle(ad);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_UPDATE_VIEW:
			{
				CamAppData *camapp = ad->camapp_handle;
				cam_retm_if(camapp == NULL, "camapp is NULL");

				camapp->update_view_cb(ad);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_ERROR_POPUP:
			{
				cam_create_error_popup(ad);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_VIDEO_CAPTURE_HANDLE:
			{
				cam_video_capture_handle(ad);
			}
			break;
		case CAM_MAIN_PIPE_OP_TYPE_RUN_IMAGE_VIEWER:
			{
				CamAppData *camapp = ad->camapp_handle;
				cam_retm_if(camapp == NULL, "camapp is NULL");
				cam_retm_if(camapp->filename == NULL, "camapp is NULL");
				if (!cam_app_run_image_viewer_ug(ad, camapp->filename, FALSE)) {
					return;
				}
			}
			break;
		default:
			break;
		}
		/*note: free memory*/
		if (pipe_info->data) {
			free(pipe_info->data);
			pipe_info = NULL;
		}
	}

	return;
}

void cam_focus_edje_rotate(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");

	DEL_EVAS_OBJECT(ad->focus_edje);
	ad->focus_edje = cam_app_load_edj(ad->ug_base, CAM_UTILS_EDJ_NAME, "focus_image");

	cam_retm_if(ad->focus_edje == NULL, "focus_edje load failed");

	evas_object_resize(ad->focus_edje, ad->camera_focus_w, ad->camera_focus_h);
	evas_object_move(ad->focus_edje, ad->af_start_x, ad->af_start_y);
	evas_object_show(ad->focus_edje);

	cam_app_draw_af_box(ad);
	cam_app_focus_guide_update(ad);
}

Eina_Bool cam_screen_rotate(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, -1, "appdata is NULL");

    if (ad->imageviewer_ug) {
		ad->is_rotating = FALSE;
		return FALSE;
    }

	elm_win_rotation_with_resize_set(ad->win_main, ad->angle);

	if (ad->focus_edje)
		cam_focus_edje_rotate(ad);

	if (ad->timer_icon_edje)
		cam_app_timer_icon_rotate(ad);

	if (ad->toolbar_edje)
		cam_toolbar_rotate(ad);

	if (ad->recording_edje)
		cam_recording_rotate(ad);

	if (ad->indicator_edje)
		cam_indicator_rotate(ad);

	if (ad->tip_popup)
		cam_tip_popup_rotate(ad);

	if (ad->pinch_edje)
		cam_zoom_create_pinch_edje(ad);

	if (ad->progress_popup != NULL)
		cam_popup_rotate(ad);

	cam_retvm_if(ad->camapp_handle == NULL, -1, "camapp_handle is NULL");

	toolbar_shot_guide_popup_create(ad, ad->camapp_handle->shooting_mode);

	if (ad->ev_edje) {
		unload_ev_edje(ad);
		load_ev_edje(ad);
	}

	if (ad->zoom_edje) {
		unload_zoom_edje(ad);
		load_zoom_edje(ad);
	}

	if (ad->guideline_edje)
		settings_guideline_refresh(ad);

	/*update thumbnail*/
	toolbar_update_quickview_thumbnail_no_animation(ad);
	/* rotate menu */
	DEBUG_TRACE("ad->displayed_setting_popup = %d", ad->displayed_setting_popup);
	DEBUG_TRACE("ad->show_edit_shortcuts_popup_after_rotate = %d", ad->show_edit_shortcuts_popup_after_rotate);
	DEBUG_TRACE("ad->show_setting_popup_after_rotate = %d", ad->show_setting_popup_after_rotate);
	if ((ad->displayed_setting_popup != DISPLAY_NONE_POPUP)
		|| (ad->show_edit_shortcuts_popup_after_rotate == TRUE)
		|| (ad->show_setting_popup_after_rotate == TRUE)) {
		/*ecore_idler_add(cam_show_setting_menu, ad);*/
		/*note: use timer to delay creating the popup*/
		ecore_timer_add(0.1, cam_show_setting_menu, ad);
	} else {
		ad->is_rotating = FALSE;
	}

	if (ad->confirm_popup)
		evas_object_raise(ad->confirm_popup);

	return ECORE_CALLBACK_CANCEL;
}

static Ecore_Idler *rotate_delay_idler = NULL;
Eina_Bool cam_app_screen_rotate_idler(void *data)
{
	if (rotate_delay_idler) {
		ecore_idler_del(rotate_delay_idler);
		rotate_delay_idler = NULL;
	}
	struct appdata *ad = (struct appdata *)data;
	cam_retv_if(ad == NULL, ECORE_CALLBACK_CANCEL);
	if (ad->ug_state == CAM_UG_TERMINATE_STATE
		|| ad->ug_state == CAM_UG_PAUSE_STATE) {
		ad->is_rotating = FALSE;
		return ECORE_CALLBACK_CANCEL;
	}
	cam_screen_rotate(ad);
	return ECORE_CALLBACK_CANCEL;
}

void cam_app_screen_rotate(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_ret_if(ad == NULL);
	if (ad->ug_state == CAM_UG_TERMINATE_STATE
		|| ad->ug_state == CAM_UG_PAUSE_STATE) {
		ad->is_rotating = FALSE;
		return;
	}
	CamAppData *cam_handle = ad->camapp_handle;
	cam_ret_if(cam_handle == NULL);
	DEBUG_TRACE("");

	if (ad->toolbar_edje) {
		rotate_delay_idler = ecore_idler_add(cam_app_screen_rotate_idler, data);
	}
}

gboolean cam_app_get_photo_resolution(int *width, int *height)
{
	cam_retv_if(width == NULL || height == NULL, FALSE);

	struct appdata *ad = (struct appdata *)cam_appdata_get();
	cam_retvm_if(ad == NULL, FALSE, "ad is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(ad->camapp_handle == NULL, FALSE, "camapp_handle is NULL");

	*width = CAM_RESOLUTION_W(camapp->photo_resolution);
	*height = CAM_RESOLUTION_H(camapp->photo_resolution);

	return TRUE;
}

gboolean cam_app_reset_resolution(void *data, int width, int height, gboolean force_set)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = NULL;
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp is NULL");

	gboolean ret = TRUE;
	int state = 0;

	cam_debug(LOG_MM, " reset resolution = [%d x %d], need_change_state = [%d]",
						  width, height, force_set);

	if (camapp->camera_mode == CAM_CAMERA_MODE) {
		int cur_img_w, cur_img_h = 0;
		int recommanded_cur_w, recommanded_cur_h = 0;
		int recommanded_new_w, recommanded_new_h = 0;

		ret &= cam_mm_get_image_size(&cur_img_w, &cur_img_h);

		if ((cur_img_w == 1392) && (cur_img_h == 1392)) {
			recommanded_cur_w = 1392;
			recommanded_cur_h = 1392;
		} else
			cam_mm_get_recommanded_preview_size(&recommanded_cur_w, &recommanded_cur_h);

		ret &= cam_mm_set_image_size(width, height);

		if ((width == 1392) && (height == 1392)) {
			recommanded_new_w = 1392;
			recommanded_new_h = 1392;
		} else
			cam_mm_get_recommanded_preview_size(&recommanded_new_w, &recommanded_new_h);

		DEBUG_TRACE("cam_mm_get_recommanded_preview_size CUR[%d %d] NEW[%d %d]",
						recommanded_cur_w, recommanded_cur_h, recommanded_new_w, recommanded_new_h);

		if ((recommanded_cur_w != recommanded_new_w)
			||(recommanded_cur_h != recommanded_new_h)
			||(force_set)) {

			state = cam_mm_get_cam_state();

			if (state == CAMERA_STATE_PREVIEW) {
				ret &= cam_app_preview_stop();
				ret &= cam_mm_set_video_size(recommanded_new_w, recommanded_new_h);
				ret &= cam_app_preview_start(ad);
			} else {
				ret &= cam_mm_set_video_size(recommanded_new_w, recommanded_new_h);
			}
		}
	} else if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		int cur_video_w, cur_video_h = 0;
		cam_mm_get_video_size(&cur_video_w, &cur_video_h);

		if (((cur_video_w != width) || (cur_video_h != height)) && (force_set)) {
			state = cam_mm_get_rec_state();

			if (state == RECORDER_STATE_READY) {
				ret &= cam_app_preview_stop();
				ret &= cam_mm_set_video_size(width, height);
				ret &= cam_app_preview_start(ad);
			} else {
				ret &= cam_mm_set_video_size(width, height);
			}
		} else {
			ret &= cam_mm_set_video_size(width, height);
		}
	} else {
		return FALSE;
	}
	return ret;
}

int cam_app_get_aenc_bitrate(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	int bitrate = 0;

	cam_retvm_if(ad == NULL, 0, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, 0, "camapp is NULL");

	if ((camapp->recording_mode == CAM_RECORD_MMS) ||(camapp->recording_mode == CAM_RECORD_SELF_MMS)) {
		bitrate = CAM_AUDIO_BITRATE_MMS;
	} else {
		bitrate = CAM_AUDIO_BITRATE_NORMAL;
	}

	return bitrate;
}

int cam_app_get_venc_bitrate(void *data, int quality)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	int return_val = 0;

	cam_retvm_if(ad == NULL, 0, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, 0, "camapp is NULL");

	if ((camapp->recording_mode == CAM_RECORD_MMS) ||(camapp->recording_mode == CAM_RECORD_SELF_MMS)) {
		switch (quality) {
		case CAM_QUALITY_HIGH:
		case CAM_QUALITY_BEST:
			return_val = 64000;
			break;

		case CAM_QUALITY_MEDIUM:
			return_val = 32000;
			break;

		case CAM_QUALITY_LOW:
			return_val = 16000;
			break;

		default:
			cam_critical(LOG_MM, "INVALID QUAILTY");
			break;
		}
	} else if ((camapp->recording_mode == CAM_RECORD_SLOW) ||(camapp->recording_mode == CAM_RECORD_FAST)) {
		switch (quality) {
		case CAM_QUALITY_HIGH:
		case CAM_QUALITY_BEST:
			return_val = 10000000;
			break;

		case CAM_QUALITY_MEDIUM:
			return_val = 4000000;
			break;

		case CAM_QUALITY_LOW:
			return_val = 2000000;
			break;

		default:
			cam_critical(LOG_MM, "INVALID QUAILTY");
			break;
		}
	} else {
		switch (camapp->video_resolution) {
		case CAM_RESOLUTION_FULLHD:
			{
				switch (quality) {
				case CAM_QUALITY_HIGH:
				case CAM_QUALITY_BEST:
					return_val = 8000000;
					break;

				case CAM_QUALITY_MEDIUM:
					return_val = 4000000;
					break;

				case CAM_QUALITY_LOW:
					return_val = 2000000;
					break;

				default:
					cam_critical(LOG_MM, "INVALID QUAILTY");
					break;
				}
			}
			break;
		case CAM_RESOLUTION_HD:
			{
				switch (quality) {
				case CAM_QUALITY_HIGH:
				case CAM_QUALITY_BEST:
					return_val = 10000000;
					break;

				case CAM_QUALITY_MEDIUM:
					return_val = 4000000;
					break;

				case CAM_QUALITY_LOW:
					return_val = 2000000;
					break;

				default:
					cam_critical(LOG_MM, "INVALID QUAILTY");
					break;
				}
			}
			break;

		case CAM_RESOLUTION_WVGA:
		case CAM_RESOLUTION_WVGA2:
			{
				switch (quality) {
				case CAM_QUALITY_HIGH:
				case CAM_QUALITY_BEST:
					return_val = 4000000;
					break;

				case CAM_QUALITY_MEDIUM:
					return_val = 2000000;
					break;

				case CAM_QUALITY_LOW:
					return_val = 1000000;
					break;

				default:
					cam_critical(LOG_MM, "INVALID QUAILTY");
					break;
				}
			}
			break;

		case CAM_RESOLUTION_VGA:

			{
				switch (quality) {
				case CAM_QUALITY_HIGH:
				case CAM_QUALITY_BEST:
					return_val = 3000000;
					break;

				case CAM_QUALITY_MEDIUM:
					return_val = 1500000;
					break;

				case CAM_QUALITY_LOW:
					return_val = 500000;
					break;

				default:
					cam_critical(LOG_MM, "INVALID QUAILTY");
					break;
				}
			}
			break;

		case CAM_RESOLUTION_WQVGA:
			{
				switch (quality) {
				case CAM_QUALITY_HIGH:
				case CAM_QUALITY_BEST:
					return_val = 2000000;
					break;

				case CAM_QUALITY_MEDIUM:
					return_val = 1000000;
					break;

				case CAM_QUALITY_LOW:
					return_val = 500000;
					break;

				default:
					cam_critical(LOG_MM, "INVALID QUAILTY");
					break;
				}
			}
			break;

		case CAM_RESOLUTION_QVGA:
			{
				switch (quality) {
				case CAM_QUALITY_HIGH:
				case CAM_QUALITY_BEST:
					return_val = 384000;
					break;

				case CAM_QUALITY_MEDIUM:
					return_val = 192000;
					break;

				case CAM_QUALITY_LOW:
					return_val = 64000;
					break;

				default:
					cam_critical(LOG_MM, "INVALID QUAILTY");
					break;
				}
			}
			break;

		case CAM_RESOLUTION_QCIF:
			{
				switch (quality) {
				case CAM_QUALITY_HIGH:
				case CAM_QUALITY_BEST:
					return_val = 384000;
					break;

				case CAM_QUALITY_MEDIUM:
					return_val = 192000;
					break;

				case CAM_QUALITY_LOW:
					return_val = 64000;
					break;

				default:
					cam_critical(LOG_MM, "INVALID QUAILTY");
					break;
				}
			}
			break;

		default:
			cam_critical(LOG_MM, "INVALID QUAILTY");
			break;
		}
	}

	cam_debug(LOG_MM, "videoenc bit rate = %d, current quilty = %d",
		  return_val, quality);
	return return_val;
}

gboolean cam_app_set_video_quality(void *data, int quality)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	int v_bitrate = 0;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp is NULL");

	v_bitrate = cam_app_get_venc_bitrate(ad, quality);
	if (v_bitrate > 0) {
		cam_mm_set_video_encoder_bitrate(v_bitrate);
	} else {
		return FALSE;
	}

	return TRUE;
}

gboolean cam_app_set_recording_mode(void *data, int mode)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	int video_codec = 0, audio_codec = 0, sample_rate = 0;
	int file_format = RECORDER_FILE_FORMAT_MP4;
	int channel = 0;
	int a_bitrate = 0;

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp is NULL");
	DEBUG_TRACE("mode = %d" , mode);
	if (mode == CAM_RECORD_MMS || mode == CAM_RECORD_SELF_MMS) {
		DEBUG_TRACE("mode = %d" , mode);
		video_codec = RECORDER_VIDEO_CODEC_H263;
		audio_codec = RECORDER_AUDIO_CODEC_AMR;
		sample_rate = 8000;
		file_format = RECORDER_FILE_FORMAT_3GP;
		channel = 1;
	} else {
		DEBUG_TRACE("mode = %d" , mode);
		video_codec = RECORDER_VIDEO_CODEC_MPEG4;
		audio_codec = RECORDER_AUDIO_CODEC_AAC;
		sample_rate = 44100;
		file_format = RECORDER_FILE_FORMAT_MP4;
		channel = 2;
	}
#ifdef CAMERA_MACHINE_I686
	video_codec = RECORDER_VIDEO_CODEC_THEORA;
	audio_codec = RECORDER_AUDIO_CODEC_VORBIS;
#endif

	if (!cam_mm_set_codec(audio_codec, video_codec))
		return FALSE;

	if (!cam_mm_set_audio_source(sample_rate, channel))
		return FALSE;

	a_bitrate = cam_app_get_aenc_bitrate(ad);
	if (a_bitrate > 0) {
		cam_mm_set_audio_encoder_bitrate(a_bitrate);
	} else {
		return FALSE;
	}

	if (!cam_app_set_video_quality(ad, camapp->video_quality))
		return FALSE;

	if (!cam_mm_set_file_format(file_format))
		return FALSE;

	return TRUE;
}

gboolean cam_app_set_size_limit(int max_val, int size_limit_type)
{
	int ret = 0;

	switch (size_limit_type) {
	case CAM_MM_SIZE_LIMIT_TYPE_BYTE:
		ret = cam_mm_set_max_size(max_val);
		if (!ret)
			return FALSE;
/*
		ret = cam_mm_set_max_time(REC_MAX_TIME_LIMITED);
		if (!ret)
			return FALSE;
*/
		break;
	case CAM_MM_SIZE_LIMIT_TYPE_SECOND:
		ret = cam_mm_set_max_size(0);
		if (!ret)
			return FALSE;
		ret = cam_mm_set_max_time(max_val);
		if (!ret)
			return FALSE;
		break;
	default:
		g_assert_not_reached();
	}

	return TRUE;
}

gboolean cam_app_init_attribute(void *data, CamMode mode)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	gboolean ret = TRUE;
	int width = 0;
	int height = 0;
	int state = 0;
	int rotate = CAMERA_ROTATION_270;
	int camera_rotate = CAMERA_ROTATION_NONE;
	int video_dev = 0;
	int capture_video_format = -1;
	#ifdef TODO_SURRPORT
	int recording_video_format = -1;
	#endif

	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp is NULL");

	state = cam_mm_get_state();

#if 0
	if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		if (state != RECORDER_STATE_CREATED) {
			return FALSE;
		}
	} else if(camapp->camera_mode == CAM_CAMERA_MODE) {
		if (state != CAMERA_STATE_CREATED) {
			return FALSE;
		}
	}
#endif

	cam_mm_get_video_size( &camapp->default_preview_width, &camapp->default_preview_height);
	DEBUG_TRACE("default_width = %d,default_height = %d", camapp->default_preview_width, camapp->default_preview_height);

#ifdef CAMERA_MACHINE_I686
	width = 320;
	height = 240;
#endif

	if (CAM_CAMERA_MODE == mode) {
		width = CAM_RESOLUTION_W(camapp->photo_resolution);
		height = CAM_RESOLUTION_H(camapp->photo_resolution);

		ret &= cam_mm_set_image_size(width, height);
		ret &= cam_mm_set_image_count(camapp->image_count);
		ret &= cam_mm_set_image_enc_quality(camapp->image_quality);
#ifdef CAMERA_MACHINE_I686
		ret &= cam_mm_set_fps(CAMERA_ATTR_FPS_15);
		ret &= cam_mm_set_video_source_format(CAMERA_PIXEL_FORMAT_I420);
#else
		ret &= cam_mm_set_fps(CAMERA_ATTR_FPS_AUTO);
		ret &= cam_mm_get_video_source_format(NULL, &capture_video_format);
		ret &= cam_mm_set_video_source_format(capture_video_format);
#endif
		ret &= cam_app_set_capture_format_shooting_mode(camapp->shooting_mode);

		if (cam_is_enabled_menu(ad, CAM_MENU_SAVE_AS_FLIP))
			ret &= cam_mm_set_image_flip(camapp->save_as_flip);
		else
			ret &= cam_mm_set_image_flip(FALSE);

		ret &= cam_mm_set_anti_hand_shake(camapp->anti_shake);
	} else if (CAM_CAMCORDER_MODE == mode) {
		width = CAM_RESOLUTION_W(camapp->video_resolution);
		height = CAM_RESOLUTION_H(camapp->video_resolution);

		ret &= cam_mm_set_image_size(CAM_RESOLUTION_W(camapp->photo_resolution), CAM_RESOLUTION_H(camapp->photo_resolution));
		ret &= cam_mm_set_image_enc_quality(camapp->image_quality);
		ret &= cam_mm_set_video_profile();
#ifdef CAMERA_MACHINE_I686
		ret &= cam_mm_set_fps(CAMERA_ATTR_FPS_15);
		ret &= cam_mm_set_video_source_format(CAMERA_PIXEL_FORMAT_I420);
		DEBUG_TRACE("");
#else
		DEBUG_TRACE("");
		ret &= cam_mm_set_fps(camapp->fps);
		if (camapp->anti_shake) {
			ret &= cam_mm_set_video_source_format(CAMERA_PIXEL_FORMAT_NV12);
		} else {
			ret &= cam_mm_get_video_source_format(NULL, &recording_video_format);
			DEBUG_TRACE("recording_video_format:%d", recording_video_format);
			ret &= cam_mm_set_video_source_format(recording_video_format);
		}
#endif
		ret &= cam_mm_set_audio_recording(camapp->audio_recording);
		ret &= cam_app_set_recording_mode(ad, camapp->recording_mode);
		DEBUG_TRACE("camapp->size_limit = %d" , camapp->size_limit);
		DEBUG_TRACE("camapp->size_limit_type = %d" , camapp->size_limit_type);
		ret &= cam_app_set_size_limit(camapp->size_limit, camapp->size_limit_type);
	} else {
		return FALSE;
	}
	cam_mm_get_video_device(&video_dev);
	DEBUG_TRACE("video_dev = %d",video_dev);
	if (video_dev == CAM_DEVICE_VGA) {
		int value;
		cam_mm_get_front_cam_display_rotate_value(&value, &rotate);

		DEBUG_TRACE("get front camera rotate %d value = %d", rotate, value);
		/*rotate = value;*/
		#ifdef TODO_SURRPORT
		rotate = CAMERA_ROTATION_270;
		#endif /*TODO:if new capi will released, this could be removed,but take care.*/

	}
	cam_mm_get_zoom_valid_intrange(&camapp->zoom_min,&camapp->zoom_max);
	DEBUG_TRACE("Zoom range [%d - %d]",camapp->zoom_min, camapp->zoom_max);

	cam_mm_get_brightless_valid_intrange(&camapp->brightness_min,&camapp->brightness_max);
	DEBUG_TRACE("brightness range [%d - %d]",camapp->brightness_min, camapp->brightness_max);
	camapp->brightness = (camapp->brightness_min + camapp->brightness_max) /2;

	ret &= cam_mm_remove_geo_tag();
	DEBUG_TRACE("cam_mm_remove_geo_tag = %d", ret);
	ret &= cam_mm_set_display_device(CAMERA_DISPLAY_TYPE_X11, GET_DISPLAY(ad->main_xid));
	ret &= cam_mm_set_camera_rotate(camera_rotate);
	ret &= cam_mm_set_display_rotate(rotate);
	ret &= cam_mm_set_display_geometry_method(CAMERA_DISPLAY_MODE_LETTER_BOX);
#ifndef USE_CAMERA_APP_SHUTTER_SOUND
	ret &= cam_mm_set_shutter_sound(TRUE);
#endif
	ret &= cam_app_reset_resolution(ad, width, height, TRUE);
	ret &= cam_mm_set_zoom(camapp->zoom_mode);
	ret &= cam_mm_set_auto_exposure(camapp->auto_exposure);
	ret &= cam_mm_set_iso(camapp->iso);
	ret &= cam_mm_set_wdr(camapp->wdr);
	ret &= cam_mm_set_brightness(camapp->brightness);
	ret &= cam_mm_enable_auto_contrast(camapp->auto_contrast);
	ret &= cam_mm_set_white_balance(camapp->white_balance);
	ret &= cam_mm_set_effect(camapp->effect);
	ret &= cam_mm_set_program_mode(camapp->scene_mode);

	if (ad->torchlight_on && camapp->flash != CAM_FLASH_OFF)
		ret &= cam_mm_set_flash(CAM_FLASH_OFF);
	else
		ret &= cam_mm_set_flash(camapp->flash);

	if (camapp->af_mode == CAM_FOCUS_AUTO
	    || camapp->af_mode == CAM_FOCUS_MACRO) {
		ret &= cam_mm_set_focus_mode(camapp->af_mode);
	} else if (camapp->af_mode == CAM_FOCUS_FACE) {
		ret &= cam_mm_set_focus_mode(CAMERA_ATTR_AF_NORMAL);
	}

	ret &= cam_mm_set_tag_enable(TRUE);
	ret &= cam_mm_set_outdoor_visibility(camapp->outdoor_visibility);
	ad->enable_mode_change = TRUE;
	ad->is_recording = FALSE;
	return ret;

}

static void cam_app_update_gps_level(void *data, int lbs_state)
{
	struct appdata *ad = (struct appdata *)data;
	GValue value = { 0, };
	cam_retm_if(ad == NULL, "appdata is NULL");

	cam_debug(LOG_UI, "	cam_app_update_gps_level : %d", lbs_state);

	CAM_GVALUE_SET_INT(value, lbs_state);
	cam_handle_value_set(ad, PROP_GPS_LEVEL, &value);

	return;
}

static gboolean cam_app_return_ext_app(void *data, const char *r_file_path)
{
	struct appdata *ad = (struct appdata *)data;
	service_h reply;
	service_create(&reply);

	if (ad->service_mime != NULL) {
		if (r_file_path == NULL) {
			service_add_extra_data(reply, SERVICE_DATA_SELECTED, "exit");
			service_reply_to_launch_request(reply, ad->service_handle, SERVICE_RESULT_FAILED);
		} else {
			service_add_extra_data(reply, SERVICE_DATA_SELECTED, r_file_path);
			service_reply_to_launch_request(reply, ad->service_handle, SERVICE_RESULT_SUCCEEDED);
		}
	}

	service_destroy(reply);
	return TRUE;

}
static void cam_app_battery_status_cb(keynode_t *key, void *data)
{
	struct appdata *ad = (struct appdata *)data;

	debug_fenter(LOG_UI);
	cam_retm_if(ad == NULL, "appdata is NULL");

	int low_status = -1;

	if (!vconf_get_int(VCONFKEY_SYSMAN_BATTERY_STATUS_LOW, &low_status)) {
		cam_debug(LOG_UI, "battery status low = %d", low_status);
		if (low_status <= VCONFKEY_SYSMAN_BAT_CRITICAL_LOW) {
			ad->battery_status = LOW_BATTERY_CRITICAL_STATUS;
			cam_app_notice_popup(ad, dgettext("sys_string", "IDS_COM_BODY_LOW_BATTERY"),
			cam_app_timeout_notice_response_cb);
		} else if (low_status == VCONFKEY_SYSMAN_BAT_WARNING_LOW) {
			ad->battery_status = LOW_BATTERY_WARNING_STATUS;
			cam_app_notice_popup((void *)ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_USE_FLASH_BATTERY_LOW"), cam_app_lowbattery_close_flash_cb);
		} else {
			ad->battery_status = NORMAL_BATTERY_STATUS;
		}
	}

	return;
}
/*if torch light vconf key value is changed, this cb is called*/
static void cam_torchlight_update_cb(keynode_t *key, void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is NULL");

	int key_value = vconf_keynode_get_bool(key); /* -1: error, 1:True, 0:False */
	if (key_value == -1) {
		DEBUG_TRACE("vconf_keynode_get_bool failed");
		return;
	}
	DEBUG_TRACE("VCONFKEY_SETAPPL_ACCESSIBILITY_TORCH_LIGHT is changed to %d", key_value);
	if (key_value) {
		/* disable flash icon */
		ad->torchlight_on = TRUE;
		cam_mm_set_flash(CAM_FLASH_OFF);

	} else {
		/* enable flash icon */
		ad->torchlight_on = FALSE;
		cam_mm_set_flash(camapp->flash);
	}
	cam_toolbar_update(ad); /*update flash icon*/
	return;
}

static void cam_app_battery_update_cb(keynode_t *key, void *data)
{
	struct appdata *ad = (struct appdata *)data;
	CamAppData *camapp = NULL;
	char *keyname = NULL;

	debug_fenter(LOG_UI);

	cam_retm_if(ad == NULL, "appdata is NULL");
	camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp_handle is NULL");

	keyname = vconf_keynode_get_name(key);

	if (!strcmp(keyname, VCONFKEY_SYSMAN_BATTERY_CHARGE_NOW)) {
		GValue value = { 0 };
		gint charging = vconf_keynode_get_int(key);
		DEBUG_TRACE("charging = %d", charging);
		CAM_GVALUE_SET_INT(value, charging);
		cam_handle_value_set(ad, PROP_BATTERY_CHARG, &value);

	} else if (!strcmp(keyname, VCONFKEY_SYSMAN_BATTERY_CAPACITY)) {
		GValue value = { 0 };
		int battery_level = vconf_keynode_get_int(key);
		CAM_GVALUE_SET_INT(value, battery_level);
		cam_handle_value_set(ad, PROP_BATTERY_LEVEL, &value);
	}
	return;
}

#if 0
Evas_Object *cam_screen_load_edj(Evas_Object *parent, const char *file,
				 const char *group)
{
	Evas_Object *eo;
	int r;

	eo = elm_layout_add(parent);
	if (eo) {
		r = elm_layout_file_set(eo, file, group);
		if (!r) {
			evas_object_del(eo);
			return NULL;
		}

		evas_object_size_hint_weight_set(eo,
						 EVAS_HINT_EXPAND,
						 EVAS_HINT_EXPAND);

		/*      //if(!strcmp((const char *)elm_widget_type_get(parent), "win")) { */
		elm_win_resize_object_add(parent, eo);
		/*      //} */
	}

	return eo;
}
#endif
Evas_Object *cam_app_load_edj(Evas_Object *parent, const char *file,
			      const char *group)
{
	Evas_Object *eo = NULL;
	int r = 0;

	eo = elm_layout_add(parent);
	if (eo) {
		r = elm_layout_file_set(eo, file, group);
		if (!r) {
			evas_object_del(eo);
			return NULL;
		}

		evas_object_size_hint_weight_set(eo, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
		evas_object_show(eo);
	}

	return eo;
}

Eina_Bool __cam_app_update_thumbnail_idler(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	if (!ad) {
		return ECORE_CALLBACK_CANCEL;
	}
	CamAppData *camapp = ad->camapp_handle;

	if (!camapp) {
		REMOVE_IDLER(ad->update_thumbnail_idler);
		return ECORE_CALLBACK_CANCEL;
	}

	DEBUG_TRACE(" ");

	if (!g_file_test(camapp->filename,G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)) {
		DEBUG_TRACE( "The captured File is not existed");
		REMOVE_IDLER(ad->update_thumbnail_idler);
		return ECORE_CALLBACK_CANCEL;;
	}

	gboolean ret = FALSE;

	if (ad->imageviewer_ug) { /*review on */
		DEBUG_TRACE("Image viewer was LAUNCHED. skip this...");
		REMOVE_IDLER(ad->update_thumbnail_idler);
		return ECORE_CALLBACK_CANCEL;;
	}

	if (camapp->thumbnail_name != NULL) {
		free (camapp->thumbnail_name);
		camapp->thumbnail_name = NULL;

	}

	ret = cam_file_get_cam_file_thumbnail_path(camapp->filename, &camapp->thumbnail_name);
	DEBUG_TRACE("ret[0:success] = [%d] camapp->filename: [%s]",
		  ret, camapp->filename);
	DEBUG_TRACE("ret[0:success] = [%d] camapp->thumbnail_name: [%s]",
		  ret, camapp->thumbnail_name);
	if (!g_file_test(camapp->thumbnail_name, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)) {

		if (g_thumbnail_image_check_count > 10) {
			REMOVE_IDLER(ad->update_thumbnail_idler);
			return ECORE_CALLBACK_CANCEL;
		}

		DEBUG_TRACE("The thumbnail File is not existed,try the %d nums", g_thumbnail_image_check_count);
		g_thumbnail_image_check_count++;
		usleep(THUMBNAIL_UPDATE_WAIT_TIME);
		/*REMOVE_IDLER(ad->update_thumbnail_idler);*//*note:renew, do not delete idler*/
		return ECORE_CALLBACK_RENEW;
	}
	else if (camapp->camera_mode == CAM_CAMERA_MODE) {
		DEBUG_TRACE("thumbnail image check count=[%d]", g_thumbnail_image_check_count);
		toolbar_update_quickview_thumbnail(ad);
	}
	else if (camapp->camera_mode == CAM_CAMCORDER_MODE) {
		toolbar_update_quickview_thumbnail(ad);

	} else {
		DEBUG_TRACE("NOT REACHED CODES REACHED!");
	}
	REMOVE_IDLER(ad->update_thumbnail_idler);
	return ECORE_CALLBACK_CANCEL;
}
/* update thumbnail to quickview after first launching or return from image viewer */
void cam_app_update_quickview_icon(void *data) {

	struct appdata *ad = (struct appdata *)data;
	cam_ret_if(ad == NULL);
	cam_ret_if(ad->camapp_handle == NULL);
	gchar *filename = NULL;

	DEBUG_TRACE("");

	/*To update quickview image, get last filename*/
	if (ad->camapp_handle->filename) {
		free(ad->camapp_handle->filename);
		ad->camapp_handle->filename = NULL;
	}

	if (ad->camapp_handle->thumbnail_name) {
		free(ad->camapp_handle->thumbnail_name);
		ad->camapp_handle->thumbnail_name = NULL;
	}

	filename = cam_app_get_last_filename();

	if (filename != NULL) {
		ad->camapp_handle->filename = strdup(filename);
		free(filename);
		filename = NULL;

		if (!cam_file_get_cam_file_thumbnail_path
			(ad->camapp_handle->filename, &ad->camapp_handle->thumbnail_name))
			DEBUG_TRACE("cam_file_get_cam_file_thumbnail_path() fail");

	}

	toolbar_update_quickview_thumbnail_no_animation(ad);

	return;
}

void cam_app_update_thumbnail()
{
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	cam_ret_if(ad == NULL);
	CamAppData *camapp = ad->camapp_handle;
	cam_ret_if(camapp == NULL);

	DEBUG_TRACE("cam_app_update_thumbnail");

	if (CAM_LAUNCHING_MODE_NORMAL == ad->launching_mode && camapp->filename) {
		DEBUG_TRACE();
		g_thumbnail_image_check_count = 0;
		if (!ad->update_thumbnail_idler)
			ad->update_thumbnail_idler = ecore_idler_add(__cam_app_update_thumbnail_idler, ad);
	}
	return;
}

gboolean cam_app_parse_args(CamExeArgs *args, service_h service)
{
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	cam_retv_if(ad == NULL, FALSE);

	ad->service_mime = NULL;

	int ret = service_get_mime(service, &ad->service_mime);
	if (ret != SERVICE_ERROR_NONE) {
		cam_debug(LOG_UI, "service_get_mime is error ");
		return FALSE;
	}

	/* mime type */
	if (ad->service_mime != NULL) {
		if ((strcmp(ad->service_mime, SERVICE_MIME_TYPE_IMAGE_1) == 0)
			|| (strcmp(ad->service_mime, SERVICE_MIME_TYPE_IMAGE_2) == 0)) {
			args->cam_mode = CAM_CAMERA_MODE;
		} else if ((strcmp(ad->service_mime, SERVICE_MIME_TYPE_VIDEO_1) == 0)
			|| (strcmp(ad->service_mime, SERVICE_MIME_TYPE_VIDEO_2) == 0)) {
			args->cam_mode = CAM_CAMCORDER_MODE;
		} else {
			cam_critical(LOG_UI, "invalid mime type");
			args->cam_mode = CAM_CAMERA_MODE;
		}
	} else {
		cam_critical(LOG_UI, "service mime is NULL");
		args->cam_mode = CAM_CAMERA_MODE;
	}

	/* allow switch */
	const char *val = NULL;
	service_get_extra_data(service, SERVICE_OPTIONAL_KEY_ALLOW_SWITCH, (char **)&val);
	if (val) {
		if (0 == strcmp(val, "true")) {
			args->allow_switch = TRUE;
			args->cam_mode = CAM_CAMERA_MODE;
		} else {
			args->allow_switch = FALSE;
		}
	} else {
		args->allow_switch = FALSE;
	}

	/* get caller appl. */
	val = NULL;
	service_get_extra_data(service, "CALLER", (char **)&val);
	if (val) {
		cam_debug(LOG_UI, "CALLER %s", val);
		args->caller = strdup(val);
	} else {
		args->caller = NULL;
	}

	/* resolution */
	val = NULL;
	int res = 0;
	service_get_extra_data(service, "RESOLUTION", (char **)&val);
	if (val) {
		cam_debug(LOG_UI, "RESOLUTION %s", val);

		if (args->cam_mode == CAM_CAMERA_MODE) {
			if (0 == strcmp(val, CAM_CAPTURE_RES_VGA))
				res = CAM_RESOLUTION_VGA;
			else
				res = IMAGE_RESOLUTION_DEFAULT;
		} else {
			if (0 == strcmp(val, CAM_RECORDING_RES_QCIF))
				res = CAM_RESOLUTION_QCIF;
			else
				res = REC_RESOLUTION_DEFAULT;
		}
	} else {
		if (args->cam_mode == CAM_CAMERA_MODE) {
			res = IMAGE_RESOLUTION_DEFAULT;
		} else {
			res = REC_RESOLUTION_DEFAULT;
		}
	}
	args->width = CAM_RESOLUTION_W(res);
	args->height = CAM_RESOLUTION_H(res);
	args->resolution = res;

	/* size limit */
	val = NULL;
	service_get_extra_data(service, "LIMIT", (char **)&val);
	if (val) {
		cam_debug(LOG_UI, "LIMIT %s", val);
		args->size_limit = atoi(val);
	} else {
		args->size_limit = REC_SIZE_LIMIT_DEFAULT;
	}

	args->review = TRUE;

	/*  print exe args */
	cam_debug(LOG_SYS, "############### exe args ###############");
	cam_debug(LOG_SYS, "mode =%d", args->cam_mode);
	cam_debug(LOG_SYS, "caller =%s", args->caller);
	cam_debug(LOG_SYS, "width =%d", args->width);
	cam_debug(LOG_SYS, "height =%d", args->height);
	cam_debug(LOG_SYS, "limit =%d", args->size_limit);
	cam_debug(LOG_SYS, "review =%d", args->review);
	cam_debug(LOG_SYS, "allow_switch =%d", args->allow_switch);
	cam_debug(LOG_SYS, "############### end ###############");

	return TRUE;
}


void cam_app_draw_af_box(void *data)
{

	cam_retm_if(data == NULL, "data is null");
	struct appdata *ad = (struct appdata *)data;
	ad->af_start_x = 0;
	ad->af_start_y = 0;

	switch (ad->rot_current) {
	case APP_DEVICE_ORIENTATION_0:
		{
			ad->af_start_x = ad->touch_lcd_x;
			ad->af_start_y = ad->touch_lcd_y;
		}
		break;
	case APP_DEVICE_ORIENTATION_180:
		{
			ad->af_start_x = ad->win_height - ad->touch_lcd_x;
			ad->af_start_y = ad->win_width - ad->touch_lcd_y;
		}
		break;
	case APP_DEVICE_ORIENTATION_270:
		{
			ad->af_start_x = ad->touch_lcd_y;
			ad->af_start_y = ad->win_height - ad->touch_lcd_x;
		}
		break;
	case APP_DEVICE_ORIENTATION_90:
		{
			ad->af_start_x = ad->win_width - ad->touch_lcd_y;
			ad->af_start_y = ad->touch_lcd_x;
		}
		break;
	default:
		break;
	}

	/* adjust */
	DEBUG_TRACE("ad->af_start_x=%f, ad->af_start_y=%f", ad->af_start_x, ad->af_start_y);

	ad->camera_focus_w = CAMERA_FOCUS_W * elm_config_scale_get();
	ad->camera_focus_h = CAMERA_FOCUS_H * elm_config_scale_get();
	DEBUG_TRACE("ad->camera_focus_w=%f, ad->camera_focus_h=%f", ad->camera_focus_w, ad->camera_focus_h);

	ad->af_start_x = ad->af_start_x - (ad->camera_focus_w / 2);
	ad->af_start_y = ad->af_start_y - (ad->camera_focus_h / 2);
	DEBUG_TRACE("af area box start x,y =[%f,%f]\n", ad->af_start_x, ad->af_start_y);

	if (ad->rot_current == APP_DEVICE_ORIENTATION_270
	    || ad->rot_current == APP_DEVICE_ORIENTATION_90) {
		if (ad->af_start_x < ad->preview_offset_x) {
			ad->af_start_x = ad->preview_offset_x;
		}
		if (ad->af_start_y < ad->preview_offset_y) {
			ad->af_start_y = ad->preview_offset_y;
		}
		if ((ad->af_start_x + ad->camera_focus_w) >
		    (ad->preview_w + ad->preview_offset_x)) {
			ad->af_start_x =
			    (ad->preview_w + ad->preview_offset_x) -
			    ad->camera_focus_w;
		}
		if ((ad->af_start_y + ad->camera_focus_h) >
		    (ad->preview_h + ad->preview_offset_y)) {
			ad->af_start_y =
			    (ad->preview_h + ad->preview_offset_y) -
			    ad->camera_focus_h;
		}

	} else {
		if (ad->af_start_y < ad->preview_offset_x) {
			ad->af_start_y = ad->preview_offset_x;
		}
		if (ad->af_start_x < ad->preview_offset_y) {
			ad->af_start_x = ad->preview_offset_y;
		}
		if ((ad->af_start_y + ad->camera_focus_h) >
		    (ad->preview_w + ad->preview_offset_x)) {
			ad->af_start_y =
			    (ad->preview_w + ad->preview_offset_x) -
			    ad->camera_focus_h;
		}
		if ((ad->af_start_x + ad->camera_focus_w) >
		    (ad->preview_h + ad->preview_offset_y)) {
			ad->af_start_x =
			    (ad->preview_h + ad->preview_offset_y) -
			    ad->camera_focus_w;
		}
	}

	if (ad->focus_edje) {
		DEBUG_TRACE
		    ("####################################################");
		DEBUG_TRACE("af area start ,ad->af_start_x,y =[%f,%f]\n",
			    ad->af_start_x, ad->af_start_y);
		DEBUG_TRACE
		    ("####################################################");
		evas_object_move(ad->focus_edje, ad->af_start_x,
				 ad->af_start_y);
		DEBUG_TRACE(" MOVE FOCUS_EDJE : %f,%f", ad->af_start_x,
			    ad->af_start_y);
	}

}


/*  get preview start x,y coordinate */
void cam_app_get_preview_offset_coordinate(void *data)
{

	cam_retm_if(data == NULL, "data is null");
	struct appdata *ad = (struct appdata *)data;

	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is null");

	int width = 0;
	int height = 0;
	CamVideoRectangle result;	/* result ractangle */
	CamVideoRectangle window;	/* target window ractangle */
	CamVideoRectangle preview;	/* target preview rectangle */
	/*wow,now, the MMHandleType is not created*/
	cam_mm_get_video_size(&width, &height);

	ad->camfw_video_width = width;
	ad->camfw_video_height = height;

	preview.w = width;
	preview.h = height;
	DEBUG_TRACE("************************************************");
	DEBUG_TRACE("preview.w =%d, preview.h=%d", preview.w, preview.h);

	window.h = ad->win_height;
	window.w = ad->win_width;
	DEBUG_TRACE("window.w =%d, window.h=%d\n", window.w, window.h);
	DEBUG_TRACE("************************************************");
	cam_app_preview_start_coordinate(preview, window, &result);

	ad->preview_offset_x = result.x;
	ad->preview_offset_y = result.y;
	ad->preview_w = result.w;
	ad->preview_h = result.h;

	DEBUG_TRACE("************************************************");
	DEBUG_TRACE("ad->preview_offset_x = %d, ad->preview_offset_y = %d",
		    ad->preview_offset_x, ad->preview_offset_y);
	DEBUG_TRACE("*************************************************");

	camapp->focus_state = CAM_FOCUS_STATUS_RELEASED;
	cam_app_focus_guide_update(ad);

	/* init */
	ad->af_x = (ad->win_width / 2) - ad->preview_offset_x;
	ad->af_y = (ad->win_height / 2) - ad->preview_offset_y;

	ad->af_x = (ad->af_x * ad->camfw_video_width) / ad->preview_w;
	ad->af_y = (ad->af_y * ad->camfw_video_height) / ad->preview_h;
	/* init */
	ad->touch_lcd_x = (ad->win_height / 2);
	ad->touch_lcd_y = (ad->win_width / 2);

	DEBUG_TRACE("*************************************************");
	DEBUG_TRACE(" ad->af_x=%d, ad->af_y=%d", ad->af_x, ad->af_y);
	DEBUG_TRACE(" ad->af_start_x=%d, ad->af_start_y=%d", ad->af_start_x, ad->af_start_y);
	DEBUG_TRACE(" ad->touch_lcd_x=%d, ad->touch_lcd_y=%d", ad->touch_lcd_x, ad->touch_lcd_y);
	DEBUG_TRACE("*************************************************");

	cam_app_draw_af_box(ad);

	if (ad->focus_edje)
		evas_object_show(ad->focus_edje);
}

void cam_app_preview_start_coordinate(CamVideoRectangle src,
				      CamVideoRectangle dst,
				      CamVideoRectangle *result)
{
	/* src is target preview rectangle */
	/* dst is target window rectangle */
	g_return_if_fail(result != NULL);
	gdouble src_ratio, dst_ratio;
	src_ratio = (gdouble) src.w / src.h;
	dst_ratio = (gdouble) dst.w / dst.h;
	if (src_ratio > dst_ratio) {
		DEBUG_TRACE("#### case 1\n");
		result->w = dst.w;
		result->h = dst.w / src_ratio;
		result->x = 0;
		result->y = (dst.h - result->h) / 2;
	} else if (src_ratio < dst_ratio) {
		DEBUG_TRACE("#### case 2\n");
		result->w = dst.h * src_ratio;
		result->h = dst.h;
		result->x = (dst.w - result->w) / 2;
		result->y = 0;
	} else {
		DEBUG_TRACE("#### case 3\n");
		result->x = 0;
		result->y = 0;
		result->w = dst.w;
		result->h = dst.h;
	}
	DEBUG_TRACE
	    ("************************************************************");
	DEBUG_TRACE
	    ("source is %dx%d dest is %dx%d, result window size is %dx%d result offset x= %dx y=%d",
	     src.w, src.h, dst.w, dst.h, result->w, result->h, result->x,
	     result->y);
	DEBUG_TRACE
	    ("************************************************************");
}


void cam_remove_tmp_file()
{
	const gchar *default_path = NULL;
	char tmpfile_name[256] = { 0 };

	default_path = cam_file_get_internal_video_path();
	DEBUG_TRACE(" video = %s", default_path);
	snprintf(tmpfile_name, sizeof(tmpfile_name), "%s%s", default_path,
		 TMPFILE_PREFIX);
	if (g_file_test(tmpfile_name, G_FILE_TEST_EXISTS)) {
		DEBUG_TRACE("REMOVE tmp file");
		unlink(tmpfile_name);
	}
	default_path = cam_file_get_external_video_path();
	DEBUG_TRACE(" video = %s", default_path);
	snprintf(tmpfile_name, sizeof(tmpfile_name), "%s%s", default_path,
		 TMPFILE_PREFIX);

	if (g_file_test(tmpfile_name, G_FILE_TEST_EXISTS)) {
		DEBUG_TRACE("REMOVE tmp file");
		unlink(tmpfile_name);
	}

}

Eina_Bool cam_app_launch_after_preview_began(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retv_if(ad == NULL, FALSE);

	cam_debug(LOG_UI, "cam_app_launch_after_preview_began");

	int state = cam_mm_get_state();

	if (state != RECORDER_STATE_RECORDING) {
		cam_debug(LOG_UI, "remove previous file");
		cam_remove_tmp_file();
	}

	cam_app_get_preview_offset_coordinate(data);
	cam_toolbar_setting_popup_create(data);
	return ECORE_CALLBACK_CANCEL;
}

void cam_utils_remove_idler_all(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	GList *list = NULL;
	Ecore_Idler *idler = NULL;

	debug_fenter(LOG_UI);

	cam_retm_if(ad == NULL, "appdata is NULL");

	/*LOCK
	   In fact, a Lock is needed here. However, because all related functions are working main loop, practically it may not be needed. */

	if (!ad->capture_cb_list) {
		cam_debug(LOG_UI, "No idler is remained.");
	} else {
		list = ad->capture_cb_list;

		while (list) {
			idler = list->data;

			if (!idler) {
				cam_warning(LOG_UI,
					    "Fail to remove idler. The idler is NULL");
			} else {
				cam_debug(LOG_UI, "Remove idler[%p].", idler);
				ecore_idler_del(idler);

				ad->capture_cb_list =
				    g_list_remove(ad->capture_cb_list, idler);
			}

			list = g_list_next(list);
		}

		g_list_free(ad->capture_cb_list);
		ad->capture_cb_list = NULL;
	}

	/* UNLOCK */
	debug_fleave(LOG_UI);
	return;
}

Eina_Bool cam_elm_cache_flush()
{
/*Make the canvas discard as much data as possible used by the engine at runtime.*/
	DEBUG_TRACE("start");
	struct appdata *ad = (struct appdata *)cam_appdata_get();
	if (ad) {
		if (ad->evas) {
			evas_render_idle_flush(ad->evas);
		}
	}
	elm_cache_all_flush();
	DEBUG_TRACE("end");
	return EINA_TRUE;
}

gboolean cam_condition_check_to_start_camera(void *data)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, EINA_FALSE, "appdata is NULL");

	/* check battery */
	if (cam_utils_check_battery_critical_low()) {
		ad->battery_status = LOW_BATTERY_CRITICAL_STATUS;
		cam_app_notice_popup(ad, dgettext("sys_string", "IDS_COM_BODY_LOW_BATTERY"), cam_app_timeout_notice_response_cb);
		return FALSE;
	} else if (cam_utils_check_battery_warning_low()) {
		ad->battery_status = LOW_BATTERY_WARNING_STATUS;
		cam_app_notice_popup((void *)ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_USE_FLASH_BATTERY_LOW"), cam_app_lowbattery_close_flash_cb);
	} else {
		ad->battery_status = NORMAL_BATTERY_STATUS;
	}

	if (cam_utils_check_call_running()) {
		ad->is_calling = TRUE;
		cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA_DURING_CALL"), cam_app_timeout_notice_response_cb);
		return FALSE;
	} else
		ad->is_calling = FALSE;

	return TRUE;
}

static Eina_Bool __cam_continuous_af_timer_cb(void *data)
{
	DEBUG_TRACE("");

	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");

	if (ad->continuous_af_timer)
		ad->continuous_af_timer = NULL;

	cam_reset_focus_mode(ad);

	return ECORE_CALLBACK_CANCEL;
}

void cam_reset_focus_mode(void *data)
{
	DEBUG_TRACE("");

	struct appdata *ad = (struct appdata *)data;
	cam_retm_if(ad == NULL, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is NULL");

	if (ad->caf_button)
		cam_toolbar_show_cafbutton(ad, FALSE);

	cam_reset_focus_coordinate(ad);

	camapp->touch_af_state = CAM_TOUCH_AF_STATE_NONE;
	camapp->focus_state = CAM_FOCUS_STATUS_RELEASED;

	cam_app_focus_guide_create(ad);
	cam_app_focus_guide_update(ad);

	cam_continuous_af_start(ad);
}

static Eina_Bool __focus_guide_destroy(void *data)
{
	DEBUG_TRACE("");

	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, ECORE_CALLBACK_CANCEL, "appdata is NULL");

	if (ad->continuous_af_timer)
		ad->continuous_af_timer = NULL;
	DEL_EVAS_OBJECT(ad->focus_edje);

	return ECORE_CALLBACK_CANCEL;
}


gboolean cam_set_default_capture_mode(void *data, CamCaptureMode type)
{
	DEBUG_TRACE("");

	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	if (camapp->camera_mode == CAM_CAMERA_MODE
		&& camapp->shooting_mode == CAM_SINGLE_MODE
		&& camapp->burst_shot == TRUE) {

		camapp->default_capture_mode = type;
		if (camapp->default_capture_mode == CAM_CAPTURE_BURST)
			camapp->capture_cb = (camera_capturing_cb)cam_continuous_shot_capture_callback;
		else
			camapp->capture_cb = (camera_capturing_cb)__cam_capture_cb;

	} else
		return FALSE;


	return TRUE;
}

gint cam_app_get_max_image_size_by_ratio(void *data, int resolution)
{
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");
	CamAppData *camapp = ad->camapp_handle;
	cam_retvm_if(camapp == NULL, FALSE, "camapp_handle is NULL");

	gint result = 0;
	unsigned int capacity = 0;
	gdouble ratio = (gdouble) CAM_RESOLUTION_W(resolution) / CAM_RESOLUTION_H(resolution);

	GetCamDevCamResolutionCaps(&capacity, ad);

	if (ratio == (gdouble)4.0/3.0) {
		if (capacity & CAM_CP_SIZE_3264X2448)
			result = CAM_RESOLUTION_3264x2448;
		else if (capacity & CAM_CP_SIZE_2048X1536)
			result = CAM_RESOLUTION_2048x1536;
		else if (capacity & CAM_CP_SIZE_1280X960)
			result = CAM_RESOLUTION_1280x960;
		else
			result = CAM_RESOLUTION_VGA;
	} else if (ratio == (gdouble)16.0/9.0) {
		if (capacity & CAM_CP_SIZE_3264X1836)
			result = CAM_RESOLUTION_3264x1836;
		else if (capacity & CAM_CP_SIZE_2048X1152)
			result = CAM_RESOLUTION_2048x1152;
		else if (capacity & CAM_CP_SIZE_1280X720)
			result = CAM_RESOLUTION_1280x720;
		else
			result = CAM_RESOLUTION_VGA;
	} else if (ratio == (gdouble)3.0/2.0) {
		if (capacity & CAM_CP_SIZE_3264X2176)
			result = CAM_RESOLUTION_3264x2176;
		else
			result = CAM_RESOLUTION_VGA;
	} else {
		result = CAM_RESOLUTION_VGA;
	}

	return result;
}

void cam_app_stop_capture(void* data)
{
	cam_retm_if(data == NULL, "data is null");
	struct appdata *ad = (struct appdata *)data;

	CamAppData *camapp = ad->camapp_handle;
	cam_retm_if(camapp == NULL, "camapp is null");

	if (camapp->camera_mode == CAM_CAMERA_MODE) {
		if (camapp->shooting_mode == CAM_SINGLE_MODE) {
			if (camapp->continuous_shot_data && camapp->continuous_shot_data->capture_status == CAM_CONTI_SHOT_STATUS_CAPTURING) {
				if (cam_is_enabled_menu((void*)ad, CAM_MENU_BURST_SHOT_MODE) && camapp->burst_shot == TRUE && camapp->default_capture_mode == CAM_CAPTURE_BURST) {
					DEBUG_TRACE("burst capture mode");
					cam_mm_set_conti_shot_break(TRUE);
					ad->emit_continuous_shutter = FALSE;
					cam_app_destroy_progressbar(ad);
					camapp->continuous_shot_data->capture_status = CAM_CONTI_SHOT_STATUS_STOPPED;
				}
			}
		}
	}
}
void cam_create_error_popup(void* data)
{
	cam_retm_if(data == NULL, "data is null");
	struct appdata *ad = (struct appdata *)data;

	if( ad->error_type == CAM_ERROR_TYPE_UNABLE_TO_LAUNCH){
		if (ad->fw_error_type == CAMERA_ERROR_SOUND_POLICY ||ad->fw_error_type == RECORDER_ERROR_SOUND_POLICY) {
			cam_app_notice_popup(data, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA_DURING_CALL"), cam_app_timeout_notice_response_cb);
		}else{
			cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA"), cam_app_timeout_notice_response_cb);
		}
	}
}

static Eina_Bool __cam_app_display_error_popup_idler(void *data)
{
	debug_fenter(LOG_CAM);
	struct appdata *ad = (struct appdata *)data;
	cam_retvm_if(ad == NULL, FALSE, "appdata is NULL");

	if (ad->battery_status == LOW_BATTERY_CRITICAL_STATUS){
		cam_app_notice_popup(ad, dgettext("sys_string", "IDS_COM_BODY_LOW_BATTERY"), cam_app_timeout_notice_response_cb);
	} else if (ad->is_calling == TRUE) {
		cam_app_notice_popup(ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_START_CAMERA_DURING_CALL"), cam_app_timeout_notice_response_cb);
	} else if(ad->battery_status == LOW_BATTERY_WARNING_STATUS){
		cam_app_notice_popup((void *)ad, dgettext(PACKAGE, "IDS_CAM_POP_UNABLE_TO_USE_FLASH_BATTERY_LOW"), cam_app_lowbattery_close_flash_cb);
	}

	return ECORE_CALLBACK_CANCEL;
}

//end file
